@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@
  @author Martin Petricek
 */
 
+#include "passworddialog.h"
 #include "base.h"
 #include "qtcompat.h"
 #include "qsannotation.h"
@@ -49,6 +50,7 @@
 #include <kernel/cpdf.h>
 #include <kernel/cannotation.h>
 #include <kernel/delinearizator.h>
+#include <kernel/flattener.h>
 #include <kernel/factories.h>
 #include <kernel/pdfwriter.h>
 #include <qdir.h>
@@ -293,8 +295,7 @@ QSPdfOperator* Base::createOperator(const QString &text,QSIPropertyArray* parame
  std::string opTxt=util::convertFromUnicode(text,util::PDF);
  PdfOperator::Operands param;
  parameters->copyTo(param);
- boost::shared_ptr<SimpleGenericOperator> op(new SimpleGenericOperator(opTxt,param));
- return new QSPdfOperator(op,this);
+ return new QSPdfOperator(pdfobjects::createOperator(opTxt, param),this);
 }
 
 /**
@@ -446,6 +447,77 @@ QSPdfOperatorStack* Base::createPdfOperatorStack() {
  return new QSPdfOperatorStack(this);
 }
 
+/**
+ Common code to flattener and delinearizator
+ Ask for password for opening the PDF file if one is needed
+ @param inFile name of input file
+ @param wr PdfDocumentWriter
+ @return true if either valid password is entered or no password is needed
+*/
+bool pdfWriterAskPassword(const QString &inFile,boost::shared_ptr<utils::PdfDocumentWriter> wr) {
+ for(;wr->getNeedCredentials();) {
+  //Ask for password until we either get the right one or user gets bored with retrying
+  // FIXME is the first NULL parameter OK?
+  QString pwd=gui::PasswordDialog::ask(NULL, QObject::tr("Enter password for %1:").arg(inFile));
+
+  //Dialog aborted -> exit
+  if (pwd.isNull()) { 
+   guiPrintDbg(debug::DBG_ERR, "No password available");
+   return false;
+  }
+
+  //We succedded with passwod -> exit
+  string passwd;
+  passwd = pwd.utf8();
+  try {
+    wr->setCredentials(passwd.c_str(), passwd.c_str());
+  } catch(PermissionException &e) {
+   guiPrintDbg(debug::DBG_ERR, "Bad password");
+  }
+ }
+ return true;
+}
+
+/**
+ Try to flatten PDF, reading from input file and writing flattened result to output file.
+ Does not check for overwriting output.
+ Return true if flattening was successful, false in case of failure.<br>
+ In case of failure the error mesage is available via error()
+ \see error
+ @param inFile input file
+ @param outFile output file
+*/
+bool Base::flatten(const QString &inFile,const QString &outFile) {
+ boost::shared_ptr<utils::Flattener> flat;
+ utils::OldStylePdfWriter* wr=NULL;
+ try {
+  guiPrintDbg(debug::DBG_DBG,"Flattener started");
+  wr=new utils::OldStylePdfWriter();
+  //TODO: nekde tady zaregistrovat progress observer
+  flat=utils::Flattener::getInstance(inFile,wr);
+  if (!flat) return false;//No delinearizator instance?
+  guiPrintDbg(debug::DBG_DBG,"Flattener created");
+
+  if (!pdfWriterAskPassword(inFile,flat)) return false;
+
+  int ret=flat->flatten(outFile);
+  guiPrintDbg(debug::DBG_DBG,"Flattener finished");
+  if (ret) {
+   const char *whatWasWrong=strerror(ret);
+   lastErrorMessage=whatWasWrong;
+  }
+  guiPrintDbg(debug::DBG_DBG,"Flattener exit");
+  return (ret==0);
+ } catch (NotImplementedException &e) {
+  lastErrorMessage=tr("Flattening of encrypted documents is not supported");
+  return false;
+ } catch (...) {
+  //This is the case of failure ..
+  lastErrorMessage=tr("Unknown error occured");
+  return false;
+ }
+}
+
 /**
  Try to delinearize PDF, reading from input file and writing delinearized result to output file.
  Does not check for overwriting output.
@@ -456,7 +528,7 @@ QSPdfOperatorStack* Base::createPdfOperatorStack() {
  @param outFile output file
 */
 bool Base::delinearize(const QString &inFile,const QString &outFile) {
- utils::Delinearizator* delin=NULL;
+ boost::shared_ptr<utils::Delinearizator> delin;
  utils::OldStylePdfWriter* wr=NULL;
  try {
   guiPrintDbg(debug::DBG_DBG,"Delinearizator started");
@@ -465,22 +537,23 @@ bool Base::delinearize(const QString &inFile,const QString &outFile) {
   delin=utils::Delinearizator::getInstance(inFile,wr);
   if (!delin) return false;//No delinearizator instance?
   guiPrintDbg(debug::DBG_DBG,"Delinearizator created");
+
+  if (!pdfWriterAskPassword(inFile,delin)) return false;
+
   int ret=delin->delinearize(outFile);
   guiPrintDbg(debug::DBG_DBG,"Delinearizator finished");
   if (ret) {
    const char *whatWasWrong=strerror(ret);
    lastErrorMessage=whatWasWrong;
   }
-//  guiPrintDbg(debug::DBG_DBG,"deleting pdf writer");
-//  if (wr) delete wr;
-  guiPrintDbg(debug::DBG_DBG,"deleting delinearizator");
-  if (delin) delete delin;
   guiPrintDbg(debug::DBG_DBG,"Delinearizator exit");
   return (ret==0);
+ } catch (NotImplementedException &e) {
+  lastErrorMessage=tr("Delinearization of encrypted documents is not supported");
+  return false;
  } catch (...) {
   //This is the case of failure ..
-  if (wr) delete wr;
-  if (delin) delete delin;
+  lastErrorMessage=tr("Unknown error occured");
   return false;
  }
 }
@@ -502,13 +575,12 @@ QString Base::pdftoxml (const QString& inFile, QVariant pagenums, const QString&
 		nums.push_back ((*it).toUInt());
 	
 	// Create cpdf
-	CPdf* pdf;
-	CPdf::OpenMode mode = CPdf::ReadOnly;
+	boost::shared_ptr<CPdf> pdf;
 
 	try {
 
 		guiPrintDbg (debug::DBG_DBG,"Opening document.");
-		pdf = CPdf::getInstance (util::convertFromUnicode(inFile,util::NAME).c_str(),mode);
+		pdf = getBasePdfInstance (util::convertFromUnicode(inFile,util::NAME).c_str(),"readonly");
 		assert(pdf);
 		guiPrintDbg (debug::DBG_DBG,"Document opened.");
 	
@@ -534,12 +606,12 @@ QString Base::pdftoxml (const QString& inFile, QVariant pagenums, const QString&
 	}catch (CObjectException& e)
 	{
 		setError (tr(e.what()));
-		pdf->close();
+		pdf.reset();
 		return QString ();
 	}
 
 	// Cleanup
-	pdf->close ();
+	pdf.reset();
 
 	// Save it
 	ofstream of;
@@ -588,13 +660,14 @@ QStringList Base::functions(bool includeSignatures/*=false*/) {
  script should also take care to close the file after he does not need to use it anymore
  @param name Name of file to load
  @param advancedMode Set to true to use Advanced mode whilwe opening the file
+ @param askPassword if true, attempt to ask user for password would be made if document is encrypted
  @return Loaded document, or NULL if error occured while loading it.
 */
-QSPdf* Base::loadPdf(const QString &name,bool advancedMode/*=false*/) {
+QSPdf* Base::loadPdf(const QString &name,bool advancedMode/*=false*/, bool askPassword/*=true*/) {
  if (name.isNull()) return NULL;
  CPdf::OpenMode mode=advancedMode?(CPdf::Advanced):(CPdf::ReadWrite);
  try {
-  CPdf *opened=CPdf::getInstance(util::convertFromUnicode(name,util::NAME).c_str(),mode);
+   boost::shared_ptr<CPdf> opened=getBasePdfInstance(util::convertFromUnicode(name,util::NAME).c_str(),advancedMode?"advanced":"readwrite",askPassword);
   //Return pdf wrapper with 'destructive close' behavior
   return new QSPdf(opened,this,true);
  } catch (...) {
@@ -602,16 +675,37 @@ QSPdf* Base::loadPdf(const QString &name,bool advancedMode/*=false*/) {
  }
 }
 
+/**
+ Open PDF instance.
+ Specific password solicitation (GUI, console) should be implemented in subclasses - BaseGUI ands BaseConsole
+ @param filename filename to open
+ @param openMode Mode in which to open the file (advanced, readonly and readwrite - default)
+ @param askPassword if true, attempt to ask user for password would be made if document is encrypted
+*/
+boost::shared_ptr<pdfobjects::CPdf> Base::getBasePdfInstance(const QString &filename, const QString &openMode/*=QString::null*/, bool askPassword/*=true*/) {
+ CPdf::OpenMode mode=CPdf::ReadWrite;
+ if (openMode=="advanced") mode=CPdf::Advanced;
+ if (openMode=="readonly") mode=CPdf::ReadOnly;
+ if (openMode=="readwrite") mode=CPdf::ReadWrite;
+ //Basic mode without asking a password (we do not know how)
+ return CPdf::getInstance(util::convertFromUnicode(filename,util::NAME).c_str(),mode);
+}
+
 /** \copydoc loadFromFile */
 QString Base::loadFile(const QString &name) {
  return loadFromFile(name);
 }
 
 /** \copydoc saveToFile */
-bool Base::saveFile(const QString &name,const QString &content) {
+bool Base::saveFile(const QString &name, const QString &content) {
  return saveToFile(name,content);
 }
 
+/** \copydoc saveRawToFile */
+bool Base::saveRawFile(const QString &name, const QByteArray &content) {
+ return saveRawToFile(name, content);
+}
+
 /** Return list of all objects that are in current script interpreter */
 QStringList Base::objects() {
  QObjectList objs=qs->presentObjects();
@@ -712,7 +806,7 @@ QStringList Base::variables() {
 /** Return version of editor as string
  @return Version of editor (major.minor.release or major.minor.relase-suffix) */
 QString Base::version() {
- return VERSION;
+ return PDFEDIT_VERSION;
 }
 
 
