@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #define __BASECORE_H__
 
 #include <qobject.h>
+#include <boost/shared_ptr.hpp>
 #include "qtcompat.h"
 #include QPTRDICT
 class QSProject;
@@ -69,7 +70,7 @@ public:
  void conPrintLine(const QString &line);
  void runScript(const QString &script);
  void call(const QString &name,const QString &arguments="");
- void importDocument(pdfobjects::CPdf *pdf);
+ void importDocument(boost::shared_ptr<pdfobjects::CPdf> pdf);
  void destroyDocument();
  QSPdf* getQSPdf() const;
  void stopScript();
