@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,6 +43,8 @@
 #include "numbertool.h"
 #include "optionwindow.h"
 #include "pagespace.h"
+#include "pdfutil.h"
+#include "passworddialog.h"
 #include "pdfeditwindow.h"
 #include "propertyeditor.h"
 #include "qscobject.h"
@@ -89,6 +91,15 @@ BaseGUI::~BaseGUI() {
  delete consoleWriter;
 }
 
+boost::shared_ptr<pdfobjects::CPdf> BaseGUI::getBasePdfInstance(const QString &filename, const QString &openMode/*=QString::null*/, bool askPassword/*=true*/) {
+ CPdf::OpenMode mode=CPdf::ReadWrite;
+ if (openMode=="advanced") mode=CPdf::Advanced;
+ if (openMode=="readonly") mode=CPdf::ReadOnly;
+ if (openMode=="readwrite") mode=CPdf::ReadWrite;
+ //Password is asked for (or not) based on askPassword parameter
+ return util::getPdfInstance(w,filename,mode,askPassword);
+}
+
 /**
  Call QApplication::processEvents, to process any events (redrawing, etc)
  May be useful if you perform some lengthy operation to allow GUI to redraw
@@ -313,6 +324,15 @@ void BaseGUI::addObjectDialog(QObject *container) {
  }
 }
 
+/**
+ Shows dialog that will ask user for password.
+ @param title Title of the dialog. If not specified, some default like "Enter password" is used.
+ @return entered password or NULL if dialog is cancelled
+*/
+QString BaseGUI::askPassword(const QString &title/*=QString::null*/) {
+ return PasswordDialog::ask(w,title);
+}
+
 /** \copydoc Menu::checkByName */
 void BaseGUI::checkItem(const QString &name,bool check) {
  w->menuSystem->checkByName(name,check);
@@ -379,6 +399,24 @@ QString BaseGUI::fileSaveDialog(const QString &oldName/*=QString::null*/) {
  return ret;
 }
 
+/**
+ Show "save file" dialog and return file selected, or NULL if dialog was cancelled
+ Name must be different than origName
+ @param origName Original name of the file
+ @return name of selected file.
+ */
+QString BaseGUI::fileSaveDialogDiffer(const QString &origName) {
+ guiPrintDbg(debug::DBG_DBG,"fileSaveDialogDiffer");
+ QString ret=QString::null;
+ for(;;) {
+  ret=saveFileDialogPdf(w,QString::null);
+  if (origName.isNull()) break;
+  if (ret!=origName) break;
+  warn(tr("You must pick a different file than '%1'").arg(origName));
+ } 
+ return ret;
+}
+
 /**
  Show "save file" dialog and return file selected, or NULL if dialog was cancelled
  @param oldName Old name of the file (if known) - will be preselected
@@ -486,7 +524,7 @@ void BaseGUI::message(const QString &msg) {
 */
 QVariant BaseGUI::mergeDialog() {
  QVariant retValue;
- CPdf *doc=qpdf->get();
+ boost::shared_ptr<CPdf> doc=qpdf->get();
  if (!doc) {
   //No document opened at all
   errorException("","mergeDialog",tr("No document opened"));
@@ -562,8 +600,8 @@ bool BaseGUI::modified() {
 }
 
 /** \copydoc PdfEditWindow::openFile */
-bool BaseGUI::openFile(const QString &name) {
- return w->openFile(name);
+bool BaseGUI::openFile(const QString &name, bool askPassword/*=true*/) {
+ return w->openFile(name,askPassword);
 }
 
 /**
