@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -64,11 +64,18 @@ public:
  void addNumberTool(NumberTool *tool);
  void treeItemDeleted(TreeItemAbstract* theItem);
 public slots: //This will be all exported to scripting
+ virtual boost::shared_ptr<pdfobjects::CPdf> getBasePdfInstance(const QString &filename, const QString &openMode=QString::null, bool askPassword=true);
  /*-
   Allow application to process its events, so the gui can redraw itself.
   Useful, it it is called periodically while doing some lenthy operation
  */
  void processEvents();
+ /*-
+  Shows dialog that will ask user for password.
+  Parameter title specifies title of the dialog. If not specified, some default like "Enter password" is used.
+  Return entered password or null if dialog is cancelled
+ */
+ QString askPassword(const QString &title=QString::null);
  /*-
   Set text of all menu and toolbar items with given name to specified string.
   The string will be transtated according to the translation file, so it is
@@ -163,6 +170,12 @@ public slots: //This will be all exported to scripting
   If file selected in dialog already exists, user is asked to confirm overwriting before returing its name.
  */
  QString fileSaveDialog(const QString &oldName=QString::null);
+ /*-
+  Show "save file" dialog and return file selected, or NULL if dialog was cancelled.
+  If file selected in dialog already exists, user is asked to confirm overwriting before returing its name.
+  Name must be different than origName.
+ */
+ QString fileSaveDialogDiffer(const QString &origName);
  /*-
   Invokes "save file" dialog for XML file and return selected filename, or NULL if dialog was cancelled.
   If file selected in dialog already exists, user is asked to confirm overwriting before returing its name.
@@ -231,9 +244,13 @@ public slots: //This will be all exported to scripting
  /*-
   Opens file with given name in this editor window.
   Opens without any questions, does not ask user to save changes to current file, etc ...
+  If askPassword is true (default), user is asked for password to the
+   document and loading fails if user does not enter correct password.
+  If askPassword is false, script have to handle entering the correct
+   password and possible closing of the document on failure by itself.
   Return true on success, false on failure to load file.
  */
- bool openFile(const QString &name);
+ bool openFile(const QString &name, bool askPassword=true);
  /*- Opens file with given name in new editor window */
  void openFileNew(const QString &name);
  /*- Invokes options dialog. Does not wait for dialog to be closed by user and return immediately. */
