@@ -314,10 +314,6 @@ Data: %3
         <source>Changed revision to:</source>
         <translation>Změněna revize:</translation>
     </message>
-    <message>
-        <source>Saving as</source>
-        <translation>Ukládám jako</translation>
-    </message>
     <message>
         <source>Operators</source>
         <translation>Operátory</translation>
@@ -363,7 +359,7 @@ Data: %3
     </message>
     <message>
         <source>Encryption filter:</source>
-        <translation>Šifrovací filtr:</translation>
+        <translation type="obsolete">Šifrovací filtr:</translation>
     </message>
     <message>
         <source>No page selected!</source>
@@ -722,7 +718,7 @@ Data: %3
     </message>
     <message>
         <source>Encrypted content will show up as garbage and many operations will be impossible</source>
-        <translation>Zašifrovaný obsah bude vypadat jako smetí a mnoho operací nebude možných</translation>
+        <translation type="obsolete">Zašifrovaný obsah bude vypadat jako smetí a mnoho operací nebude možných</translation>
     </message>
     <message>
         <source>Rect was drawn.</source>
@@ -1079,6 +1075,50 @@ Data: %3
         <source>Use &apos;%1 --help&apos; to see list of commandline options and their parameters</source>
         <translation>Použijte &apos;%1 --help&apos; k zobrazení seznamu přepínačů na příkazové řádce a jejich parametrů</translation>
     </message>
+    <message>
+        <source>Saved as</source>
+        <translation>Uloženo jako</translation>
+    </message>
+    <message>
+        <source>Unable to open file: %1</source>
+        <translation>Nelze otevřít soubor: %1</translation>
+    </message>
+    <message>
+        <source>Not implemented: %1</source>
+        <translation>Nepodporováno: %1</translation>
+    </message>
+    <message>
+        <source>Unknown error</source>
+        <translation>Neznámá chyba</translation>
+    </message>
+    <message>
+        <source>Apply from page</source>
+        <translation>Aplikovat od strany</translation>
+    </message>
+    <message>
+        <source>How many pages</source>
+        <translation>Kolik stran</translation>
+    </message>
+    <message>
+        <source>Flattening failed!</source>
+        <translation>Zploštění selhalo!</translation>
+    </message>
+    <message>
+        <source>Flattened</source>
+        <translation>Zploštěný</translation>
+    </message>
+    <message>
+        <source>No pages in document</source>
+        <translation>V dokumentu nejsou žádné stránky</translation>
+    </message>
+    <message>
+        <source>Operation not implemented: %1</source>
+        <translation>Operace není podporována: %1</translation>
+    </message>
+    <message>
+        <source>Enter password for %1:</source>
+        <translation>Zadejte heslo pro %1:</translation>
+    </message>
 </context>
 <context>
     <name>annotation_type</name>
@@ -1416,6 +1456,18 @@ Režim zvýraznění</translation>
         <source>Script not found</source>
         <translation>Skript nenalezen</translation>
     </message>
+    <message>
+        <source>Flattening of encrypted documents is not supported</source>
+        <translation>Zplošťování šifrovaných dokumentů není podporováno</translation>
+    </message>
+    <message>
+        <source>Unknown error occured</source>
+        <translation>Nastala neznámá chyba</translation>
+    </message>
+    <message>
+        <source>Delinearization of encrypted documents is not supported</source>
+        <translation>Delinearizace šifrovaných dokumentů není podporována</translation>
+    </message>
 </context>
 <context>
     <name>gui::BaseCore</name>
@@ -1468,6 +1520,10 @@ Režim zvýraznění</translation>
         <source>No document opened</source>
         <translation>Není otevřen dokument</translation>
     </message>
+    <message>
+        <source>You must pick a different file than &apos;%1&apos;</source>
+        <translation>Musíte vybrat jiný soubor než &apos;%1&apos;</translation>
+    </message>
 </context>
 <context>
     <name>gui::ColorTool</name>
@@ -1505,6 +1561,11 @@ Režim zvýraznění</translation>
         <source>Open file with pages to be inserted</source>
         <translation>Otevřít soubor se stránkami k vložení</translation>
     </message>
+    <message>
+        <source>END</source>
+        <comment>end of document marker</comment>
+        <translation>KONEC</translation>
+    </message>
 </context>
 <context>
     <name>gui::MultiTreeWindow</name>
@@ -1765,6 +1826,17 @@ Režim zvýraznění</translation>
         <translation>%1 z %2</translation>
     </message>
 </context>
+<context>
+    <name>gui::PasswordDialog</name>
+    <message>
+        <source>Enter password</source>
+        <translation>Zadejte heslo</translation>
+    </message>
+    <message>
+        <source>Password:</source>
+        <translation>Heslo:</translation>
+    </message>
+</context>
 <context>
     <name>gui::PdfEditWindow</name>
     <message>
@@ -1803,10 +1875,6 @@ Režim zvýraznění</translation>
         <source>Unknown error occured while saving document</source>
         <translation>Neznámá chyba při ukládání dokumentu</translation>
     </message>
-    <message>
-        <source>Error occured while saving copy</source>
-        <translation>Při ukládání kopie došlo k chybě</translation>
-    </message>
     <message>
         <source>Linearized PDF</source>
         <translation>Linearizované PDF</translation>
@@ -1827,6 +1895,22 @@ Režim zvýraznění</translation>
         <source>Selected annotations</source>
         <translation>Vybrané anotace</translation>
     </message>
+    <message>
+        <source>Saving not implemented:
+%1</source>
+        <translation>Ukládání není implementováno:
+%1</translation>
+    </message>
+    <message>
+        <source>Error occured while saving copy:
+%1</source>
+        <translation>Při ukládání kopie došlo k chybě:
+%1</translation>
+    </message>
+    <message>
+        <source>Password entered for document is not valid</source>
+        <translation>Zadané heslo není platné pro tento dokument</translation>
+    </message>
 </context>
 <context>
     <name>gui::Property</name>
@@ -1925,6 +2009,12 @@ Režim zvýraznění</translation>
         <source>Unknown error occured while saving document</source>
         <translation>Neznámá chyba při ukládání dokumentu</translation>
     </message>
+    <message>
+        <source>Unable to save:
+%1</source>
+        <translation>Nelze uložit:
+%1</translation>
+    </message>
 </context>
 <context>
     <name>gui::RefPropertyDialog</name>
@@ -2080,7 +2170,7 @@ Režim zvýraznění</translation>
     <message>
         <source>Save &amp;copy...</source>
         <comment>fsavecopy</comment>
-        <translation>Uložit kopii...</translation>
+        <translation type="obsolete">Uložit kopii...</translation>
     </message>
     <message>
         <source>&amp;Page</source>
@@ -2347,6 +2437,11 @@ Režim zvýraznění</translation>
         <comment>reloadpage</comment>
         <translation>Obnovit stránku (ukázat změny)</translation>
     </message>
+    <message>
+        <source>&amp;Copy current revision</source>
+        <comment>fcopyrevision</comment>
+        <translation>Zkopírovat aktuální revizi</translation>
+    </message>
 </context>
 <context>
     <name>gui::TreeItemPdf</name>
