@@ -316,7 +316,7 @@ Datos: %3
     </message>
     <message>
         <source>Saving as</source>
-        <translation>Guardando como</translation>
+        <translation type="obsolete">Guardando como</translation>
     </message>
     <message>
         <source>Operators</source>
@@ -363,7 +363,7 @@ Datos: %3
     </message>
     <message>
         <source>Encryption filter:</source>
-        <translation>Filtro de cifrado:</translation>
+        <translation type="obsolete">Filtro de cifrado:</translation>
     </message>
     <message>
         <source>No page selected!</source>
@@ -722,7 +722,7 @@ Datos: %3
     </message>
     <message>
         <source>Encrypted content will show up as garbage and many operations will be impossible</source>
-        <translation>El contenido cifrado se mostrará difuso y muchas operaciones serán imposibles</translation>
+        <translation type="obsolete">El contenido cifrado se mostrará difuso y muchas operaciones serán imposibles</translation>
     </message>
     <message>
         <source>Rect was drawn.</source>
@@ -1079,6 +1079,50 @@ Datos: %3
         <source>Use &apos;%1 --help&apos; to see list of commandline options and their parameters</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Saved as</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to open file: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Not implemented: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Apply from page</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>How many pages</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Flattening failed!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Flattened</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No pages in document</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Operation not implemented: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter password for %1:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>annotation_type</name>
@@ -1427,6 +1471,18 @@ Datos: %3
         <source>Script not found</source>
         <translation>Script no encontrado</translation>
     </message>
+    <message>
+        <source>Flattening of encrypted documents is not supported</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown error occured</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delinearization of encrypted documents is not supported</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>gui::BaseCore</name>
@@ -1479,6 +1535,10 @@ Datos: %3
         <source>No document opened</source>
         <translation>Ningún documento abierto</translation>
     </message>
+    <message>
+        <source>You must pick a different file than &apos;%1&apos;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>gui::ColorTool</name>
@@ -1516,6 +1576,11 @@ Datos: %3
         <source>Open file with pages to be inserted</source>
         <translation>Abrir archivo con las páginas a insertarse</translation>
     </message>
+    <message>
+        <source>END</source>
+        <comment>end of document marker</comment>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>gui::MultiTreeWindow</name>
@@ -1780,6 +1845,17 @@ Datos: %3
         <translation type="obsolete">La zona a redimensionar debe ser entero positivo o nulo !</translation>
     </message>
 </context>
+<context>
+    <name>gui::PasswordDialog</name>
+    <message>
+        <source>Enter password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Password:</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>gui::PdfEditWindow</name>
     <message>
@@ -1820,7 +1896,7 @@ Datos: %3
     </message>
     <message>
         <source>Error occured while saving copy</source>
-        <translation>Error ocurrido mientras se guardaba una copia</translation>
+        <translation type="obsolete">Error ocurrido mientras se guardaba una copia</translation>
     </message>
     <message>
         <source>Linearized PDF</source>
@@ -1842,6 +1918,20 @@ Datos: %3
         <source>Selected annotations</source>
         <translation>Anotaciones seleccionadas</translation>
     </message>
+    <message>
+        <source>Saving not implemented:
+%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error occured while saving copy:
+%1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Password entered for document is not valid</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>gui::Property</name>
@@ -1940,6 +2030,11 @@ Datos: %3
         <source>Unknown error occured while saving document</source>
         <translation>Error desconocido ocurrido mientras se guardaba el documento</translation>
     </message>
+    <message>
+        <source>Unable to save:
+%1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>gui::RefPropertyDialog</name>
@@ -2100,7 +2195,7 @@ Datos: %3
     <message>
         <source>Save &amp;copy...</source>
         <comment>fsavecopy</comment>
-        <translation>Guardar c&amp;opia...</translation>
+        <translation type="obsolete">Guardar c&amp;opia...</translation>
     </message>
     <message>
         <source>&amp;Page</source>
@@ -2367,6 +2462,11 @@ Datos: %3
         <comment>reloadpage</comment>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Copy current revision</source>
+        <comment>fcopyrevision</comment>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>gui::TreeItemPdf</name>
