@@ -629,11 +629,11 @@
     </message>
     <message>
         <source>Encryption filter:</source>
-        <translation>Фильтр шифрования:</translation>
+        <translation type="obsolete">Фильтр шифрования:</translation>
     </message>
     <message>
         <source>Encrypted content will show up as garbage and many operations will be impossible</source>
-        <translation>Зашифрованное содержимое будет отображено неподобающе, и многие операции будет невозможно выполнить</translation>
+        <translation type="obsolete">Зашифрованное содержимое будет отображено неподобающе, и многие операции будет невозможно выполнить</translation>
     </message>
     <message>
         <source>Error occured while loading file</source>
@@ -1100,6 +1100,26 @@ Data: %3
         <source>How many pages</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Flattening failed!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Flattened</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No pages in document</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Operation not implemented: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter password for %1:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>annotation_type</name>
@@ -1436,6 +1456,18 @@ Data: %3
         <source>Warning</source>
         <translation>Предупреждение</translation>
     </message>
+    <message>
+        <source>Flattening of encrypted documents is not supported</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown error occured</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delinearization of encrypted documents is not supported</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>gui::BaseCore</name>
@@ -1488,6 +1520,10 @@ Data: %3
         <source>No document opened</source>
         <translation>Ни один документ не открыт</translation>
     </message>
+    <message>
+        <source>You must pick a different file than &apos;%1&apos;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>gui::ColorTool</name>
@@ -1525,6 +1561,11 @@ Data: %3
         <source>&amp;Filename</source>
         <translation>&amp;Имя файла</translation>
     </message>
+    <message>
+        <source>END</source>
+        <comment>end of document marker</comment>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>gui::MultiTreeWindow</name>
@@ -1784,6 +1825,17 @@ Data: %3
         <translation>Сохранить как изображение...</translation>
     </message>
 </context>
+<context>
+    <name>gui::PasswordDialog</name>
+    <message>
+        <source>Enter password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Password:</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>gui::PdfEditWindow</name>
     <message>
@@ -1856,6 +1908,10 @@ Data: %3
 %1</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Password entered for document is not valid</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>gui::Property</name>
@@ -2279,7 +2335,7 @@ Data: %3
     <message>
         <source>Save &amp;copy...</source>
         <comment>fsavecopy</comment>
-        <translation>Сохранить &amp;копию...</translation>
+        <translation type="obsolete">Сохранить &amp;копию...</translation>
     </message>
     <message>
         <source>Save new &amp;revision</source>
@@ -2386,6 +2442,11 @@ Data: %3
         <comment>reloadpage</comment>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Copy current revision</source>
+        <comment>fcopyrevision</comment>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>gui::TreeItemPdf</name>
