@@ -354,10 +354,6 @@ Data: %3
         <source>Warning: This document is encrypted!</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Encryption filter:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>No page selected!</source>
         <translation type="unfinished"></translation>
@@ -693,10 +689,6 @@ Data: %3
         <source>Line was drawn.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Encrypted content will show up as garbage and many operations will be impossible</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Rect was drawn.</source>
         <translation type="unfinished"></translation>
@@ -1096,6 +1088,26 @@ Data: %3
         <source>How many pages</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Flattening failed!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Flattened</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No pages in document</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Operation not implemented: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enter password for %1:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>annotation_type</name>
@@ -1432,6 +1444,18 @@ Data: %3
         <source>Warning</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Flattening of encrypted documents is not supported</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unknown error occured</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Delinearization of encrypted documents is not supported</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>gui::BaseCore</name>
@@ -1484,6 +1508,10 @@ Data: %3
         <source>No document opened</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>You must pick a different file than &apos;%1&apos;</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>gui::ColorTool</name>
@@ -1521,6 +1549,11 @@ Data: %3
         <source>Open file with pages to be inserted</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>END</source>
+        <comment>end of document marker</comment>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>gui::MultiTreeWindow</name>
@@ -1780,6 +1813,17 @@ Data: %3
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>gui::PasswordDialog</name>
+    <message>
+        <source>Enter password</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Password:</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>gui::PdfEditWindow</name>
     <message>
@@ -1848,6 +1892,10 @@ Data: %3
 %1</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Password entered for document is not valid</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>gui::Property</name>
@@ -2103,11 +2151,6 @@ Data: %3
         <comment>rot90</comment>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Save &amp;copy...</source>
-        <comment>fsavecopy</comment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Page</source>
         <comment>pagemenu</comment>
@@ -2373,6 +2416,11 @@ Data: %3
         <comment>reloadpage</comment>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Copy current revision</source>
+        <comment>fcopyrevision</comment>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>gui::TreeItemPdf</name>
