@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@
 #include "util.h"
 #include "version.h"
 #include "kernel/cannotation.h"
+#include "kernel/pdfedit-core-dev.h"
 #include <iostream>
 #include <qapplication.h>
 #include <qdir.h>
@@ -86,7 +87,7 @@ void handleHelp(){
  Print version to STDOUT and exit
  */
 void handleVersion(){
- cout << VERSION << endl;
+ cout << PDFEDIT_VERSION << endl;
  exit(0);
 }
 
@@ -213,6 +214,13 @@ int main(int argc, char *argv[]){
  }
  app.installTranslator(&translator);
 
+ // initializes all global configuration stuff
+ if(pdfedit_core_dev_init(&argc, &argv))
+ {
+   guiPrintDbg(debug::DBG_PANIC, "Unable to initialize pdfedit core");
+   return 1;
+ }
+
  //parse commandline parameters
  /*
   Whole name of one parameter should not be prefix of another parameter, as unpredictable behaviour can occur,
@@ -235,11 +243,6 @@ int main(int argc, char *argv[]){
  guiPrintDbg(debug::DBG_DBG,"Commandline parameters processed");
  guiPrintDbg(debug::DBG_DBG,"App path: " << Q_OUT(appPath));
 
- // initializes global parameters for xpdf code - TODO use
- // configuration file - from parameters
- GlobalParams::initGlobalParams("");
- globalParams->setupBaseFonts(NULL);
-
  //load settings
  globalSettings=Settings::getInstance();
  globalSettings->setName("settings");
