@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -358,7 +358,7 @@ void MultiTreeWindow::clearSecondary() {
  @param pdfDoc Document used to initialize treeview
  @param fileName Name of PDF document (will be shown in treeview as name of root element)
  */
-void MultiTreeWindow::init(CPdf *pdfDoc,const QString &fileName) {
+void MultiTreeWindow::init(boost::shared_ptr<CPdf> pdfDoc,const QString &fileName) {
  mainTree->init(pdfDoc,fileName);
  tab->setTabToolTip(mainTree,tr("Document tree")+" - "+fileName);
  //Emit "selection have changed", as the old tree structure is gone
