@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -264,7 +264,7 @@ QProgressBar * PdfEditWindow::getProgressBar() {
 PdfEditWindow::PdfEditWindow(const QString &fName/*=QString::null*/,QWidget *parent/*=0*/,const char *name/*=0*/):QMainWindow(parent,name,Qt::WDestructiveClose | Qt::WType_TopLevel) {
  //Set the initial title
  setFileName(QString::null);
- document=NULL;
+ document=boost::shared_ptr<CPdf>();
  selectedTreeItem=NULL;
  selectedPageNumber=0;
  //Horizontal splitter Preview + Commandline | Treeview + Property editor
@@ -758,7 +758,7 @@ bool PdfEditWindow::saveCopy(const QString &name) {
 void PdfEditWindow::setFileName(const QString &name) {
  fileName=name;
  if (name.isNull()) { //No name
-  setCaption(QString(APP_NAME));
+  setCaption(QString(APP_NAME)+" "+QString(PDFEDIT_VERSION));
   baseName=QString::null;
   return;
  }
@@ -778,7 +778,7 @@ void PdfEditWindow::setTitle(int revision/*=0*/) {
  if (revision) revisionInfo=QString(" - ")+tr("viewing revision")+" "+QString::number(revision);
  QStringList docFlags;
  if (document->isLinearized()) docFlags+=tr("Linearized PDF");
- if (pdfobjects::utils::isEncrypted(*document,NULL)) docFlags+=tr("Encrypted");
+ if (pdfobjects::utils::isEncrypted(document)) docFlags+=tr("Encrypted");
  QString docInfo="";
  if (docFlags.count()) {
   docInfo=" ( "+docFlags.join(", ")+" )";
@@ -797,20 +797,21 @@ void PdfEditWindow::destroyFile() {
  selectedOperator.reset();//no operator selected
  selectedPage.reset();//no page selected
  selectedPageNumber=0;//no page selected
- document->close(false);
+ document.reset();
  base->destroyDocument();
 // Doing GC on closing file may have side effects, so it's better not to do it
 // base->cleanup();//Garbage collection on scripting objects
- document=NULL;
+ document=boost::shared_ptr<CPdf>();
  setFileName(QString::null);
 }
 
 /**
  Open file in editor.
  @param name Name of file to open
+ @param askPassword Ask user directly for password? If not, password have to be set other ways if necessary (via script for example)
  @return True if success, false if failure
 */
-bool PdfEditWindow::openFile(const QString &name) {
+bool PdfEditWindow::openFile(const QString &name, bool askPassword/*=true*/) {
  destroyFile();
  if (name.isNull()) {
   base->setError(tr("Name is empty"));
@@ -819,11 +820,21 @@ bool PdfEditWindow::openFile(const QString &name) {
  CPdf::OpenMode mode=globalSettings->readBool("mode/advanced")?(CPdf::Advanced):(CPdf::ReadWrite);
  try {
   guiPrintDbg(debug::DBG_DBG,"Opening document");
-  document=CPdf::getInstance(util::convertFromUnicode(name,util::NAME).c_str(),mode);
+  document=getPdfInstance(this,name,mode,askPassword);
+  if (askPassword && document->needsCredentials()) {
+   //User failed to enter correct password when asked.
+   //resets document instance to force closing
+   document.reset();
+   base->setError(tr("Password entered for document is not valid"));
+   //File failed to open, keep window opened with empty file.
+   emptyFile();
+   base->call("onLoadError");
+   return false;
+  }
   // registers observer with progress bar on document writer
   // this will cause displaying of content saving progress
   pdfobjects::utils::IPdfWriter * writer=document->getPdfWriter();
-  if(writer) {
+  if (writer) {
    REGISTER_PTR_OBSERVER(writer, progressObserver);
   }
   assert(document);
@@ -858,7 +869,8 @@ bool PdfEditWindow::openFile(const QString &name) {
 /** Opens new empty file in editor. */
 void PdfEditWindow::emptyFile() {
  destroyFile();
- document=NULL;
+// document=boost::shared_ptr<CPdf>();
+ document.reset();
  base->importDocument(document);
  tree->uninit();
  emit documentChanged(document);
