@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,13 +27,12 @@
  \brief PDF manipulation utility functions header
 */
 
-#include <kernel/iproperty.h>
-#include <kernel/cobject.h>
 #include <kernel/cannotation.h>
+#include <kernel/cobject.h>
+#include <kernel/cpdf.h>
+#include <kernel/iproperty.h>
 class QString;
-namespace pdfobjects {
-class CPdf;
-}
+class QWidget;
 
 namespace util {
 
@@ -47,11 +46,11 @@ QString getTypeName(IProperty *obj);
 QString getTypeName(boost::shared_ptr<IProperty> obj);
 IndiRef getRef(IProperty *ref);
 IndiRef getRef(boost::shared_ptr<IProperty> ref);
-bool isRefValid(CPdf *pdf, IndiRef ref);
+bool isRefValid(boost::shared_ptr<CPdf> pdf, IndiRef ref);
 bool isSimple(IProperty* prop);
 bool isSimple(boost::shared_ptr<IProperty> prop);
 boost::shared_ptr<IProperty> dereference(boost::shared_ptr<IProperty> obj);
-bool saveCopy(CPdf *obj, const QString &name, QString *error);
+bool saveCopy(boost::shared_ptr<CPdf> obj, const QString &name, QString *error);
 boost::shared_ptr<IProperty> getObjProperty(boost::shared_ptr<CDict> obj, const QString &name);
 boost::shared_ptr<IProperty> getObjProperty(boost::shared_ptr<CArray> obj, const QString &name);
 boost::shared_ptr<IProperty> recursiveProperty(boost::shared_ptr<CDict> obj, const QString &name);
@@ -61,6 +60,10 @@ QString annotType(CAnnotation::AnnotType at);
 QString annotType(boost::shared_ptr<CAnnotation> anot);
 QString annotTypeName(boost::shared_ptr<CAnnotation> anot);
 
+//Password-related functions
+boost::shared_ptr<CPdf> getPdfInstance(QWidget *parent, const QString &filename, CPdf::OpenMode mode, bool askPassword=true);
+bool setPdfPassword(boost::shared_ptr<CPdf> pdf, const QString &pass);
+
 } // namespace util
 
 #endif
