@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -134,7 +134,7 @@ QSCObject* QSImporter::createQSObject(boost::shared_ptr<IProperty> ip,BaseCore *
  @param pdf CPdf to wrap into to QSPdf
  @return QSPdf(pdf)
  */
-QSPdf* QSImporter::createQSObject(CPdf* pdf) {
+QSPdf* QSImporter::createQSObject(boost::shared_ptr<CPdf> pdf) {
  if (!pdf) return NULL;
  return new QSPdf(pdf,base);
 }
