@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -43,19 +43,26 @@ using namespace pdfobjects;
  Note to page manipulation - page numbers start from number 1 (not from zero as some programmers may expect),
  number of last page is equal to count of pages.
  */
-/** \brief QObject wrapper around CPdf */
+/** \brief QObject wrapper around shared_ptr&lt;CPdf&gt; */
 class QSPdf : public QSCObject {
  Q_OBJECT
 public:
- QSPdf(CPdf *_pdf,BaseCore *_base,bool _destructive=false);
+QSPdf(boost::shared_ptr<CPdf>_pdf,BaseCore *_base,bool _destructive=false);
  virtual ~QSPdf();
- CPdf* get() const;
- void set(CPdf* pdf);
+ boost::shared_ptr<CPdf> get() const;
+ void set(boost::shared_ptr<CPdf> pdf);
 public slots:
- /*- Return name of filter used to encrypt the document, or NULL if document is not encrypted */
- QString encryption();
+ /*- Returns true if document is opened in read-only mode, false if in read-write mode */
+ bool isReadOnly();
+ /*- Returns true if document is encrypted. */
+ bool isEncrypted();
  /*- Return true, if document is linearized PDF, false otherwise */
  bool isLinearized();
+ /*-
+  Return true if document is protected and opening the document reqires credentials
+  (usually a password), false otherwise.
+ */
+ bool needsCredentials();
  /*-
   Check for PDF validity - return true, if this object is valid PDF document,
   false if the PDF document was closed or not yet opened
@@ -82,6 +89,11 @@ public slots:
   Return true if saved successfully, false if failed to save because of any reason
  */
  bool save(bool newRevision=false);
+ /*-
+  Sets PDF password to use for decryption. Needed for opening password-protected documents
+  Return true if the password was successfully set, false in case of error (bad password ...)
+ */
+ bool setPassword(const QString &pass);
  /*- Get document dictionary (object catalog) */
  QSDict* getDictionary();
  /*- Remove page with given number from document. */
@@ -123,7 +135,7 @@ public slots:
  bool referenceValid(int valueNum,int valueGen);
 private:
  /** Pointer to object held in class*/
- CPdf *obj;
+ boost::shared_ptr<CPdf> obj;
  /** Destructive flag - if the PDF file may be closed with the unloadPdf() function */
  bool destructive;
 };
