@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -112,6 +112,15 @@ QString QSPdfOperator::getText() {
  return util::convertToUnicode(text,util::PDF);
 }
 
+QString QSPdfOperator::getEncodedText() {
+ std::string text;
+ TextSimpleOperator * textOp = dynamic_cast<TextSimpleOperator*>(obj.get());
+ if (!textOp)
+	 return QString::null;
+ textOp->getFontText(text);
+ return util::convertToUnicode(text, util::PDF);
+}
+
 /**
  Create new operator iterator from this PDF operator.
  The iterator will be initially positioned at this item
