@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -126,6 +126,14 @@ public slots:
  int childCount();
  /*- Return text representation of this pdf operator */
  QString getText();
+
+ // TODO place to somehow better place or leave it here?
+ /*-
+  Returns encoded text from text operator. Returns an empty string 
+  for all other operators.
+  */
+ QString getEncodedText();
+
  /*- Return name of this pdf operator */
  QString getName();
  /*- Returns parameters of this operator in array */
