@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #define __QSSTREAM_H__
 
 #include <kernel/cobject.h>
+#include <qstringlist.h>
 #include "qsiproperty.h"
 class QString;
 
@@ -65,6 +66,25 @@ public slots:
  bool saveBuffer(const QString &fileName);
  /*- Return decoded text representation of this property */
  QString getDecoded();
+ /*- Return decoded raw bytes representation of this property */
+ QByteArray getRawDecoded();
+ /*- Add property with given name to stream dictionary */
+ void add(const QString &name,QSIProperty *ip);
+ void add(const QString &name,QObject *ip);
+ /*- Add string property with given name to stream dictionary */
+ void add(const QString &name,const QString &ip);
+ /*- Add integer property with given name to stream dictionary */
+ void add(const QString &name,int ip);
+ /*- Return number of properties held in stream dictionary */
+ int count();
+ /*- Delete property with given name from stream dictionary */
+ void delProperty(const QString &name);
+ /*- Check for existence of property with given name in stream dictionary. If it exists, returns true */
+ bool exist(const QString &name);
+ /*- Get property with given name from stream dictionary */
+ QSCObject* property(const QString &name);
+ /*- Return array containing names of all properties in stream dictionary */
+ QStringList propertyNames();
 };
 
 } // namespace gui
