@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -56,7 +56,7 @@ public:
  virtual void applyReadOnly(bool _readonly);
  virtual bool isValid();
  IndiRef getValue();
- void setPdf(CPdf *_pdf);
+ void setPdf(boost::weak_ptr<CPdf> _pdf);
 protected slots:
  void selectRef();
  void emitChange();
@@ -67,7 +67,7 @@ private:
  /** Push button for GUI selection */
  QPushButton *pb;
  /** PDF stored for validating references */
- CPdf *pdf;
+ boost::weak_ptr<CPdf> pdf;
 };
 
 } // namespace gui
