@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -45,7 +45,7 @@ using namespace pdfobjects;
 class RefPropertyDialog : public QDialog {
 Q_OBJECT
 public:
- RefPropertyDialog(CPdf* _pdf,IndiRef src, QWidget *parent=0);
+ RefPropertyDialog(boost::weak_ptr<CPdf> _pdf,IndiRef src, QWidget *parent=0);
  ~RefPropertyDialog();
  QString getResult();
 private slots:
@@ -60,7 +60,7 @@ private:
  /** Current value */
  IndiRef value;
  /** Pdf document with reference */
- CPdf* pdf;
+ boost::weak_ptr<CPdf> pdf;
  /** Label to show errors/messages*/
  QLabel* infoText;
 };
