@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
  */
 
 #include "selectpagesdialog.h"
+#include "pdfutil.h"
 #include "util.h"
 #include <qvariant.h>
 #include <qpushbutton.h>
@@ -337,13 +338,13 @@ void SelectPagesDialog::init (size_t count) {
 //
 //
 bool SelectPagesDialog::init (const QString& fileName) {
-	CPdf* document;
+	boost::shared_ptr<CPdf> document;
 	CPdf::OpenMode mode = CPdf::ReadOnly;
 
 	try {
 
 		guiPrintDbg (debug::DBG_DBG,"Opening document.");
-		document = CPdf::getInstance (util::convertFromUnicode(fileName,util::NAME).c_str(),mode);
+		document = util::getPdfInstance (this,fileName,mode);
 		assert(document);
 		guiPrintDbg (debug::DBG_DBG,"Document opened.");
 	
@@ -357,7 +358,7 @@ bool SelectPagesDialog::init (const QString& fileName) {
 
 	// Init pages
 	init (document->getPageCount());
-	document->close();
+	document.reset();
 	
 	return true;
 }
