@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -58,7 +58,7 @@ using namespace pdfobjects;
  @param name Name of this item - will be shown in treeview
  @param after Item after which this one will be inserted
  */
-TreeItemPdf::TreeItemPdf(TreeData *_data,CPdf *_pdf,Q_ListView *parent,const QString &name/*=QString::null*/,Q_ListViewItem *after/*=NULL*/):TreeItemAbstract("Document",_data,parent,after) {
+TreeItemPdf::TreeItemPdf(TreeData *_data,boost::shared_ptr<CPdf> _pdf,Q_ListView *parent,const QString &name/*=QString::null*/,Q_ListViewItem *after/*=NULL*/):TreeItemAbstract("Document",_data,parent,after) {
  assert(_pdf);
  init(_pdf,name);
  reloadSelf();
@@ -72,7 +72,7 @@ TreeItemPdf::TreeItemPdf(TreeData *_data,CPdf *_pdf,Q_ListView *parent,const QSt
  @param name Name of file - will be shown in treeview
  @param after Item after which this one will be inserted
  */
-TreeItemPdf::TreeItemPdf(TreeData *_data,CPdf *_pdf,Q_ListViewItem *parent,const QString &name/*=QString::null*/,Q_ListViewItem *after/*=NULL*/):TreeItemAbstract("Document",_data,parent,after) {
+TreeItemPdf::TreeItemPdf(TreeData *_data,boost::shared_ptr<CPdf> _pdf,Q_ListViewItem *parent,const QString &name/*=QString::null*/,Q_ListViewItem *after/*=NULL*/):TreeItemAbstract("Document",_data,parent,after) {
  init(_pdf,name);
  reloadSelf();
 }
@@ -92,7 +92,7 @@ TreeItemPdf::TreeItemPdf(TreeData *_data,TreeItemPdf *parent,const QString &name
  @param pdf CPdf used to initialize this item
  @param name Name of this item - will be shown in treeview (usually name of PDF file)
  */
-void TreeItemPdf::init(CPdf *pdf,const QString &name) {
+void TreeItemPdf::init(boost::shared_ptr<CPdf> pdf,const QString &name) {
  obj=pdf;
  // object name
  if (name.isNull()) {
@@ -108,7 +108,7 @@ void TreeItemPdf::observePageDict() {
  //Add observer to pagecount
  try {
   assert(obj);
-  pageDictionary=pdfobjects::utils::getPageTreeRoot(*obj);
+  pageDictionary=pdfobjects::utils::getPageTreeRoot(obj);
   assert(pageDictionary.get());
   if (pageDictionary.get()) {
    //Register observer on page dictionary (because of page count)
@@ -138,7 +138,7 @@ void TreeItemPdf::removeObserver() {
  @param pdf CPdf used to initialize this item
  @param name Name of this item - will be shown in treeview
  */
-void TreeItemPdf::initSpec(CPdf *pdf,const QString &name) {
+void TreeItemPdf::initSpec(boost::shared_ptr<CPdf> pdf,const QString &name) {
  obj=pdf;
  // object name
  if (name.isNull()) {
@@ -157,7 +157,7 @@ void TreeItemPdf::initSpec(CPdf *pdf,const QString &name) {
 
 /** return CPdf stored inside this item
  @return stored object (CPdf) */
-CPdf* TreeItemPdf::getObject() {
+boost::shared_ptr<CPdf> TreeItemPdf::getObject() {
  return obj;
 }
 
