@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -56,11 +56,11 @@ using namespace pdfobjects;
 */
 class TreeItemPdf : public TreeItemAbstract {
 public:
- TreeItemPdf(TreeData *_data,CPdf *_pdf,Q_ListView *parent,const QString &name=QString::null,Q_ListViewItem *after=NULL);
- TreeItemPdf(TreeData *_data,CPdf *_pdf,Q_ListViewItem *parent,const QString &name=QString::null,Q_ListViewItem *after=NULL);
+ TreeItemPdf(TreeData *_data,boost::shared_ptr<CPdf> _pdf,Q_ListView *parent,const QString &name=QString::null,Q_ListViewItem *after=NULL);
+ TreeItemPdf(TreeData *_data,boost::shared_ptr<CPdf> _pdf,Q_ListViewItem *parent,const QString &name=QString::null,Q_ListViewItem *after=NULL);
  TreeItemPdf(TreeData *_data,TreeItemPdf *parent,const QString &name,Q_ListViewItem *after=NULL);
  virtual ~TreeItemPdf();
- CPdf* getObject();
+ boost::shared_ptr<CPdf> getObject();
  //From TreeItemAbstract interface
  virtual bool validChild(const QString &name,Q_ListViewItem *oldChild);
  virtual ChildType getChildType(const QString &name);
@@ -74,10 +74,10 @@ public:
 private:
  void observePageDict();
  void removeObserver();
- void init(CPdf *pdf,const QString &name);
- void initSpec(CPdf *pdf,const QString &name);
+ void init(boost::shared_ptr<CPdf> pdf,const QString &name);
+ void initSpec(boost::shared_ptr<CPdf> pdf,const QString &name);
  /** CPdf stored in this TreeItem */
- CPdf *obj;
+ boost::shared_ptr<CPdf> obj;
  /** Node type (Null, Pages,Outlines) */
  QString nType;
  /** Observer registered for this item */
