@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -332,6 +332,26 @@ bool saveToFile(const QString &name,const QString &content) {
  assert(codec);
  QCString qb=codec->fromUnicode(content);
  f.writeBlock(qb.data(),qb.length());
+ f.close();
+
+ return true;
+}
+
+/**
+ Save raw bytes into file.
+ @param name Filename of file to write to. It will be overwritten.
+ @param content Buffer to write.
+ @return true in case of success, false in case of failure
+*/
+bool saveRawToFile(const QString &name, const QByteArray &content) {
+ QFile f(name);
+ if (!f.open(IO_WriteOnly)) {
+  //Failure
+  return false;
+ }
+
+ f.writeBlock(content.data(),content.size());
+
  f.close();
  return true;
 }
@@ -413,16 +433,16 @@ QString getUntil(char separator,QString &line,bool escape/*=false*/) {
 void setDebugLevel(const QString &param){
  QString cns=param.upper();
  if (cns.length()) { //Check for symbolic constants
-  if (QString("PANIC").startsWith(cns))		{ debug::debugLevel=debug::DBG_PANIC;	return; }
-  if (QString("CRITICAL").startsWith(cns))	{ debug::debugLevel=debug::DBG_CRIT;	return; }
-  if (QString("ERROR").startsWith(cns))		{ debug::debugLevel=debug::DBG_ERR;	return; }
-  if (QString("WARNING").startsWith(cns))	{ debug::debugLevel=debug::DBG_WARN;	return; }
-  if (QString("INFO").startsWith(cns))		{ debug::debugLevel=debug::DBG_INFO;	return; }
-  if (QString("DEBUG").startsWith(cns))		{ debug::debugLevel=debug::DBG_DBG;	return; }
-  if (QString("DBG").startsWith(cns))		{ debug::debugLevel=debug::DBG_DBG;	return; }
+  if (QString("PANIC").startsWith(cns))		{ debug::changeDebugLevel(debug::DBG_PANIC); return; }
+  if (QString("CRITICAL").startsWith(cns))	{ debug::changeDebugLevel(debug::DBG_CRIT); return; }
+  if (QString("ERROR").startsWith(cns))		{ debug::changeDebugLevel(debug::DBG_ERR); return; }
+  if (QString("WARNING").startsWith(cns))	{ debug::changeDebugLevel(debug::DBG_WARN); return; }
+  if (QString("INFO").startsWith(cns))		{ debug::changeDebugLevel(debug::DBG_INFO); return; }
+  if (QString("DEBUG").startsWith(cns))		{ debug::changeDebugLevel(debug::DBG_DBG); return; }
+  if (QString("DBG").startsWith(cns))		{ debug::changeDebugLevel(debug::DBG_DBG); return; }
  }
  //If debuglevel is set outside of limits - no problem, nearest "in limits" value is defacto used
- debug::debugLevel=atoi(param);
+ debug::changeDebugLevel(atoi(param));
  //If non-number is given, default 0 is silently used ... :)
 }
 
