@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -90,14 +90,14 @@ public:
 	 * @param o		Xpdf object. 
 	 * @param rf	Indirect id and gen id.
 	 */
-	CArray (CPdf& p, Object& o, const IndiRef& rf);
+	CArray (boost::weak_ptr<CPdf> p, const Object& o, const IndiRef& rf);
 
 	/**
 	 * Constructor.
 	 *
 	 * @param o		Xpdf object. 
 	 */
-	CArray (Object& o);
+	CArray (const Object& o);
 
 
 public:	
@@ -195,7 +195,7 @@ public:
 	 * Set pdf to this object and its children.
 	 * @param pdf New pdf.
 	 */
-	virtual void setPdf (CPdf* pdf);
+	virtual void setPdf (boost::weak_ptr<CPdf> pdf);
 
 	/**
 	 * Set ref to this object and its children.
@@ -353,7 +353,7 @@ namespace utils {
  * @param obj	Xpdf object which holds the value.
  * @param val	Variable where the value will be stored.
  */
-template <PropertyType Tp,typename T> void complexValueFromXpdfObj (IProperty& ip, ::Object& obj, T val);
+template <PropertyType Tp,typename T> void complexValueFromXpdfObj (IProperty& ip, const ::Object& obj, T val);
 
 //=========================================================
 // To string functions
@@ -385,7 +385,7 @@ template <typename T> void complexValueToString (const typename T::Value& val, s
  */
 template<typename SimpleValueType, typename ItemType, PropertyType ItemPType>
 inline SimpleValueType
-getSimpleValueFromArray (const boost::shared_ptr<CArray>& array, size_t position)__attribute__((deprecated));
+getSimpleValueFromArray (const boost::shared_ptr<CArray>& array, size_t position) DEPRECATED;
 
 // gcc doesn't like __attribute__ in function definition
 template<typename SimpleValueType, typename ItemType, PropertyType ItemPType>
@@ -424,7 +424,7 @@ getSimpleValueFromArray (const boost::shared_ptr<CArray>& array, size_t position
 /** \copydoc getSimpleValueFromArray */
 template<typename SimpleValueType, typename ItemType, PropertyType ItemPType>
 inline SimpleValueType
-getSimpleValueFromArray (const boost::shared_ptr<IProperty>& array, size_t position)__attribute__((deprecated));
+getSimpleValueFromArray (const boost::shared_ptr<IProperty>& array, size_t position) DEPRECATED;
 	
 // gcc doesn't like __attribute__ in function definition
 template<typename SimpleValueType, typename ItemType, PropertyType ItemPType>
@@ -515,7 +515,7 @@ getRefFromArray (const IP& ip, size_t position)
  */
 template<typename Value, typename ItemType, PropertyType ItemPType>
 inline void
-setSimpleValueInArray (const CArray& array, size_t position, const Value& val)__attribute__((deprecated));
+setSimpleValueInArray (const CArray& array, size_t position, const Value& val) DEPRECATED;
 
 // gcc doesn't like __attribute__ in function definition
 template<typename Value, typename ItemType, PropertyType ItemPType>
@@ -558,7 +558,7 @@ setSimpleValueInArray (const CArray& array, size_t position, const typename Item
 /** \copydoc setSimpleValueInArray */
 template<typename Value, typename ItemType, PropertyType ItemPType>
 inline void
-setSimpleValueInArray (const IProperty& array, size_t position, const Value& val)__attribute__((deprecated));
+setSimpleValueInArray (const IProperty& array, size_t position, const Value& val) DEPRECATED;
 	
 // gcc doesn't like __attribute__ in function definition
 template<typename Value, typename ItemType, PropertyType ItemPType>
@@ -634,7 +634,7 @@ setDoubleInArray (const IP& ip, size_t position, double val)
  */
 template<typename ItemType, PropertyType ItemPType>
 inline boost::shared_ptr<ItemType>
-getTypeFromArray (const boost::shared_ptr<CArray>& array, size_t pos)__attribute__((deprecated));
+getTypeFromArray (const boost::shared_ptr<CArray>& array, size_t pos) DEPRECATED;
 
 // gcc doesn't like __attribute__ in function definition
 template<typename ItemType, PropertyType ItemPType>
@@ -695,7 +695,7 @@ getTypeFromArray (const boost::shared_ptr<CArray>& array, size_t pos)
 /** \copydoc getTypeFromArray */
 template<typename ItemType, PropertyType ItemPType>
 inline boost::shared_ptr<ItemType>
-getTypeFromArray (const boost::shared_ptr<IProperty>& array, size_t pos)__attribute__((deprecated));
+getTypeFromArray (const boost::shared_ptr<IProperty>& array, size_t pos) DEPRECATED;
 
 // gcc doesn't like __attribute__ in function definition
 template<typename ItemType, PropertyType ItemPType>
