@@ -32,6 +32,7 @@
 #include "kernel/pdfoperators.h"
 #include "kernel/stateupdater.h"
 #include "kernel/cobject.h"
+#include "kernel/cstreamsxpdfreader.h"
 #include "kernel/cinlineimage.h"
 #include "kernel/contentschangetag.h"
 #include "kernel/pdfoperatorsiter.h"
@@ -112,32 +113,30 @@ namespace {
 		dict.initDict ((XRef*)NULL); // We do not have (need) valid xref, but be CAREFUL
 
 		// Get first object
-		Object o;
-		streamreader.getXpdfObject (o);
+		boost::shared_ptr< ::Object> o(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
+		streamreader.getXpdfObject (*o);
 
 		//
 		// Get the inline image dictionary
 		// 
-		while (!streamreader.eof() && !o.isCmd("ID")) 
+		while (!streamreader.eof() && !o->isCmd("ID")) 
 		{
-			if (o.isName())
+			if (o->isName())
 			{
-				char* key = ::copyString (o.getName());
-				streamreader.getXpdfObject (o);
+				char* key = ::copyString (o->getName());
+				streamreader.getXpdfObject (*o);
 				if (streamreader.eof()) 
 				{
 					gfree (key);
 					assert (!"Bad inline image.");
 					throw CObjInvalidObject ();
 				}
-				dict.dictAdd (key, &o);
+				dict.dictAdd (key, o.get());
 			
 			}
 			
-			streamreader.getXpdfObject (o);
+			streamreader.getXpdfObject (*o);
 		}
-		// Free ID
-		o.free ();
 
 		// Bad content stream
 		if (streamreader.eof())
@@ -188,7 +187,7 @@ namespace {
 	bool
 	createOperandsFromStream (CStreamsXpdfReader<CContentStream::CStreams>& streamreader, 
 					PdfOperator::Operands& operands,
-					xpdf::XpdfObject& o)
+					boost::shared_ptr< ::Object>& o)
 	{
 		// Get first object
 		streamreader.getXpdfObject (*o);
@@ -229,7 +228,7 @@ namespace {
 					PdfOperator::Operands& operands)
 	{
 		// Get operands
-		xpdf::XpdfObject o;
+		boost::shared_ptr< ::Object> o(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
 		if (!createOperandsFromStream (streamreader, operands, o))
 			return shared_ptr<PdfOperator> ();
 		
@@ -248,7 +247,7 @@ namespace {
 			}
 			
 			shared_ptr<CInlineImage> inimg (getInlineImage (streamreader));
-			return shared_ptr<PdfOperator> (new InlineImageCompositePdfOperator (chcktp->name, chcktp->endTag, inimg));
+			return shared_ptr<PdfOperator> (new InlineImageCompositePdfOperator (inimg, chcktp->name, chcktp->endTag));
 		}
 
 		// factory function for all other operators
@@ -405,7 +404,7 @@ namespace {
 					{
 						if (our_change)
 							break;
-						xpdf::XpdfObject o;
+						boost::shared_ptr< ::Object> o(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
 						streamreader.lookXpdfObject (*o);
 						if (o->isName (ContentsChangeTag::CHANGE_TAG_ID))
 							break;
@@ -597,7 +596,7 @@ CContentStream::CContentStream (CStreams& strs,
 	// Create operand observer
 	operandobserver = boost::shared_ptr<OperandObserver> (new OperandObserver (this));
 	
-	// Parse it, move parsed straems from strs to cstreams
+	// Parse it, move parsed streams from strs to cstreams
 	parse (operators, strs, *this, operandobserver, &cstreams);
 	
 	// Save bounding boxes
