@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,11 +29,7 @@
 // static includes
 #include "kernel/static.h"
 
-//
-#include "kernel/cobject.h"
-
-// PdfOperator and its iterators
-#include "kernel/pdfoperators.h"
+#include "kernel/pdfoperatorsbase.h"
 #include "kernel/pdfoperatorsiter.h"
 
 //==========================================================
@@ -43,10 +39,9 @@ namespace pdfobjects {
 //
 // Forward declaration
 //
-class IProperty;
-class CContentStream;	
+class CContentStream;
+class CStream;
 typedef observer::ObserverHandler<CContentStream> CContentStreamObserverSubject;
-typedef observer::IObserver<IProperty> IIPropertyObserver;
 
 //==========================================================
 // CContentStream
@@ -132,7 +127,7 @@ private:
 	 * has been modified in a way that this content stream no longer exists. It
 	 * depends on the position of this observer in cstream observer list.
 	 */
-	struct CStreamObserver : public IIPropertyObserver
+	struct CStreamObserver : public IPropertyObserver
 	{
 		//
 		// Constructor
@@ -159,12 +154,12 @@ private:
 	 *
 	 * If an operand is changed, save the stream notifying all observers.
 	 */
-	struct OperandObserver : public IIPropertyObserver
+	struct OperandObserver : public IPropertyObserver
 	{
 		//
 		// Constructor
 		//
-		OperandObserver (CContentStream* cc) : contentstream (cc)
+		OperandObserver (CContentStream* cc) : contentstream (cc), _locked(false)
 			{assert (cc);}
 		//
 		// Observer interface
@@ -172,6 +167,14 @@ private:
 		virtual void notify (boost::shared_ptr<IProperty> newValue, 
 							 boost::shared_ptr<const IProperty::ObserverContext>) const throw();
 		virtual priority_t getPriority() const throw ()	{return 0;}
+		//
+		//
+		//
+		/** lock notifying */
+		void lock() { _locked = true; }
+		/** unlock notifying */
+		void unlock() { _locked = false; }
+
 		//
 		// Destructor
 		//
@@ -179,6 +182,7 @@ private:
 
 	private:
 		CContentStream* contentstream;
+		bool _locked;
 	};
 
 	/** Observer observing underlying cstreams. */
@@ -459,6 +463,13 @@ public:
 		gfxres = res;
 	}
 
+	/** Returns resources used by this content stream.
+	 * @return Resources instance wrapped by shared pointer.
+	 */
+	boost::shared_ptr<GfxResources> getResources()const
+	{
+		return gfxres;
+	}
 
 	/**
 	 * Save content stream to underlying cstream(s) and notify all observers. 
@@ -484,6 +495,11 @@ public:
 	void setSmartPointer (boost::shared_ptr<CContentStream> ths)
 		{ assert (smart_this.expired()); smart_this = ths; }
 
+	/**
+	 * Replaces text in this content stream. Simple method implemented so far.
+	 */
+	void replaceText (const std::string& what, const std::string& with);
+
 
 private:
 	/**
@@ -529,8 +545,6 @@ public:
 };
 
 
-
-
 //==========================================================
 // Operator changing functions
 //==========================================================
