@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -96,14 +96,14 @@ public:
 	 * @param o		Xpdf object. 
 	 * @param rf	Indirect id and gen id.
 	 */
-	CDict (CPdf& p, Object& o, const IndiRef& rf);
+	CDict (boost::weak_ptr<CPdf> p, const Object& o, const IndiRef& rf);
 
 	/**
 	 * Constructor.
 	 *
 	 * @param o		Xpdf object. 
 	 */
-	CDict (Object& o);
+	CDict (const Object& o);
 
 
 public:	
@@ -162,7 +162,14 @@ public:
 	 */
 	virtual void getStringRepresentation (std::string& str) const;
 
-	
+
+	/**
+	 * Simple shallow copy constructor (does not copy pointers).
+	 *
+	 * @param dict dictionary which will be copied
+	 */
+	void init (const CDict& dict);
+
 	/** 
 	 * Returns property count.
 	 * 
@@ -225,7 +232,7 @@ public:
 	 * Set pdf to this object and its children.
 	 * @param pdf New pdf.
 	 */
-	virtual void setPdf (CPdf* pdf);
+	virtual void setPdf (boost::weak_ptr<CPdf> pdf);
 
 	/**
 	 * Set ref to this object and its children.
@@ -253,16 +260,14 @@ public:
 	 * the cloned object is added.
 	 * Indicate that this object has changed and return the pointer to the cloned object.
 	 *
-	 * @param newIp New property.
+	 * If a property with the same name is already in this dictionary an exception is thrown.
+	 *
+	 * @param propertyName property name
+	 * @param newIp new property
 	 * @return Pointer to the new property.
 	 *
 	 * \exception OutOfRange Thrown when property not found.
-	 */
-	boost::shared_ptr<IProperty> addProperty (const IProperty& newIp);
-	
-	/**
-	 * \copydoc addProperty
-	 * @param propertyName 	Name of the created property.
+	 * \exception CObjInvalid When the object is invalid
 	 */
 	boost::shared_ptr<IProperty> addProperty (const std::string& propertyName, const IProperty& newIp);
 
@@ -428,7 +433,7 @@ namespace utils {
  * @param obj	Xpdf object which holds the value.
  * @param val	Variable where the value will be stored.
  */
-template <PropertyType Tp,typename T> void complexValueFromXpdfObj (IProperty& ip, ::Object& obj, T val);
+template <PropertyType Tp,typename T> void complexValueFromXpdfObj (IProperty& ip, const ::Object& obj, T val);
 
 /**
  * This function is a slower equivalent to complexValueFromXpdfObj. But on the
@@ -457,25 +462,82 @@ void dictFromXpdfObj (CDict& resultDict, ::Object& dict);
  */
 size_t stringToCharBuffer(Object & stringObject, CharBuffer & outputBuf);
 
+/** Helper function which returns data from given stream.
+ * @param str Stream to read (until it returns EOF).
+ * @param dictLength Initial size reported by the stream dictionary.
+ * @param size Output size of the buffer.
+ *
+ * This is low-level function which simply reads given stream from its 
+ * beginning until EOF. It can be used to retrieve data from whatever
+ * Stream filter stack layer. E.g. if we want to get encoded data we
+ * can simply give stream->getBaseStream() as parameter and this function
+ * will return buffer as it is written in the file.
+ *
+ * @return Buffer with stream data (size will contain number of bytes
+ * stored) or NULL on error.
+ */
+unsigned char* bufferFromStream(Stream& str, size_t dictLength, size_t& size);
+
+/** Helper function for removing filters from the given stream object.
+ * @param obj Stream object.
+ * @param size Size of returned buffer.
+ * @return Buffer with raw stream data or NULL on error.
+ *
+ * If the given obj used some filters, they are all decoded to get orignal
+ * data and the stream dictionary is updated so that it doesn't contain
+ * any filters. 
+ * <br>
+ * Stream object stored in the given obj is not touched (because it doesn't
+ * give much sense - it returns decoded data anyway, it doesn't use dictionary
+ * to find out how to decode). Nevertheless this operation may be considered 
+ * harmfull for later usage of given the object in the xpdf code paths!
+ */
+unsigned char* convertStreamToDecodedData (const Object& obj, size_t& size);
+
+/** Function to be used for data extracting from the given stream object.
+ * Note that implementation can apply additional filters to the stream
+ * data currently stored in the obj.stream and update object accordingly
+ * (change Filter and associated entry). Length entry doesn't have to 
+ * be changed by the implementation as it is supposed to be updated by 
+ * caller (because we want to prevent useless object updating when a
+ * chain of this function is called for multiple filters).
+ * <br>
+ * Function is called from the streamToCharBuffer function to have transparent
+ * access to the stream data without any knowledge about filters.
+ * bufferFromStreamData is the referencial implementation which provides
+ * encoded data without any filters applied (all other implementations
+ * can use this function as the base and convert returned buffer into
+ * their represenation).
+ *
+ * @param Stream object.
+ * @param size Number of bytes written to the returned buffer.
+ * @return Buffer (size bytes) with data (must be deallocated by caller) or 
+ * NULL on error.
+ */
+typedef unsigned char* (*stream_data_extractor)(const Object& obj, size_t& size);
+
 /** Makes a valid pdf indirect object representation of stream object.
  * @param streamObject Xpdf object representing stream.
  * @param ref Reference for this indirect object.
  * @param outputBuf Output byte buffer containing complete representation.
- * @param asIndirect Flag for indirect output.
+ * @param extractor Function to be used to extract data from the object's 
+ * 	stream.
  *
- * Allocates and fill buffer in given outputBuf with pdf object format
+ * Allocates and fills buffer in given outputBuf with pdf object format
  * representation of given stream object. Moreover adds indirect header and
- * footer if asIndirect parameter is true. 
+ * footer if ref is non NULL. 
+ * <br>
+ * If you want some filters to be used to encode stream data, use extractor
+ * function parameter for this purpose. bufferFromStreamData used by default
+ * returns stream data without any filters applied.
  * <br>
  * Given buffer may contain NUL bytes inside. Caller should consume number of
  * returned bytes from outputBuf.
- * <br>
- * Reference parameter is ignored if asIndirect is false, because it is used
- * only for indirect object header.
  * 
  * @return number of bytes used in outputBuf or 0 if problem occures.
  */
-size_t streamToCharBuffer (Object & streamObject, Ref ref, CharBuffer & outputBuf, bool asIndirect=true);
+size_t streamToCharBuffer (const Object & streamObject, Ref* ref, CharBuffer & outputBuf, 
+		stream_data_extractor extractor);
 	
 /**
  * Convert xpdf object to string
@@ -521,7 +583,7 @@ void getStringFromXpdfStream (std::string& str, ::Object& obj);
  */
 template<typename SimpleValueType, typename ItemType, PropertyType ItemPType>
 inline SimpleValueType
-getSimpleValueFromDict (const boost::shared_ptr<CDict>& dict, const std::string& id)__attribute__((deprecated));
+getSimpleValueFromDict (const boost::shared_ptr<CDict>& dict, const std::string& id) DONOTUSE;
 
 /** \copydoc getSimpleValueFromDict */
 template<typename SimpleValueType, typename ItemType, PropertyType ItemPType>
@@ -560,7 +622,7 @@ getSimpleValueFromDict (const boost::shared_ptr<CDict>& dict, CDict::PropertyId
 /** \copydoc getSimpleValueFromDict */
 template<typename SimpleValueType, typename ItemType, PropertyType ItemPType>
 inline SimpleValueType
-getSimpleValueFromDict (const CDict& dict, const std::string& id)__attribute__((deprecated));
+getSimpleValueFromDict (const CDict& dict, const std::string& id) DONOTUSE;
 
 template<typename SimpleValueType, typename ItemType, PropertyType ItemPType>
 inline SimpleValueType
@@ -591,7 +653,7 @@ getSimpleValueFromDict (const CDict& dict, const std::string& id)
 /** \copydoc getSimpleValueFromDict */
 template<typename SimpleValueType, typename ItemType, PropertyType ItemPType>
 inline SimpleValueType
-getSimpleValueFromDict (const boost::shared_ptr<IProperty>& dict, const std::string& id)__attribute__((deprecated));
+getSimpleValueFromDict (const boost::shared_ptr<IProperty>& dict, const std::string& id) DONOTUSE;
 	
 template<typename SimpleValueType, typename ItemType, PropertyType ItemPType>
 inline SimpleValueType
@@ -678,7 +740,7 @@ getNameFromDict (const IP& ip, const std::string& id)
  */
 template<typename Value, typename ItemType, PropertyType ItemPType>
 inline void
-setSimpleValueInDict (const CDict& dict, const std::string& name, const Value& val)__attribute__((deprecated));
+setSimpleValueInDict (const CDict& dict, const std::string& name, const Value& val) DONOTUSE;
 
 template<typename Value, typename ItemType, PropertyType ItemPType>
 inline void
@@ -723,7 +785,7 @@ setSimpleValueInDict (const CDict& dict, CDict::PropertyId name, const typename
 /** \copydoc setSimpleValueInDict */
 template<typename Value, typename ItemType, PropertyType ItemPType>
 inline void
-setSimpleValueInDict (const IProperty& dict, const std::string& name, const Value& val)__attribute__((deprecated));
+setSimpleValueInDict (const IProperty& dict, const std::string& name, const Value& val) DONOTUSE;
 	
 template<typename Value, typename ItemType, PropertyType ItemPType>
 inline void
@@ -790,7 +852,7 @@ setDoubleInDict (const IP& ip, const std::string& name, double val)
  */
 template<typename ItemType, PropertyType ItemPType>
 inline boost::shared_ptr<ItemType>
-getTypeFromDictionary (const boost::shared_ptr<CDict>& dict, const std::string& key)__attribute__((deprecated));
+getTypeFromDictionary (const boost::shared_ptr<CDict>& dict, const std::string& key) DONOTUSE;
 
 template<typename ItemType, PropertyType ItemPType>
 inline boost::shared_ptr<ItemType>
@@ -858,7 +920,7 @@ getTypeFromDictionary (const boost::shared_ptr<CDict>& dict, CDict::PropertyId k
 /** \copydoc getTypeFromDictionary */
 template<typename ItemType, PropertyType ItemPType>
 inline boost::shared_ptr<ItemType>
-getTypeFromDictionary (const boost::shared_ptr<IProperty>& dict, const std::string& key)__attribute__((deprecated));
+getTypeFromDictionary (const boost::shared_ptr<IProperty>& dict, const std::string& key) DONOTUSE;
 
 template<typename ItemType, PropertyType ItemPType>
 inline boost::shared_ptr<ItemType>
