@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -100,17 +100,28 @@ CInlineImage::CInlineImage (::Object& oDict, const CStream::Buffer& buf) : CStre
 //
 //
 //
-CInlineImage::CInlineImage (CPdf& p, ::Object& oDict, const CStream::Buffer& buf, const IndiRef& rf) : CStream ()
+CInlineImage::CInlineImage (const CDict& dict, const CStream::Buffer& buf) : CStream (dict)
 {
 	kernelPrintDbg (debug::DBG_DBG, "");
-	assert (objDict == oDict.getType());
+
+	// Set buffer, do not use setRawBuffer because CStream would be ... copied
+	std::copy (buf.begin(), buf.end(), std::back_inserter (this->buffer));
+}
+
+//
+//
+//
+CInlineImage::CInlineImage (boost::weak_ptr<CPdf> p, ::Object& oDict, const CStream::Buffer& buf, const IndiRef& rf) : CStream ()
+{
+	kernelPrintDbg (debug::DBG_DBG, "");
+		assert (objDict == oDict.getType());
 
 	// Init dictionary, we do not have access to dictionary container
 	utils::dictFromXpdfObj (this->dictionary, oDict);
 	assert (0 < this->dictionary.getPropertyCount ());
 	
 	// Set pdf and ref
-	setPdf (&p);
+	setPdf (p);
 	setIndiRef (rf);
 	
 	// Set buffer, do not use setRawBuffer because CStream would be ... copied
