@@ -51,10 +51,4 @@
 //=====================================================================================
 #include "kernel/cstream.h"
 
-//=====================================================================================
-// CStreamsXpdfReader
-//=====================================================================================
-#include "kernel/cstreamsxpdfreader.h"
-
-
 #endif // _COBJECT_H
