@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -125,7 +125,9 @@ boost::shared_ptr<CDict> getDictFromRef(boost::shared_ptr<IProperty> refProp)
 	// gets reference value and dereferences indirect object
 	IndiRef ref;
 	IProperty::getSmartCObjectPtr<CRef>(refProp)->getValue(ref);
-	boost::shared_ptr<IProperty> indirect_ptr=refProp->getPdf()->getIndirectProperty(ref);
+	shared_ptr<CPdf> pdf = refProp->getPdf().lock();
+	assert(pdf);
+	boost::shared_ptr<IProperty> indirect_ptr=pdf->getIndirectProperty(ref);
 	if(indirect_ptr->getType() != pDict)
 		throw ElementBadTypeException("");
 	return IProperty::getSmartCObjectPtr<CDict>(indirect_ptr);
@@ -235,7 +237,9 @@ getReferencedObject (boost::shared_ptr<IProperty> ip)
 
 			IndiRef ref;
 			IProperty::getSmartCObjectPtr<CRef>(ip)->getValue(ref);
-			return ip->getPdf()->getIndirectProperty (ref);
+			shared_ptr<CPdf> pdf = ip->getPdf().lock();
+			assert(pdf);
+			return pdf->getIndirectProperty (ref);
 
 		}else
 			return ip;
@@ -263,6 +267,21 @@ using namespace boost;
 	return array;
 }
 
+void getRectangleFromProperty(const shared_ptr<IProperty> prop, libs::Rectangle & rect)
+{
+	if(!isArray(prop))
+		throw CObjBadValue();
+	
+	shared_ptr<CArray> array = IProperty::getSmartCObjectPtr<CArray>(prop);
+	if(array->getPropertyCount() != 4)
+		throw CObjBadValue();
+
+	rect.xleft = getDoubleFromArray(array, 0);
+	rect.yleft = getDoubleFromArray(array, 1);
+	rect.xright = getDoubleFromArray(array, 2);
+	rect.yright = getDoubleFromArray(array, 3);
+}
+
 boost::shared_ptr<IProperty> getIPropertyFromDate(const tm * time)
 {
 using namespace boost;
@@ -305,7 +324,12 @@ using namespace boost;
 //
 ::XRef*
 getXRef (shared_ptr<IProperty> ip)
- { return (ip->getPdf() == NULL) ? NULL : ip->getPdf()->getCXref(); }
+{
+	shared_ptr<CPdf> pdf = ip->getPdf().lock();
+	if(!pdf)
+		return NULL;
+	return pdf->getCXref(); 
+}
 
 
  
