@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,7 +42,7 @@ namespace pdfobjects {
 // Protected constructor, called when we have parsed an object
 //
 template<PropertyType Tp>
-CObjectSimple<Tp>::CObjectSimple (CPdf& p, Object& o, const IndiRef& rf) : IProperty (&p,rf), value(Value())
+CObjectSimple<Tp>::CObjectSimple (boost::weak_ptr<CPdf> p, const Object& o, const IndiRef& rf) : IProperty (p,rf), value(Value())
 {
 	//kernelPrintDbg (debug::DBG_DBG,"CObjectSimple <" << debug::getStringType<Tp>() << ">(p,o,rf) constructor.");
 	
@@ -55,7 +55,7 @@ CObjectSimple<Tp>::CObjectSimple (CPdf& p, Object& o, const IndiRef& rf) : IProp
 // Protected constructor, called when we have parsed an object
 //
 template<PropertyType Tp>
-CObjectSimple<Tp>::CObjectSimple (Object& o) : value(Value())
+CObjectSimple<Tp>::CObjectSimple (const Object& o) : value(Value())
 {
 	//kernelPrintDbg (debug::DBG_DBG,"CObjectSimple <" << debug::getStringType<Tp>() << ">(o) constructor.");
 	
