@@ -27,12 +27,14 @@
 #include "kernel/static.h"
 
 #include "kernel/cpagecontents.h"
+#include "kernel/factories.h"
 #include "utils/observer.h"
 #include "kernel/cobject.h"
 #include "kernel/cpage.h"
 #include "kernel/cpdf.h"
 #include "kernel/cpagedisplay.h"
 #include "kernel/contentschangetag.h"
+#include "kernel/cinlineimage.h"
 
 //==========================================================
 namespace pdfobjects {
@@ -458,6 +460,106 @@ CPageContents::replaceText (const std::string& what, const std::string& with)
 		(*it)->replaceText (what, with);
 }
 
+//
+//
+//
+void 
+CPageContents::addText (const std::string& what, 
+						const libs::Point& where,
+						const std::string& font_id)
+{
+	init();
+
+	// create the array of PDF operators and add them to back of content streams
+	// q
+	// BT
+	// rg col
+	// fname fsize Tf
+	// x y Td
+	// text Tj
+	// ET
+	// Q
+	//
+	std::string fontName (font_id);
+	if (fontName.empty())
+		fontName = "PDFEDIT_F1";
+    double fontSize = 15.0;
+    shared_ptr<UnknownCompositePdfOperator> q(new UnknownCompositePdfOperator("q", "Q"));
+    shared_ptr<UnknownCompositePdfOperator> BT(new UnknownCompositePdfOperator("BT", "ET"));
+    PdfOperator::Operands fontOperands;
+    fontOperands.push_back(shared_ptr<IProperty>(new CName (fontName)) );
+    fontOperands.push_back(shared_ptr<IProperty>(new CReal (fontSize)));
+    q->push_back(BT,q);
+    BT->push_back(createOperator("Tf", fontOperands), getLastOperator(BT));
+    
+	_likely_tm.set_position(where);
+	PdfOperator::Operands posOperands = _likely_tm;
+    BT->push_back(createOperator("Tm", posOperands), getLastOperator(BT));
+
+    PdfOperator::Operands textOperands;
+    textOperands.push_back(shared_ptr<IProperty>(new CString (what)));
+    BT->push_back(createOperator("Tj", textOperands), getLastOperator(BT));
+    PdfOperator::Operands emptyOperands;
+    BT->push_back(createOperator("ET", emptyOperands), getLastOperator(BT));
+    q->push_back(createOperator("Q", emptyOperands), getLastOperator(q));
+    
+	std::vector<shared_ptr<PdfOperator> > contents;
+    contents.push_back(q);
+    
+	addToBack (contents);
+}
+
+void 
+CPageContents::addInlineImage (const CStream::Buffer& what,
+							   const libs::Point& image_size,
+							   const libs::Point& where)
+{
+	init();
+
+	// create the array of PDF operators and add them to back of content streams
+	// q
+	// BI % Begin inline image object
+	// /W 17 % Width in samples
+	// /H 17 % Height in samples
+	// /CS /RGB % Color space
+	// /BPC 8 % Bits per component
+	// /F [/A85 /LZW] % Filters
+	// ID % Begin image data
+	// J1/gKA>.]AN&J?]-<HW]aRVcg*bb.\eKAdVV%/PcZ
+	// Omitted data
+	// R.s(4KE3&d&7hb*7[%Ct2HCqC~>
+	// EI
+	// Q
+	//
+    shared_ptr<UnknownCompositePdfOperator> q(new UnknownCompositePdfOperator("q", "Q"));
+
+	// translate
+	q->push_back(createOperatorTranslation(where.x, where.y), getLastOperator(q));
+	// scale
+	q->push_back(createOperatorScale(image_size.x, image_size.y), getLastOperator(q));
+
+
+	CDict image_dict;
+	image_dict.addProperty ("W", CInt (image_size.x));
+	image_dict.addProperty ("H", CInt (image_size.y));
+	image_dict.addProperty ("CS", CName ("RGB"));
+	image_dict.addProperty ("BPC", CInt (8));
+	CInlineImage img (image_dict, what);
+	shared_ptr<CInlineImage> inline_image (new CInlineImage (image_dict, what));
+	shared_ptr<InlineImageCompositePdfOperator> BI(new InlineImageCompositePdfOperator (inline_image));
+    
+	q->push_back(BI,getLastOperator(q));
+	PdfOperator::Operands o;
+    q->push_back(createOperator("Q", o), getLastOperator(q));
+    
+	std::vector<shared_ptr<PdfOperator> > contents;
+    contents.push_back(q);
+    
+	addToBack (contents);
+}
+
+
+
 
 //==========================================================
 namespace {
@@ -758,6 +860,34 @@ CPageContents::parse ()
 		_ccs.push_back (cc);
 	}
 
+	// uff, go through the first content operators and find out usefull information
+	// - for now the text orientation
+	// - pdfoperators will be reimplemented anyway
+	for (CCs::const_iterator it = _ccs.begin(); 
+			it != _ccs.end(); 
+			++it)
+	{
+		CContentStream::Operators ops;
+		(*it)->getPdfOperators (ops);
+		if (ops.empty())
+			continue;
+		PdfOperator::Iterator opit = PdfOperator::getIterator (ops.front());
+		while (!opit.isEnd())
+		{
+			std::string tmp;
+			opit.getCurrent()->getOperatorName (tmp);
+			PdfOperator::Operands operands;
+			if (tmp == "Tm")
+			{
+					kernelPrintDbg (debug::DBG_WARN, "Using non default different Tm");
+				opit.getCurrent()->getParameters (operands);
+				_likely_tm = operands;
+			}
+			opit.next();
+		}
+	}
+
+
 
 	// Indicate change
 	change ();
