@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,22 +27,29 @@
 #define __CPDF_H__
 
 #include "kernel/static.h"
-
-#include <inttypes.h>
-
-// xpdf
-#include "kernel/xpdf.h"
-
-// mode controller
-#include "kernel/modecontroller.h"
-#include "kernel/cobject.h"
+#include "kernel/cobjecthelpers.h"
 #include "kernel/xrefwriter.h"
+#include "kernel/modecontroller.h"
+#include "kernel/iproperty.h"
+#include "kernel/cstream.h"
+
+class StreamWriter;
 
 // =============================================================================
 namespace pdfobjects {
 
+class IProperty;
+class CDict;
+class CXref;
+class CPage;
+template<typename IP> inline boost::shared_ptr<CDict> getCDictFromDict (IP& ip, const std::string& key);
+
 namespace utils {
 
+template<typename Container> void getAllChildrenOfPdfObject (boost::shared_ptr<CDict> topdict, Container& cont);
+
+class IPdfWriter;
+
 /**
  * Indirect referencies comparator.
  *
@@ -73,9 +80,6 @@ public:
 
 } // namespace utils
 
-class CPage;
-//class COutline;
-
 	
 /** Type for page tree node count chache.
  * It is mapping where key is indirect reference of page tree node and
@@ -127,7 +131,7 @@ typedef std::map<IndiRef, ResolvedRefEntry*, utils::IndComparator > ResolvedRefS
 /**
  * Indirect properties mapping type.
  */
-typedef std::map<IndiRef, boost::shared_ptr<IProperty>, utils::IndComparator> IndirectMapping;
+typedef std::map<const IndiRef, boost::shared_ptr<IProperty>, utils::IndComparator> IndirectMapping;
 
 /** Type for pdf identificator.
  */
@@ -151,8 +155,10 @@ typedef std::map<cpdf_id_t, ResolvedRefStorage *> ResolvedRefMapping;
  * <b>Instancing</b><br>
  * Public constructor is not available and instances can be created on by 
  * static factory getInstance method. Also no public destructor is available 
- * and instance can be destroyed only by close method. This implies that
- * instance can be used only as pointer or reference.
+ * because instance returned by getInstance methods is wrapped by shared_ptr
+ * smart pointer which keeps instance alive until reference to the pointer
+ * exists (this is based on reference counting scheme - see smart_ptr 
+ * documentation for more information).
  * 
  * <p>
  * <b>Open mode</b><br>
@@ -212,17 +218,16 @@ typedef std::map<cpdf_id_t, ResolvedRefStorage *> ResolvedRefMapping;
  * Pages are counted from 1 (first page) up to getPageCount return value. Note
  * that this may not represent values used for inner page counting writen on the
  * page. CPdf doesn't handle any kind of special document numbering.
- *
  * <p>
  * <b>Revision manipulation</b><br>
  * CPdf provides interface also for document revision handling done in XRefWriter
- * class. Actual revision number (the newest revision has 0 number and grows to
- * older revisions) can be obtained by getActualRevision method. Current
- * revision can be changed by changeRevision method. As a result, just object
- * included until current revisions are available. Also no changes can be done
- * if revision is not the newest one, because PDF document doesn't support
- * revision branching. All these operations are just delegated (after som 
- * checks) to XRefWriter.
+ * class. Actual revision number (the newest revision has the highest number and 
+ * gets smaller towards the older revisions with the 0 used for the oldest one) 
+ * can be obtained by getActualRevision method. Current revision can be changed 
+ * by changeRevision method. As a result, just objects included until the current 
+ * revisions are available. Also no changes can be done if revision is not the 
+ * newest one, because PDF document doesn't support revision branching. 
+ * All these operations are just delegated (after som checks) to XRefWriter.
  * <br>
  * All internal data structures which may depend on current revision are
  * intialized and cleaned up in initRevisionSpecific method.
@@ -243,8 +248,8 @@ typedef std::map<cpdf_id_t, ResolvedRefStorage *> ResolvedRefMapping;
  * @see save(bool).
  * 
  * Different way of page content storing is so called document clonig done by
- * clone method. This method stores document content of current revision. This
- * enables to nake snapshot of document of arbitrary revision to separate
+ * clone method. This method stores document content up to current revision. This
+ * enables to make snapshot of document of arbitrary revision to separate
  * document and this document (as it has that revision as the newest one)
  * enables making changes.
  * 
@@ -258,7 +263,7 @@ typedef std::map<cpdf_id_t, ResolvedRefStorage *> ResolvedRefMapping;
  * method.
  *
  */
-class CPdf
+class CPdf: public noncopyable
 {
 public:
 	// NOTE: this declaration has to be here, because mode field is private and
@@ -643,7 +648,7 @@ protected:
 	 *
 	 * @return true if tree consolidation kept pages count, false otherwise.
 	 */
-	bool consolidatePageTree(boost::shared_ptr<CDict> & interNode, bool propagate=false);
+	bool consolidatePageTree(const boost::shared_ptr<CDict> & interNode, bool propagate=false);
 	
 	/** Consolidates pageList after change in Page tree.
 	 * @param oldValue Old reference (CNull if no previous state).
@@ -651,7 +656,7 @@ protected:
 	 *
 	 * Removes all CPages, which are in old reference sub tree (if oldValue is 
 	 * not CNull - what means that new element to Kids array has been added) 
-	 * from pageList and invalidates them. Uses isDescendant method for each 
+	 * from pageList and invalidates them. Uses isNodeDescendant method for each 
 	 * page from pageList to find out if it is in sub tree.
 	 * <br>
 	 * Also calculates difference between lost pages and newly added pages (each
@@ -701,7 +706,7 @@ protected:
 	 * but on the same position. It is not possible that these values could be 
 	 * on different positions (this would cause page numbering problem).
 	 */
-	void consolidatePageList(boost::shared_ptr<IProperty> & oldValue, boost::shared_ptr<IProperty> & newValue);
+	void consolidatePageList(const boost::shared_ptr<IProperty> & oldValue, const boost::shared_ptr<IProperty> & newValue);
 
 	/** Registers definitive value of property to the xref.
 	 * @param ip Property to be used.
@@ -714,7 +719,7 @@ protected:
 	 * 
 	 * @return Reserved reference to changed object.
 	 */
-	IndiRef registerIndirectProperty(boost::shared_ptr<IProperty> ip, IndiRef &ref);
+	IndiRef registerIndirectProperty(const boost::shared_ptr<IProperty> &ip, IndiRef &ref);
 	
 	/** Registers page tree observers.
 	 * @param prop Page tree node reference or dictionary.
@@ -746,7 +751,7 @@ protected:
 	 * <br>
 	 * This method should be called with clenaup flag set to false when 
 	 * node is removed from the tree and set to true when clean up for CPdf
-	 * is done (e.g. when document closed).
+	 * is done (e.g. when document about to be destroyed).
 	 * <br>
 	 * NOTE: If position of given node is ambiguous, unregistration is skipped,
 	 * because node is still in the tree.
@@ -778,7 +783,7 @@ protected:
 	 * @see subsReferencies
 	 * @return reference of added property.
 	 */
-	IndiRef addProperty(boost::shared_ptr<IProperty> ip, IndiRef &indiRef, 
+	IndiRef addProperty(const boost::shared_ptr<IProperty> &ip, IndiRef &indiRef, 
 			ResolvedRefStorage & storage, bool followRefs);
 
 	/** Substitues reference(s) with valid in this pdf.
@@ -826,16 +831,8 @@ protected:
 	 * @return invalid reference if no substitution has to be done or reference
 	 * which should be used instead (use isRefValid for checking).
 	 */
-	IndiRef subsReferencies(boost::shared_ptr<IProperty> ip, ResolvedRefStorage & container, bool followRefs);
+	IndiRef subsReferencies(const boost::shared_ptr<IProperty> &ip, ResolvedRefStorage & container, bool followRefs);
 private:
-
-	/** File handle for document.
-	 * Initialized in getInstance and may be used *ONLY* in close method (to 
-	 * close). All other operations must be done on top of stream object 
-	 * which wrapps file handle.
-	 */
-	FILE * file;
-	
 	/** Identificator for this pdf instance.
 	 */
 	cpdf_id_t id;
@@ -862,22 +859,8 @@ private:
 	 * with same reference has to share value and this is guarantied by this 
 	 * mapping.
 	 */
-	IndirectMapping indMap;
+	mutable IndirectMapping indMap;
 
-	/** Trailer dictionary for this revision.
-	 *
-	 * This dictionary contains all information for current revision. When
-	 * revision is changed this has to be initialized before
-	 * initRevisionSpecific method is called. First initialization is done in
-	 * constructor.
-	 * <br>
-	 * Trailer is direct object so it can't be obtained through
-	 * getIndirectProperty method. Only way how to do change, add or delete its
-	 * members (which is strongly unrecomended unless you know what you are
-	 * doing) is to use XRefWriter interface.
-	 */
-	boost::shared_ptr<CDict> trailer;
-		
 	/** Document catalog dictionary.
 	 *
 	 * It is used for document property handling. Initialization is done by
@@ -959,11 +942,9 @@ private:
 
 	/** Intializes revision specific stuff.
 	 * 
-	 * Cleans up all internal structures which may depend on current discourage 
-	 * revision.
+	 * Cleans up all internal structures which may depend on the current revision.
 	 * This includes indirect mapping and pageList (all pages are invalidated).
-	 * After clean up is ready, initializes trailer field from Xref trailer xpdf
-	 * Object. docCatalog field is initialized same way.
+	 * After clean up is ready, initializes docCatalog field.
 	 * <br>
 	 * Finally registers pageTreeWatchDog observer. Uses
 	 * registerPageTreeObserver method with Pages reference as parameter.
@@ -1010,6 +991,11 @@ private:
 	 */
 	configuration::ModeController* modeController;
 
+	/** Weak reference to this instance for proper reference counting
+	 * with combination to published shared_ptr.
+	 */
+	boost::weak_ptr<CPdf> _this;
+
 	/** Empty constructor.
 	 *
 	 * This constructor is disabled, because we want to prevent uninitialized
@@ -1032,13 +1018,22 @@ private:
 	
 	/** Destructor.
 	 * 
-	 * It is no available outside class, because we whant to prevent
-	 * deleting instances without control.
-	 * <br>
-	 * Instance can be destryed by close method (which destroyes it
-	 * using this destructor).
+	 * It is not available outside the class, because we want to keep
+	 * absolute control over instance deleting. The instance is destroyed
+	 * after the its last reference to the smart pointer is released.
 	 */
 	~CPdf();
+
+	/** Helper method to cleanup all data structure before CPdf destroying.
+	 * This includes invalidating all pages from pageList (those returned 
+	 * by getPage), unregistering all observers, clearing all cached
+	 * indirect objects and cleaning up resolvedRefMapping.
+	 * <br>
+	 * Method has to be called before the object itself is deleted.
+	 */
+	void invalidate();
+
+ 	friend class PdfFileDeleter;
 public:
 	/** Factory method for CPdf instances.
 	 * @param filename File name with pdf content (if null, new document 
@@ -1051,7 +1046,7 @@ public:
 	 * @throw PdfOpenException if file open fails.
 	 * @return Initialized (and ready to be used) CPdf instance.
 	 */
-	static CPdf * getInstance(const char * filename, OpenMode mode);
+	static boost::shared_ptr<CPdf> getInstance(const char * filename, OpenMode mode);
 
 	/** Returns unique identificator for this pdf.
 	 *
@@ -1062,15 +1057,6 @@ public:
 		return id;
 	}
 	
-	/** Closes pdf file.
-	 * @param saveFlag Flag which determine whether to save before close
-	 *	(parameter may be omited and false is used by default).
-	 *
-	 * Destroyes CPdf instance in safe way. Instance MAY NOT be used
-	 * after this method is called.
-	 */
-	int close(bool saveFlag=false);
-
 	/** Returns pointer to cross reference table.
 	 *
 	 * This is pointer to CXref subtype of XRefWriter type field. It
@@ -1127,7 +1113,7 @@ public:
 	 * 
 	 * @return IProperty wrapped by shared_ptr smart pointer.
 	 */
-	boost::shared_ptr<IProperty> getIndirectProperty(IndiRef &ref);
+	boost::shared_ptr<IProperty> getIndirectProperty(const IndiRef &ref)const;
 
 	/** Adds new indirect object.
 	 * @param prop Original property.
@@ -1190,7 +1176,7 @@ public:
 	 * @return Reference of new property (see restriction when given
 	 * property is reference itself).
 	 */ 
-	IndiRef addIndirectProperty(boost::shared_ptr<IProperty> prop, bool followRefs=false);
+	IndiRef addIndirectProperty(const boost::shared_ptr<IProperty> &prop, bool followRefs=false);
 
 	/** Registers change of indirect property to the xref.
 	 * @param prop Indirect property.
@@ -1215,7 +1201,7 @@ public:
 	 * @throw ElementBadTypeException if XrefWriter is in paranoid mode and
 	 * paranoid check fails for new value.
 	 */
-	void changeIndirectProperty(boost::shared_ptr<IProperty> prop);
+	void changeIndirectProperty(const boost::shared_ptr<IProperty> &prop);
 	
 	/** Saves changes to pdf file.
 	 * @param newRevision Flag for new revision creation.
@@ -1225,7 +1211,7 @@ public:
 	 * For more implementation information @see XRefWriter
 	 *
 	 * <br>
-	 * Method will fail if actual revision is greater than 0.
+	 * Method will fail if the current revision is not the most recent one.
 	 * <p>
 	 * <b>Usage</b>
 	 * <ul>
@@ -1258,9 +1244,10 @@ public:
 	 * Stores actual document state to the given file.
 	 * Actual document state stands for all objects from all revistions until 
 	 * current one. This means that kind of fork of document is done. Be
-	 * careful, because actual changes are not considered (in revision 0),
-	 * because they are not really part of document (you have to save them as
-	 * new revision at first and than clone will contain also actual changes).
+	 * careful, because actual changes are not considered (in the most recent 
+	 * revision), because they are not really part of document (you have to 
+	 * save them as new revision at first and than clone will contain also 
+	 * actual changes).
 	 * <p>
 	 * <b>Usage</b>
 	 * <pre>
@@ -1290,6 +1277,7 @@ public:
 	 */
 	boost::shared_ptr<CDict> getDictionary()const
 	{
+		// TODO need credentials?
 		return docCatalog;
 	}
 
@@ -1300,28 +1288,36 @@ public:
 	 * @return Trailer dictionary wrapped by smart pointer (using shared_ptr
 	 * from boost library).
 	 */
-	boost::shared_ptr<const CDict> getTrailer()const
-	{
-		return trailer;
-	}
+	boost::shared_ptr<const CDict> getTrailer()const;
+
+	/** Changes/Adds given value associated with the given name to the trailer.
+	 * @param name Property name.
+	 * @param value Property value.
+	 * 
+	 * If a property with the given name already exists, its value will be
+	 * replaced by the given one (if it is safe to do so see XRefWriter::changeTrailer)
+	 * or simply add a new one entry to the trailer.
+	 * @throw ReadOnlyDocumentException if no changes can be done because actual
+	 * revision is not the newest one or if pdf is in read-only mode.
+	 * @throw NotImplementedException if document is encrypted or when trailer
+	 * dictionary can't be cloned (because clone method failes).
+	 * @throw ElementBadTypeException if the change is not allowed (either due to
+	 * type safety or that given entry cannot be changed).
+	 */
+	void changeTrailer(std::string &name, const boost::shared_ptr<IProperty> &value);
 		
-	/** Inserts exisitng page.
+	/** Inserts given page to the document.
 	 * @param page Page used for new page creation.
 	 * @param pos Position where to insert new page.
 	 *
-	 * Inserts deep copy of given page at given position. If position is
-	 * greater than page count, it is added after last page. Storing to 0
-	 * position is same as if pos parameter was 1. All pages behind pos
-	 * are renumbered.
+	 * If position is greater than page count, it is added after last page. 
+	 * Storing to 0 position is same as if pos parameter was 1. All pages 
+	 * behind pos are renumbered.
 	 * <br>
-	 * Method may fail if page at position is ambiguous. This means that 
-	 * it is not possible to get position of page reference in its parent Kids
-	 * array due to multiple occurance in Kids array. @see getNodePosition
-	 * 
-	 * <br>
-	 * Insertion never causes ambigues page tree, because deep copy of given
-	 * page is added as new indirect property and so it has different indirect
-	 * reference as original one.
+	 * Method may fail if page at position is ambiguous or given page is 
+	 * already stored in document. This means that it is not (or won't be) 
+	 * possible to get position of page reference in its parent Kids
+	 * array due to multiple occurance in Kids array. @see getNodePosition 
 	 * <br>
 	 * If given page comes from different valid (non NULL) pdf, some more tasks
 	 * are done comparing to normal property adding to page tree. At first
@@ -1332,15 +1328,16 @@ public:
 	 * all its Kids and also its own Parent and so on recursively). In further
 	 * step all inheritable page attributes are set (because original page may
 	 * not have contained them directly). Finally dictionary is added with
-	 * followRefs set to true (in addIndirectProperty method).
+	 * followRefs set to true (in addIndirectProperty method) so that all 
+	 * referenced objecs are deep-copied too.
 	 *
 	 * @throw ReadOnlyDocumentException if mode is set to ReadOnly or we are in
 	 * older revision (where no changes are allowed).
 	 * @throw AmbiguesPageTreeException if page can't be inserted to given
-	 * position because of ambiguous page tree.
+	 * position because of ambiguous page tree or page is already in the tree.
 	 * @throw NoPageRootException if no page tree root can be found.
 	 */
-	boost::shared_ptr<CPage> insertPage(boost::shared_ptr<CPage> page, size_t pos);
+	boost::shared_ptr<CPage> insertPage(const boost::shared_ptr<CPage> &page, size_t pos);
 
 	/** Removes page from given position.
 	 * @param pos Position of the page.
@@ -1376,7 +1373,7 @@ public:
 	 * @throw PageNotFoundException if given page is not recognized by CPdf
 	 * instance.
 	 */
-	size_t getPagePosition(boost::shared_ptr<CPage> page)const;
+	size_t getPagePosition(const boost::shared_ptr<CPage> &page)const;
 
 	/** Returnes total page count.
 	 *
@@ -1394,7 +1391,7 @@ public:
 	// =======================
 
 	/** Returns page at given position.
-	 * @param pos Position (starting from 0).
+	 * @param pos Position (starting from 1).
 	 *
 	 * At first tries to find page with given position in pageList. If found,
 	 * returns instance from list. Otherwise, searches page tree by findPageDict
@@ -1429,7 +1426,7 @@ public:
 	 * one or given page can't be found).
 	 * @return CPage instance wrapped by smart pointer.
 	 */ 
-	boost::shared_ptr<CPage> getNextPage(boost::shared_ptr<CPage> page)const;
+	boost::shared_ptr<CPage> getNextPage(const boost::shared_ptr<CPage> &page)const;
 
 	/** Returns previous page.
 	 * @param page Pointer to the page.
@@ -1443,49 +1440,27 @@ public:
 	 * one or given page can't be found).
 	 * @return CPage instance wrapped by smart pointer.
 	 */
-	boost::shared_ptr<CPage> getPrevPage(boost::shared_ptr<CPage> page)const;
+	boost::shared_ptr<CPage> getPrevPage(const boost::shared_ptr<CPage> &page)const;
 
 	/** Checks for next page.
 	 * @param page Page to check.
 	 *
 	 * @return true if getNextPage() method returns page and doesn't throw
 	 * PageNotFoundException, false otherwise. 
+	 * @throw PageNotFoundException if given page doesn't come from this CPdf
+	 * instance.
 	 */
-	bool hasNextPage(boost::shared_ptr<CPage> page)const
-	{
-		try
-		{
-			getNextPage(page);
-			// next page was successful
-			return true;
-		}catch(PageNotFoundException & e)
-		{
-			// nextPage failed
-			return false;
-		}
-		return true;
-	}
+	bool hasNextPage(const boost::shared_ptr<CPage> &page)const;
 	
 	/** Checks for previous page.
 	 * @param page Page to check.
 	 *
-	 * @return true if getPrevPage() method returnspage and doesn't throw
+	 * @return true if getPrevPage() method returns page and doesn't throw
 	 * PageNotFoundException. 
+	 * @throw PageNotFoundException if given page doesn't come from this CPdf
+	 * instance.
 	 */
-	bool hasPrevPage(boost::shared_ptr<CPage> page)const
-	{
-		try
-		{
-			getPrevPage(page);
-			// prev page was successful
-			return true;
-		}catch(PageNotFoundException & e)
-		{
-			// getPrevPage failed
-			return false;
-		}
-		return true;
-	}
+	bool hasPrevPage(const boost::shared_ptr<CPage> &page)const;
 
 	/** Returns last page.
 	 * 
@@ -1510,7 +1485,7 @@ public:
 	{
 		// mode is used only if we are in the newest revision, otherwise we are
 		// in ReadOnly
-		return (!xref->getActualRevision())?mode:ReadOnly;
+		return (utils::isLatestRevision(*xref))?mode:ReadOnly;
 	}
 
 	/** Checks whether this pdf is linearized.
@@ -1528,8 +1503,7 @@ public:
 	/** Revision type.
 	 * This is used to determine which revision should or is used.
 	 * It is only alias to unsigned number and 0 stands for the 
-	 * newest revision. An older revision has higher number than
-	 * newer one.
+	 * oldest revision and newer revisions have higher numbers.
 	 */
 	typedef unsigned revision_t;
 
@@ -1560,7 +1534,8 @@ public:
 	}
 
 	/** Changes revision to given one.
-	 * @param revisionNum Revision number (the newest is 0).
+	 * @param revisionNum Revision number (the oldest is 0, getRevisionCount()-1 
+	 * for the newest one).
 	 *
 	 * Delegates to xref field and reinitializes all internal structures
 	 * which are revision specific (calls initRevisionSpecific method).
@@ -1577,7 +1552,7 @@ public:
 	 *
 	 * @see XRefWriter::getRevisionCount
 	 */
-	size_t getRevisionsCount()
+	size_t getRevisionsCount()const
 	{
 		return xref->getRevisionCount();
 	}
@@ -1589,8 +1564,11 @@ public:
 	 * are visited.
 	 */
 	template<typename Container>
-	void getOutlines (Container& cont)
+	void getOutlines (Container& cont)const
 	{
+
+		check_need_credentials(xref);
+
 		// Clear outline container
 		cont.clear ();
 		
@@ -1621,6 +1599,17 @@ public:
 
 	/** Throws an exception if this document can not be changed. */
 	void canChange () const;
+
+	/** Checks whether encryption credentials are required for docuement.
+	 * @return true if no credentials have been set yet and they are
+	 * required (setCredentials method has to be called), false otherwise.
+	 */
+	bool needsCredentials()const;
+
+	/** Sets credentials for encrypted document.
+	 * Delegates to CXref::setCredentials method.
+	 */
+	void setCredentials(const char * ownerPasswd, const char * userPasswd);
 };
 
 
@@ -1658,7 +1647,7 @@ enum PageTreeNodeType { ErrorNode, UnknownNode, LeafNode, InterNode, RootNode };
  *
  * @return Dictionary wrapped by shared_ptr (NULL dictionary if not found).
  */
-boost::shared_ptr<CDict> getPageTreeRoot(const CPdf & pdf);
+boost::shared_ptr<CDict> getPageTreeRoot(const boost::shared_ptr<CPdf> &pdf);
 	
 /** Helper method to find page at certain position.
  * @param pdf Pdf instance where to search.
@@ -1732,8 +1721,8 @@ boost::shared_ptr<CDict> getPageTreeRoot(const CPdf & pdf);
  * position.
  */
 boost::shared_ptr<CDict> findPageDict(
-		const CPdf & pdf, 
-		boost::shared_ptr<IProperty> pagesDict, 
+		const boost::shared_ptr<CPdf> &pdf, 
+		const boost::shared_ptr<IProperty> &pagesDict, 
 		size_t startPos, 
 		size_t pos, 
 		PageTreeNodeCountCache * cache);
@@ -1761,7 +1750,9 @@ boost::shared_ptr<CDict> findPageDict(
  * of page tree ambiguity (see searchTreeNode for more information).
  * @return Node position.
  */
-size_t getNodePosition(const CPdf & pdf, boost::shared_ptr<IProperty> node, PageTreeNodeCountCache * cache);
+size_t getNodePosition(const boost::shared_ptr<CPdf> &pdf, 
+		const boost::shared_ptr<IProperty> &node, 
+		PageTreeNodeCountCache * cache);
 
 /** Calculates number of direct pages under given node property.
  * @param interNodeProp Page tree node property (must be dictionary or reference
@@ -1826,7 +1817,7 @@ PageTreeNodeType getNodeType(const boost::shared_ptr<IProperty> & nodeProp)throw
  *
  * @return true If given child belongs to parent subtree, false otherwise.
  */
-bool isDescendant(CPdf & pdf, IndiRef parent, boost::shared_ptr<CDict> child);
+bool isNodeDescendant(const boost::shared_ptr<CPdf>& pdf, const IndiRef &parent, const boost::shared_ptr<CDict> &child);
 
 /** Collects all kids elements from internode dictionary.
  * @param interNodeDict Intermediate node dictionary.
@@ -1847,80 +1838,16 @@ void getKidsFromInterNode(const boost::shared_ptr<CDict> & interNodeDict, Contai
 
 /** Checks whether file content is encrypted.
  * @param pdf Pdf instance to check.
- * @param filterName Name of the filter used for encryption (set only if
- * content is encrypted).
- *
- * Checks for Encrypt entry in document's trailer. If it is present, it means
- * that content is enctypted and so tries to get FilterName entry from Encrypt
- * dictionary (if filterName is non NULL).
  * 
+ * Simple helper which asks its cross reference table.
+ *
  * @return true if file content is encrypted, false otherwise.
  */
-bool isEncrypted(CPdf & pdf, std::string * filterName);
+bool isEncrypted(const boost::shared_ptr<CPdf> &pdf);
 
-/** Returns cobjects from given reference property.
- * @param refProp Reference property (must be pRef typed).
- *
- * Gets reference value from property and dereferences indirect object from it.
- * Uses refProp's pdf for dereference (so it has to be valid).
- * Checks target object for given template pType and if it matches casts it to
- * given CType and returns.
- *
- * @throw ElementBadTypeException if refProp is not CRef instance or indirect
- * object is not CType instance.
- * @return CType instance wrapped by shared_ptr smart pointer.
- */
-template<typename CType, PropertyType pType>
-boost::shared_ptr<CType> getCObjectFromRef(boost::shared_ptr<IProperty> refProp)__attribute__((deprecated));
-
-// gcc doesn't like __attribute__ in function definition
-template<typename CType, PropertyType pType>
-boost::shared_ptr<CType> getCObjectFromRef(boost::shared_ptr<IProperty> refProp)
-{
-	// REMARK
-	// This helper has to be here because of gcc template manipulation
-	// (cobjecthelpers.h can't include from this header file)
-	
-	if(!isRef(refProp))
-		throw ElementBadTypeException("");
-	
-	// gets reference value and dereferences indirect object
-	assert(refProp->getPdf());
-	assert(hasValidRef(refProp));
-	IndiRef ref;
-	IProperty::getSmartCObjectPtr<CRef>(refProp)->getValue(ref);
-	boost::shared_ptr<IProperty> indirect_ptr=refProp->getPdf()->getIndirectProperty(ref);
-	if(indirect_ptr->getType() != pType)
-		throw ElementBadTypeException("");
-	return IProperty::getSmartCObjectPtr<CType>(indirect_ptr);
-}
-
-/** Returns cobjects from given reference and pdf.
- * @param ref Indirect reference.
- * @param pdf CPdf instance where to fetch.
- *
- * Calls getIndirectProperty on given pdf and cast returned indirect object to
- * given CType.
- *
- * @throw ElementBadTypeException if indirect object is not CType instance.
- * @return CType instance wrapped by shared_ptr smart pointer.
- */
-template<typename CType, PropertyType pType>
-boost::shared_ptr<CType> getCObjectFromRef(IndiRef ref, CPdf & pdf)__attribute__((deprecated));
-
-// gcc doesn't like __attribute__ in function definition
-template<typename CType, PropertyType pType>
-boost::shared_ptr<CType> getCObjectFromRef(IndiRef ref, CPdf & pdf)
-{
-	// REMARK
-	// This helper has to be here because of gcc template manipulation
-	// (cobjecthelpers.h can't include from this header file)
-	
-	boost::shared_ptr<IProperty> indirect_ptr=pdf.getIndirectProperty(ref);
-	if(indirect_ptr->getType() != pType)
-		throw ElementBadTypeException("");
-	return IProperty::getSmartCObjectPtr<CType>(indirect_ptr);
-}
+// Following functions have to be in this header files because they are templates
+// (so have to be in header) and cobjecthelpers.h cannot include cpdf.h which
+// is necessary for CPdf type completness
 
 /** Returns cobjects from given reference property.
  * @param refProp Reference property (must be pRef typed).
@@ -1935,7 +1862,7 @@ boost::shared_ptr<CType> getCObjectFromRef(IndiRef ref, CPdf & pdf)
  * @return CType instance wrapped by shared_ptr smart pointer.
  */
 template<typename CType>
-boost::shared_ptr<CType> getCObjectFromRef(boost::shared_ptr<IProperty> refProp)
+boost::shared_ptr<CType> getCObjectFromRef(const boost::shared_ptr<IProperty> &refProp)
 {
 	// REMARK
 	// This helper has to be here because of gcc template manipulation
@@ -1945,11 +1872,11 @@ boost::shared_ptr<CType> getCObjectFromRef(boost::shared_ptr<IProperty> refProp)
 		throw ElementBadTypeException("");
 	
 	// gets reference value and dereferences indirect object
-	assert(refProp->getPdf());
-	assert(hasValidRef(refProp));
+	boost::shared_ptr<CPdf> pdf = refProp->getPdf().lock();
+	assert(pdf);
 	IndiRef ref;
 	IProperty::getSmartCObjectPtr<CRef>(refProp)->getValue(ref);
-	boost::shared_ptr<IProperty> indirect_ptr=refProp->getPdf()->getIndirectProperty(ref);
+	boost::shared_ptr<IProperty> indirect_ptr=pdf->getIndirectProperty(ref);
 	if(indirect_ptr->getType() != CType::type)
 		throw ElementBadTypeException("");
 	return IProperty::getSmartCObjectPtr<CType>(indirect_ptr);
@@ -1966,19 +1893,18 @@ boost::shared_ptr<CType> getCObjectFromRef(boost::shared_ptr<IProperty> refProp)
  * @return CType instance wrapped by shared_ptr smart pointer.
  */
 template<typename CType>
-boost::shared_ptr<CType> getCObjectFromRef(IndiRef ref, CPdf & pdf)
+boost::shared_ptr<CType> getCObjectFromRef(const IndiRef& ref, const boost::shared_ptr<CPdf>& pdf)
 {
 	// REMARK
 	// This helper has to be here because of gcc template manipulation
-	// (cobjecthelpers.h can't include from this header file)
-	
-	boost::shared_ptr<IProperty> indirect_ptr=pdf.getIndirectProperty(ref);
+	// (cobjecthelpers.h can't include from this header file)	
+	assert(pdf);
+	boost::shared_ptr<IProperty> indirect_ptr=pdf->getIndirectProperty(ref);
 	if(indirect_ptr->getType() != CType::type)
 		throw ElementBadTypeException("");
 	return IProperty::getSmartCObjectPtr<CType>(indirect_ptr);
 }
 
-
 } // namespace utils
 
 } // namespace pdfobjects
