@@ -31,7 +31,8 @@
 #include "kernel/pdfedit-core-dev.h"
 
 using namespace pdfobjects;
-CXref::CXref(BaseStream * stream):XRef(stream), internal_fetch(true)
+
+void CXref::init()
 {
 	if(!pdfedit_core_dev_init_check())
 	{
@@ -51,9 +52,21 @@ CXref::CXref(BaseStream * stream):XRef(stream), internal_fetch(true)
 	internal_fetch = false;
 }
 
+CXref::CXref(BaseStream * stream):XRef(stream), internal_fetch(true)
+{
+	try
+	{
+		init();
+	}catch(...)
+	{
+		delete stream;
+		throw;
+	}
+}
+
 void CXref::cleanUp()
 {
-using namespace debug;
+	using namespace debug;
 
 	kernelPrintDbg(DBG_DBG, "");
 
@@ -62,7 +75,7 @@ using namespace debug;
 	// returned from remove object (iterators are not invalidated by remove
 	// method)
 	kernelPrintDbg(DBG_DBG, "Deallocating changedStorage (size="<<changedStorage.size()<<")");
-	ObjectStorage< ::Ref, ObjectEntry*, xpdf::RefComparator>::Iterator i;
+	ChangedStorage::Iterator i;
 	int index=0;
 	for(i=changedStorage.begin(); i!=changedStorage.end(); ++i)
 	{
@@ -99,6 +112,9 @@ using namespace debug;
 	// newStorage doesn't need special entries deallocation
 	newStorage.clear();
 	kernelPrintDbg(DBG_DBG, "newStorage cleaned up");
+
+	// remove changed trailer
+	currTrailer.reset();
 }
 
 CXref::~CXref()
@@ -183,14 +199,17 @@ using namespace debug;
 
 ::Object * CXref::changeTrailer(const char * name, ::Object * value)
 {
-using namespace debug;
+	using namespace debug;
 
+	if (!name || !value)
+	{
+		kernelPrintDbg(DBG_ERR, "Invalid parameters. name="<<name<<" value="<<value);
+		throw ElementBadTypeException("");
+	}
 	kernelPrintDbg(DBG_DBG, "name="<<name<<" value type="<<value->getType());
 	
 	check_need_credentials(this);
 
-	Dict * trailer = trailerDict.getDict(); 
-
 	Object * clonedObject=value->clone();
 	if(!clonedObject)
 	{
@@ -203,7 +222,17 @@ using namespace debug;
 		throw NotImplementedException("clone failure.");
 	}
 	char * key=copyString(name);
-	::Object * prev = trailer->update(key, clonedObject);
+
+	// make sure that we will write into the CXref::currTrailer and
+	// not the one in XRef which will change when-ever we change
+	// current revision
+	if (!currTrailer)
+	{
+		// first change to the trailer
+		currTrailer = boost::shared_ptr<Object>(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
+		XRef::getTrailerDict()->copy(currTrailer.get());
+	}
+	::Object * prev = getTrailerDict()->dictUpdate(key, clonedObject);
 	gfree(clonedObject);
 
 	// update doesn't store key if key, value has been already in the 
@@ -240,8 +269,8 @@ using namespace debug;
 		}
 
 		// reference is never reused if generation number is MAXOBJGEN
-		// according specification
-		if(entries[i].gen>=MAXOBJGEN)
+		// according to specification
+		if(entries[i].gen>=MAXOBJGEN || entries[i].gen<0)
 		{
 			kernelPrintDbg(DBG_DBG, "Entry ["<<i<<", "<<entries[i].gen<<"] can't be reused. MAXOBJGEN reached.");
 			continue;
@@ -373,7 +402,7 @@ using namespace debug;
 	return obj;
 }
 
-RefState CXref::knowsRef(::Ref& ref)
+RefState CXref::knowsRef(const ::Ref& ref)const
 {
 using namespace debug;
 
@@ -454,25 +483,24 @@ using namespace debug;
 
 ::Object * CXref::getTrailerEntry(char * name)
 {
-using namespace debug;
+	using namespace debug;
 
 	kernelPrintDbg(DBG_DBG, "name="<<name);
-	Dict * trailer = trailerDict.getDict();
+	const Dict * trailer = getTrailerDict()->getDict();
 
 	// lookupNF doesn't create deep copy, so 
 	// we have to get value and then make deep copy
 	// calling clone method. To keep clean reference counting
 	// obj has to be freed
-	::Object obj;
-	trailer->lookupNF(name, &obj);
+	boost::shared_ptr< ::Object> obj(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
+	trailer->lookupNF(name, obj.get());
 
-	::Object * retValue=obj.clone();
-	obj.free();
+	::Object * retValue=obj->clone();
 	if(!retValue)
 	{
 		// cloning has failed
 		kernelPrintDbg(DBG_ERR, "Trailer::"<<name<<" ("
-				<<obj.getType() 
+				<<obj->getType() 
 				<<") can't be cloned. Uses objNull instead");
 		throw NotImplementedException("clone failure.");
 	}
@@ -482,67 +510,67 @@ using namespace debug;
 
 ::Object *CXref::getDocInfo(::Object *obj)
 {
-using namespace debug;
+	using namespace debug;
 
 	kernelPrintDbg(DBG_DBG, "");
 
 	// TODO needs credentials ?
 
 	// gets object
-	::Object docObj;
-	XRef::getDocInfo(&docObj);
+	boost::shared_ptr< ::Object> docObj(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
+	XRef::getDocInfo(docObj.get());
 
 	// creates deep copy and frees object from getDocInfo
 	// and initialize parameter from cloned value
-	::Object * retObj=docObj.clone();
-	docObj.free();
+	::Object * retObj=docObj->clone();
 	if(!retObj)
 	{
 		// cloning has failed
 		kernelPrintDbg(DBG_ERR, "Trailer::Info ("
-				<<docObj.getType()
+				<<docObj->getType()
 				<<") can't be cloned. Uses objNull instead");
 		throw NotImplementedException("clone failure.");
 	}
 	*obj=*retObj;
 
+	// TODO do we really want to have different point returned than filled?
 	return retObj;
 }
 
 ::Object *CXref::getDocInfoNF(::Object *obj)
 {
-using namespace debug;
+	using namespace debug;
 
 	kernelPrintDbg(DBG_DBG, "");
 
 	// TODO needs credentials ?
 
 	// gets object
-	::Object docObj;
-	XRef::getDocInfoNF(&docObj);
+	boost::shared_ptr< ::Object> docObj(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
+	XRef::getDocInfoNF(docObj.get());
 
 	// creates deep copy and frees object (because getDocInfoNF 
 	// uses copy method) from getDocInfo
 	// and initialize parameter from cloned value
-	::Object * retObj=docObj.clone();
-	docObj.free();
+	::Object * retObj=docObj->clone();
 	if(!retObj)
 	{
 		// cloning has failed
 		kernelPrintDbg(DBG_ERR, "Trailer::Info ("
-				<<docObj.getType()
+				<<docObj->getType()
 				<<") can't be cloned. Uses objNull instead");
 		throw NotImplementedException("clone failure.");
 	}
 	// shallow copy of the content (deep copied)
 	*obj=*retObj;
 
+	// TODO do we really want to have different point returned than filled?
 	return retObj;
 }
 
-::Object * CXref::fetch(int num, int gen, ::Object *obj)
+::Object * CXref::fetch(int num, int gen, ::Object *obj)const
 {
-using namespace debug;
+	using namespace debug;
 
 	kernelPrintDbg(DBG_DBG, "num="<<num<<" gen="<<gen);
 	
@@ -595,8 +623,8 @@ using namespace debug;
 
 	// delegates to original implementation
 	kernelPrintDbg(DBG_DBG, ref<<" is not changed - using Xref");
-	Object tmpObj;
-	XRef::fetch(num, gen, &tmpObj);
+	boost::shared_ptr< ::Object> tmpObj(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
+	XRef::fetch(num, gen, tmpObj.get());
 	if (!isOk())
 	{
 		kernelPrintDbg(DBG_ERR, ref<<" object fetching failed with code="
@@ -607,14 +635,13 @@ using namespace debug;
 	// clones fetched object
 	// this has to be done because return value may be stream and we want to
 	// prevent direct changing of the stream
-	Object * cloneObj=tmpObj.clone();
+	Object * cloneObj=tmpObj->clone();
 	// deallocates XRef returned object content
-	tmpObj.free();
 	if(!cloneObj)
 	{
 		// cloning has failed
 		kernelPrintDbg(DBG_ERR, ref << " object ("
-				<<tmpObj.getType()
+				<<tmpObj->getType()
 				<<") can't be cloned. Uses objNull instead");
 		throw NotImplementedException("clone failure.");
 	}
@@ -636,14 +663,14 @@ using namespace debug;
 	return obj;
 }
 
-int CXref::getNumObjects() 
+int CXref::getNumObjects()const
 { 
-using namespace debug;
+	using namespace debug;
 
 	kernelPrintDbg(DBG_DBG, "");
 
 	size_t newSize=0;
-	ObjectStorage< ::Ref, RefState, xpdf::RefComparator>::Iterator begin, i;
+	RefStorage::ConstIterator begin, i;
 
 	for(i=newStorage.begin(); i!=newStorage.end(); ++i)
 		if(i->second==INITIALIZED_REF)
@@ -681,17 +708,16 @@ using namespace debug;
 
 bool CXref::checkEncryptedContent()
 {
-	Object encrypt;
+	boost::shared_ptr< ::Object> encrypt(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
 	needs_credentials = false;
 	enableInternalFetch();
-	getTrailerDict()->dictLookup("Encrypt", &encrypt);
+	getTrailerDict()->dictLookup("Encrypt", encrypt.get());
 	disableInternalFetch();
 	encrypted = false;
-	if ((encrypted = encrypt.isDict())) {
+	if ((encrypted = encrypt->isDict())) {
 		needs_credentials = true;
 		encrypted = true;
 	}
-	encrypt.free();
 
 	return needs_credentials;
 }
