@@ -54,7 +54,7 @@ const int MAXOBJGEN = 65535;
  * Class works in three layers:
  * <ul>
  * <li>Maintaining layer - registers changes (in values or new objects), which
- *    uses ObjectStorage instances to know which objects are changed 
+ *    uses ChangedStorage instances to know which objects are changed 
  *    (changedStorage field) and which objects are new (newStorage field).  
  * <li>xpdf layer - delegation to original xpdf implementation of XRef.  
  * <li>caching layer - holds objects which where required to prevent getting
@@ -80,7 +80,7 @@ const int MAXOBJGEN = 65535;
  * <br>
  * Because, in fact, all object which can be changed (we are meaning change 
  * value inside Object instance) has to be indirect Object, obj and gen number 
- * are used as identificators, when objects are stored to the ObjectStorage. So
+ * are used as identificators, when objects are stored to the ChangedStorage. So
  * when someone wants to change object value using changeObject method, he has
  * to suply also obj and gen numbers.
  * Only one exception in pdf format is trailer, which is not indirect object and
@@ -111,6 +111,10 @@ private:
 	 */
 	bool internal_fetch;
 
+	/** Core initialization for instance.
+	 * Called by constructor only.
+	 */
+	void init();
 protected:
 	/** Empty constructor.
 	 *
@@ -119,7 +123,7 @@ protected:
 	 */
 	CXref(): XRef(NULL), needs_credentials(false), internal_fetch(false){}
 
-	/** Entry for ObjectStorage.
+	/** Entry for ChangedStorage.
 	 *
 	 * Each entry contains pointer to changed object. It may be extended in
 	 * future, so structure is used.
@@ -129,12 +133,16 @@ protected:
 		::Object * object;
 	} ObjectEntry;
 	
+	typedef ObjectStorage<const ::Ref, ObjectEntry*, xpdf::RefComparator> ChangedStorage;
+
 	/** Object storage for changed objects.
 	 * Mapping from object referencies to the ObjectEntry structure.
 	 * This structure contains new Object value for reference and 
 	 * flag. 
 	 */
-	ObjectStorage< ::Ref, ObjectEntry*, xpdf::RefComparator> changedStorage;   
+	ChangedStorage changedStorage;   
+
+	typedef ObjectStorage<const ::Ref, RefState, xpdf::RefComparator> RefStorage;
 
 	/** Object storage for newly created objects.
 	 * Value is the flag of newly created reference. When new entry is added, it
@@ -142,7 +150,7 @@ protected:
 	 * Initialized. Unused is default value for not found, so unknown
 	 * (ObjectStorage returns 0 if entry is not found). 
 	 */
-	ObjectStorage< ::Ref, RefState, xpdf::RefComparator> newStorage;
+	RefStorage newStorage;
 
 	/** Registers change in given object addressable through given 
 	 * reference.
@@ -171,6 +179,29 @@ protected:
 	 */
 	::Object * changeObject(::Ref ref, ::Object * instance);
 
+	/** Trailer dictionary for changes.
+	 * This is allocated on demand when changeTrailer is called for the first
+	 * time and it is used in getTrailerDict to force changed trailer
+	 * rather than the one from XRef which is parsed each time reopen method 
+	 * is called.
+	 * <br>
+	 * Instance is cleaned up only if reopen is called with dropChanges flag
+	 * (in cleanUp method) because this means that we have just created a new 
+	 * revision which is clean.
+	 */
+	boost::shared_ptr<Object> currTrailer;
+
+	/** Overrides XRef::getTrailerDict to force changed trailer if
+	 * there are some changes otherwise delegate to XRef::getTrailerDict.
+	 * Never deallocate returned object.
+	 */
+	virtual const Object *getTrailerDict()const 
+	{
+		if (!currTrailer)
+			return XRef::getTrailerDict();
+		return currTrailer.get();
+	}
+
 	/** Changes entry in trailer dictionary.
 	 * @param name Name of the value.
 	 * @param value Value to be set.
@@ -306,9 +337,13 @@ public:
 	 * @param stream Stream with file data.
 	 *
 	 * Delegates to XRef constructor with same parameter.
+	 * <br>
+	 * Given stream is always deallocated in this class. Caller should never
+	 * (even if an exception is thrown) deallocate it.
 	 *
 	 * @throw MalformedFormatExeption if XRef creation fails (instance is
 	 * unusable in such situation).
+	 * @throw PDFedit_devException if pdfedit-core-dev is not initialized.
 	 */
 	CXref(BaseStream * stream);
 
@@ -370,7 +405,7 @@ public:
 	 * @see INITIALIZED_REF
 	 * @return Current state of given reference.
 	 */
-	virtual RefState knowsRef(::Ref& ref);
+	virtual RefState knowsRef(const ::Ref& ref)const;
 
 	/** Checks if given reference is known.
 	 * @param ref Reference to check.
@@ -382,7 +417,7 @@ public:
 	 *
 	 * @return reference current state.
 	 */
-	virtual RefState knowsRef(IndiRef ref)
+	virtual RefState knowsRef(const IndiRef& ref)const
 	{
 		::Ref xpdfRef={ref.num, ref.gen};
 		return knowsRef(xpdfRef);
@@ -439,7 +474,7 @@ public:
 	 *
 	 * @return Total number of objects.
 	 */
-	virtual int getNumObjects(); 
+	virtual int getNumObjects()const; 
 
 	/** Fetches object.
 	 * @param num Object number.
@@ -467,7 +502,7 @@ public:
 	 * @return Pointer with initialized object given as parameter, if not
 	 * found obj is set to objNull.
 	 */
-	virtual ::Object * fetch(int num, int gen, ::Object *obj);
+	virtual ::Object * fetch(int num, int gen, ::Object *obj)const;
 };
 
 // implemented as macro because we want to have better log information
