@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -68,6 +68,9 @@ class NotImplementedException;
 class IndirectObjectNotFoundException;
 class ElementNotFoundException;
 class ElementBadTypeException;
+
+class PermissionException;
+
 struct CObjBadValue;
 struct CObjInvalidObject;
 struct CObjInvalidOperation;
@@ -92,6 +95,14 @@ class PdfException: public std::exception
 {
 };
 
+/** General purpose exception for pdfedit-dev related
+ * exceptions.
+ * Thrown for example when pdfedit-dev core is not initialized
+ * and its code is used.
+ */
+class PDFedit_devException: public std::exception
+{
+};
 
 /** Cobject exception base class.
  */
@@ -208,10 +219,13 @@ class PageNotFoundException: public PdfException
 {
 	size_t position;
 	std::string message;
+	
 public:
 	/** Exception constructor without position specified.
+	 * This exception should be called when page is searched by 
+	 * CPage instance.
 	 */
-	PageNotFoundException():message("Page not found")
+	PageNotFoundException():position(0),message("Page not found")
 	{
 	}
 	
@@ -491,6 +505,34 @@ public:
 	}
 };
 
+/** Exception for permission violation.
+ */
+class PermissionException: public CObjectException
+{
+	const std::string message;
+public:
+	/** Exception constructor.
+	 * @param _message Feature description which is not implemented.
+	 */
+	PermissionException(std::string _message):message(_message)
+	{
+	}
+
+	~PermissionException() throw()
+	{
+	}
+
+	const char * what()const throw()
+	{
+		return message.c_str();
+	}
+
+	void getMessage(std::string _message)
+	{
+		_message=message;
+	}
+};
+
 /**
  * Exception occurs when CObject has got unexpected value. 
  */
