@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -87,7 +87,7 @@ public:
 	 * @return Type instance.
 	 */
 	static Type* 
-	getInstance(CPdf & pdf, const IndiRef & indirefParent, Object & obj)
+	getInstance(boost::shared_ptr<CPdf> pdf, const IndiRef & indirefParent, const Object & obj)
 	{
 		return new Type(pdf, obj, indirefParent);
 	}
@@ -102,7 +102,7 @@ public:
 	 * @return Type instance.
 	 */
 	static Type* 
-	getInstance(Object & obj)
+	getInstance(const Object & obj)
 	{
 		return new Type (obj);
 	}
@@ -215,7 +215,7 @@ public:
 	 * method.
 	 * @return CDict instance.
 	 */
-	static CDict * getInstance(CPdf & pdf, const IndiRef & indirefParent, Object & obj)
+	static CDict * getInstance(boost::shared_ptr<CPdf>  pdf, const IndiRef & indirefParent, const Object & obj)
 	{
 		return new CDict(pdf, obj, indirefParent);
 	}
@@ -228,7 +228,7 @@ public:
 	 *
 	 * @return CDict instance.
 	 */
-	static CDict * getInstance(Object & obj)
+	static CDict * getInstance(const Object & obj)
 	{
 		// checks type
 		if(obj.getType()!=objDict)
@@ -268,7 +268,7 @@ public:
 	 * method.
 	 * @return CArray instance.
 	 */
-	static CArray * getInstance(CPdf & pdf, const IndiRef & indirefParent, Object & obj)
+	static CArray * getInstance(boost::shared_ptr<CPdf>  pdf, const IndiRef & indirefParent, const Object & obj)
 	{
 		return new CArray(pdf, obj, indirefParent);
 	}
@@ -281,7 +281,7 @@ public:
 	 *
 	 * @return CArray instance.
 	 */
-	static CArray * getInstance(Object & obj)
+	static CArray * getInstance(const Object & obj)
 	{
 		// checks type
 		if(obj.getType()!=objArray)
