@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,6 +32,7 @@
 // iterator
 #include "utils/iterator.h"
 #include "kernel/pdfoperators.h"
+#include "kernel/contentschangetag.h"
 
 
 //==========================================================
@@ -272,7 +273,7 @@ struct ChangePdfOperatorIterator: public PdfOperator::Iterator
 		std::string name;
 		_cur.lock()->getOperatorName (name);
 
-		if (name == getChangeTagName())
+		if (name == ContentsChangeTag::CHANGE_TAG_NAME)
 			return true;
 		
 		return false;
