@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #include "kernel/stateupdater.h"
 #include "kernel/pdfoperators.h"
 #include "kernel/cobject.h"
+#include "kernel/factories.h"
 
 
 //==========================================================
@@ -434,13 +435,20 @@ namespace {
 	}
 	// "Tj"
 	GfxState *
-	opTjUpdate (GfxState* state, boost::shared_ptr<GfxResources>, const boost::shared_ptr<PdfOperator>, const PdfOperator::Operands& args, BBox* rc)
+	opTjUpdate (GfxState* state, boost::shared_ptr<GfxResources>, const boost::shared_ptr<PdfOperator> op, const PdfOperator::Operands& args, BBox* rc)
 	{
 		assert (1 <= args.size ());
 
 		// This can happen in really damaged pdfs
- 		if (state->getFont())
-			StateUpdater::printTextUpdate (state, getStringFromIProperty (args[0]), rc);
+ 		if (state->getFont()) {
+			TextSimpleOperator *txtOp = dynamic_cast<TextSimpleOperator*>(op.get());
+			assert(txtOp);
+			// TODO - can we use const GfxFont *?
+			txtOp->setFontData((GfxFont *)state->getFont());
+			std::string rawStr;
+			txtOp->getRawText(rawStr);
+			StateUpdater::printTextUpdate (state, rawStr, rc);
+		}
 		
 		// return changed state
 		return state;
@@ -481,7 +489,7 @@ namespace {
 	}
 	// "\"
 	GfxState *
-	opSlashUpdate (GfxState* state, boost::shared_ptr<GfxResources>, const boost::shared_ptr<PdfOperator>, const PdfOperator::Operands& args, BBox* rc)
+	opSlashUpdate (GfxState* state, boost::shared_ptr<GfxResources>, const boost::shared_ptr<PdfOperator> op, const PdfOperator::Operands& args, BBox* rc)
 	{
 		assert (3 <= args.size ());
 		
@@ -498,7 +506,14 @@ namespace {
 		double ty = state->getLineY() - state->getLeading();
 		state->textMoveTo(tx, ty);
 
- 		StateUpdater::printTextUpdate (state, getStringFromIProperty (args[2]), rc);	// to 'rc' save only text bbox
+
+		TextSimpleOperator *txtOp = dynamic_cast<TextSimpleOperator*>(op.get());
+		assert(txtOp);
+		// TODO can we use const GfxFont *?
+		txtOp->setFontData((GfxFont *)state->getFont());
+		std::string rawStr;
+		txtOp->getRawText(rawStr);
+		StateUpdater::printTextUpdate (state, rawStr, rc);
 
 		// Set edge of rectangle from actual position on output devices
 		//state->transform(state->getCurX (), state->getCurY(), & rc->xright, & rc->yright);
@@ -508,7 +523,7 @@ namespace {
 	}
 	// "TJ"
 	GfxState *
-	opTJUpdate (GfxState* state, boost::shared_ptr<GfxResources>, const boost::shared_ptr<PdfOperator>, const PdfOperator::Operands& args, BBox* rc)
+	opTJUpdate (GfxState* state, boost::shared_ptr<GfxResources>, const boost::shared_ptr<PdfOperator> op, const PdfOperator::Operands& args, BBox* rc)
 	{
 		assert (1 <= args.size ());
 
@@ -570,6 +585,10 @@ namespace {
 			rc->yright = max( rc->yright, max( h_rc.yleft, h_rc.yright ) );
 		}// for
 		
+		TextSimpleOperator *txtOp = dynamic_cast<TextSimpleOperator*>(op.get());
+		assert(txtOp);
+		// TODO can we use const GfxFont *?
+		txtOp->setFontData((GfxFont *)state->getFont());
 		// return changed state
 		return state;
 	}
@@ -712,6 +731,13 @@ namespace {
 	//==========================================================
 	// End of actual state (position) updaters
 	//==========================================================
+	
+	static void throwMalformedFormat(const char *msg)
+	{
+		kernelPrintDbg(debug::DBG_ERR, "Unable to parse object ("
+				<<msg<<")");
+		throw MalformedFormatExeption(msg);
+	}
 
 //==========================================================
 } // namespace
@@ -725,7 +751,7 @@ namespace {
 GfxState*
 StateUpdater::printTextUpdate (GfxState* state, const std::string& txt, BBox* rc)
 {
-	GfxFont *font;
+	const GfxFont *font;
 	int wMode;
 	double riseX, riseY;
 	CharCode code;
@@ -733,11 +759,11 @@ StateUpdater::printTextUpdate (GfxState* state, const std::string& txt, BBox* rc
 	double x, y, dx, dy,/* dx2, dy2,*/ curX, curY, tdx, tdy, lineX, lineY;
 	double originX = 0, originY, tOriginX, tOriginY;
 	double oldCTM[6], newCTM[6];
-	double *mat = NULL;
+	const double *mat = NULL;
 	//Dict *resDict = NULL;
 	char *p;
 	int len = 0, n = 0, uLen = 0,/* nChars = 0, nSpaces = 0,*/ i = 0;
-	GString s (txt.c_str(),txt.size());
+	GString s (txt.c_str(),(Guint)txt.size());
 
 	font = state->getFont();
 	wMode = font->getWMode();
@@ -790,8 +816,8 @@ StateUpdater::printTextUpdate (GfxState* state, const std::string& txt, BBox* rc
 		  //
 		  // Try to find out the height and width of this letter
 		  //
-		  xpdf::XpdfObject charProc;
-		  static_cast<Gfx8BitFont*>(font)->getCharProc (code, charProc.get());
+		  boost::shared_ptr< ::Object> charProc(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
+		  static_cast<const Gfx8BitFont*>(font)->getCharProc (code, charProc.get());
 		  if (charProc->isStream())
 		  {
 			  // Make parser
@@ -801,12 +827,13 @@ StateUpdater::printTextUpdate (GfxState* state, const std::string& txt, BBox* rc
 						  gFalse
 						  )
 					  );
-			  xpdf::XpdfObject obj;
+			  boost::shared_ptr< ::Object> obj(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
 			  // Read till BI found
 			  while (!parser->eofOfActualStream() && !obj->isCmd("BI"))
 			  {
-				obj.reset ();
-				parser->getObj (obj.get());
+				obj->free ();
+				if(!parser->getObj (obj.get())) 
+					throwMalformedFormat("bad data stream");
 			  }
 
 			  if (!parser->eofOfActualStream())
@@ -814,16 +841,18 @@ StateUpdater::printTextUpdate (GfxState* state, const std::string& txt, BBox* rc
 				  //
 				  // Find height information in image stream dictionary
 				  //
-				  parser->getObj (obj.get());
+				  if(!parser->getObj (obj.get())) 
+					  throwMalformedFormat("bad data stream");
 				  while (!obj->isCmd("ID") && !obj->isEOF()) 
-				  { 
+				  {
 					if (obj->isName()) 
 					{
 					  // Get name
-					  string key (copyString (obj->getName()));
-					  obj.reset();
+					  string key (obj->getName());
+					  obj->free();
 					  // Get key
-					  parser->getObj(obj.get());
+					  if(!parser->getObj(obj.get())) 
+						  throwMalformedFormat("bad data stream");
 					  if (obj->isEOF() || obj->isError()) 
 						break;
 					  //
@@ -846,17 +875,14 @@ StateUpdater::printTextUpdate (GfxState* state, const std::string& txt, BBox* rc
 						kernelPrintDbg (DBG_DBG, "Bad inline image dictionary.");
 						break;
 					}
-					parser->getObj(obj.get());
+					obj->free();
+					if(!parser->getObj(obj.get())) 
+						throwMalformedFormat("bad data stream");
 				  }
 
 			   } //  if (parser->eofOfActualStream())
 			} // if (charProc->isStream())
 
-			// Free resources
-				assert (2 == charProc->getStream()->incRef());
-				assert (1 == charProc->getStream()->decRef());
-			charProc.reset ();
-
 			//
 			// Found right width now do the transformations
 			//
@@ -1160,6 +1186,55 @@ StateUpdater::getEndTag (const string& name)
 	return string (chcktp->endTag);
 }
 
+bool checkAndFixOperator (const StateUpdater::CheckTypes& ops, PdfOperator::Operands& operands)
+{
+	size_t argNum = static_cast<size_t> ((ops.argNum > 0) ? ops.argNum : -ops.argNum);
+		
+	//
+	// Check operator size if > 0 than it is the exact size, maximum
+	// otherwise
+	//
+	if (((ops.argNum >= 0) && (operands.size() != argNum)) 
+		 || ((ops.argNum <  0) && (operands.size() > argNum)) )
+	{
+		utilsPrintDbg (DBG_ERR, "Number of operands mismatch.. expected " << ops.argNum << " got: " << operands.size());
+		return false;
+	}
+	
+	//
+	// Check arguments
+	//
+	PdfOperator::Operands::reverse_iterator rit = operands.rbegin ();
+	// Be careful -- buffer overflow
+	argNum = std::min (argNum, operands.size());
+	advance (rit, argNum);
+	PdfOperator::Operands::iterator it = rit.base ();
+	// Loop from the first operator to the end
+	for (int pos = 0; it != operands.end (); ++it, ++pos)
+	{			
+		if (!isBitSet(ops.types[pos], (*it)->getType()))
+		{
+			utilsPrintDbg (DBG_ERR, "Bad " << pos << "-th operand type [" << (*it)->getType() << "] " << hex << " 0x" << ops.types[pos]);
+			return false;
+		}
+
+		// 
+		// If xpdf returned an Int, but the operand can be a real convert it
+		// 
+		if (isInt(*it))
+		{
+			if (isBitSet(ops.types[pos], pReal))
+			{ // Convert it to real
+				double dval = 0.0;
+				dval = IProperty::getSmartCObjectPtr<CInt>(*it)->getValue();
+				shared_ptr<IProperty> pIp (new CReal (dval));
+				std::replace (operands.begin(), operands.end(), *it, pIp);
+			}
+		}
+	}
+
+	return true;
+}
 //==========================================================
 } // namespace pdfobjects
 //==========================================================
