@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -225,6 +225,35 @@ inline bool
 isSimpleOp (const StateUpdater::CheckTypes& chck)
 	{ return ('\0' == chck.endTag[0]); }
 
+/**
+ * Is it a text operator (one which holds text to be displayed).
+ * @param chck Check type structure.
+ * @return True if chck is a text operator, false otherwise.
+ */
+inline bool isTextOp(const StateUpdater::CheckTypes& chck)
+{
+	if (!strcmp(chck.name, "TJ") || 
+	    !strcmp(chck.name, "Tj") || 
+	    !strcmp(chck.name, "\"") || 
+	    !strcmp(chck.name, "'")
+	   )
+		return true;
+	return false;
+}
+
+/**
+ * Check if the operands match the specification and replace operand with
+ * its stronger equivalent.
+ *
+ * (e.g. When xpdf returns an object with integer type, but the operand can be a real, we have to
+ * convert it to real.)
+ *
+ * @param ops Operator specification
+ * @param operands Operand stack.
+ *
+ * @return True if type and count match, false otherwise.
+ */
+bool checkAndFixOperator (const pdfobjects::StateUpdater::CheckTypes& ops, PdfOperator::Operands& operands);
 
 
 //==========================================================
