@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -36,6 +36,10 @@
 #include <os/win.h>
 #endif
 
+#ifdef _POSIX_SOURCE
+#include <os/posix.h>
+#endif
+
 //============================================
 //  POSIX
 //============================================
@@ -71,9 +75,8 @@
 // boost
 //============================================
 #include <boost/smart_ptr.hpp>
-#include <boost/iostreams/stream.hpp>
-#include <boost/iostreams/filtering_stream.hpp>
-
+#include <boost/noncopyable.hpp>
+#include <boost/algorithm/string/replace.hpp>
 
 //============================================
 // our stuff
@@ -98,6 +101,9 @@ using std::min;
 #include "utils/debug.h"
 #include "utils/objectstorage.h"
 #include "utils/observer.h"
+#include "utils/confparser.h"
+#include "utils/rulesmanager.h"
+
 
 // types
 #define _JM_NAMESPACE libs	 
