@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -103,7 +103,7 @@ namespace {
 		//
 		// Get real text from operators using xpdf (see the crazy code below)
 		//
-		GfxFont* font = (const_cast<GfxState&>(state)).getFont();
+		const GfxFont* font = (const_cast<GfxState&>(state)).getFont();
 			if (!font)
 				return text;
 		char* p = const_cast<char*> (text.c_str ());
@@ -117,7 +117,7 @@ namespace {
 		while (len > 0) 
 		{
 			n = font->getNextChar (	p, 
-									len, 
+									static_cast<int>(len), 
 									&code,
 									&u, 
 									sizeof(Unicode), 
@@ -128,11 +128,11 @@ namespace {
 			len -= n;
 		
 			// Put rather name tham the character
-			Gfx8BitFont* f = dynamic_cast<Gfx8BitFont*> (font);
+			const Gfx8BitFont* f = dynamic_cast<const Gfx8BitFont*> (font);
 			if (f)
 			{
 				string tmp;
-				char* c = f->getCharName(code);
+				const char* c = f->getCharName(code);
 				if (c)
 					tmp = c;
 				if (1 < tmp.size())
@@ -254,7 +254,7 @@ namespace {
 					string txt = getStringFromIProperty (ip);
 					PdfOperator::Operands opers;
 					opers.push_back (shared_ptr<CString> (new CString (txt)));
-					shared_ptr<SimpleGenericOperator> newop (new SimpleGenericOperator ("Tj", opers));
+					shared_ptr<PdfOperator> newop = createOperator ("Tj", opers);
 					// Set bbox 
 					BBox bbox;
 					StateUpdater::printTextUpdate (s.get(), txt, &bbox);
@@ -314,7 +314,7 @@ SimpleWordEngine::operator() (const PdfOperatorPtr op, const GfxState& gfx_state
 			sfrag->add (s);
 			sfrag->add (res);
 			// Set fragment font
-			GfxFont* font = s->getFont();
+			const GfxFont* font = s->getFont();
 			if (font) 
 			{
 				sfrag->add (string (font->getTag()->getCString()));
