@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,10 +24,12 @@
 // vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
 
 #include "kernel/static.h"
-#include<errno.h>
 #include "kernel/xrefwriter.h"
 #include "kernel/cpdf.h"
-#include "kernel/cobject.h"
+#include "kernel/cxref.h"
+#include "kernel/streamwriter.h"
+#include "kernel/pdfwriter.h"
+#include "kernel/factories.h"
 
 using namespace debug;
 
@@ -45,35 +47,56 @@ namespace pdfobjects {
 
 namespace utils {
 
-bool checkLinearized(StreamWriter & stream, XRef * xref, Ref * ref)
+bool checkLinearized(StreamWriter & stream, CXref * xref, Ref * ref)
 {
 	// searches num gen obj entry. Starts from stream begining
 	stream.reset();
 	Object obj;
-	Parser parser=Parser(
-			xref, new Lexer(
-				NULL, stream.makeSubStream(stream.getPos(), false, 0, &obj)
-				),
-			gTrue
-			);
+	Stream * subStr = stream.makeSubStream(stream.getPos(), false, 0, &obj);
+	Parser parser=Parser(xref, new Lexer(NULL, subStr), gTrue);
+	
+	//  result is false by default - it MUST BE linearized dictionary
+	bool result = false;
 
-	while(stream.getPos() < FIRST_LINEARIZED_BLOCK)
+	// TODO rewrite to use shared_ptr for obj1, obj2, obj3 
+	while(subStr->getPos() < FIRST_LINEARIZED_BLOCK)
 	{
 		Object obj1, obj2, obj3;
-		parser.getObj(&obj1);
-		parser.getObj(&obj2);
-		parser.getObj(&obj3);
+		if(!parser.getObj(&obj1))
+			goto malformedErr;
+		if(obj1.isEOF())
+			break;
+		if(!parser.getObj(&obj2))
+		{
+			obj1.free();
+			goto malformedErr;
+		}
+		if(obj2.isEOF())
+		{
+			obj1.free();
+			break;
+		}
+		if(!parser.getObj(&obj3))
+		{
+			obj1.free();
+			obj2.free();
+			goto malformedErr;
+		}
+		if(obj3.isEOF())
+		{
+			obj1.free();
+			obj2.free();
+			break;
+		}
 
 		// indirect object must start with 
 		// num gen obj line
 		if(obj1.isInt() && obj2.isInt() && obj3.isCmd())
 		{
 			Object obj;
-			parser.getObj(&obj);
-
-			//  result is false by default - it MUST BE linearized dictionary
-			bool result=false;
-			
+			if(!parser.getObj(&obj))
+				goto malformedErr;
+ 	
 			if(obj.isDict())
 			{
 				// indirect object is dictionary, so it can be Linearized
@@ -92,22 +115,32 @@ bool checkLinearized(StreamWriter & stream, XRef * xref, Ref * ref)
 					}
 					result=true;
 				}
-			}
+			}else 
+				if(obj.isEOF())
+					break;
 			obj.free();
-
-			obj1.free();
-			obj2.free();
-			obj3.free();
-			return result;
 		}
 
 		obj1.free();
 		obj2.free();
 		obj3.free();
+		if(result)
+			break;
 	}
 
 	// no indirect object in the document
-	return false;
+	return result;
+
+malformedErr:
+	utilsPrintDbg(DBG_ERR, "Unable to parse stream - bad content.");
+	throw MalformedFormatExeption("bad data stream");
+}
+
+
+bool isLatestRevision(const XRefWriter &xref)
+{
+	// The most recent revision has the highest number
+	return xref.getActualRevision() == xref.getRevisionCount()-1;
 }
 
 } // end of utils namespace
@@ -123,16 +156,37 @@ XRefWriter::XRefWriter(StreamWriter * stream, CPdf * _pdf)
 	// searches %%EOF element from startxref position.
 	storePos=XRef::eofPos;
 
-	// checks whether file is linearized
+	// enables internal fetch for case of encrypted document.
+	// Fetching is ok in such a case because we fetching only
+	// uncrypted data - trailer and check for linearized dictionary
+	enableInternalFetch();
+
+	// check for linearized document is safe also for encrypted
+	// documents because only strings are encrypted and the
+	// Linearized entry is the name object
 	Ref linearizedRef;
 	linearized=utils::checkLinearized(*stream, this, &linearizedRef);
 	if(linearized)
 		kernelPrintDbg(DBG_DBG, "Pdf content is linearized. Linearized dictionary "<<linearizedRef);
-	
-	// collects all available revisions
+
+	// revisions can be collected also for encrypted documents, because
+	// we are parsing only trailer which doesn't contain any directly
+	// encrypted data - strings
+	// revision is initialized to the most recent one
 	collectRevisions();
+
+	// sets internal fetch back to normal
+	disableInternalFetch();
 }
 
+XRefWriter::~XRefWriter()
+{
+	kernelPrintDbg(debug::DBG_DBG, "");
+	if(pdfWriter)
+		delete pdfWriter;
+}
+
+
 utils::IPdfWriter * XRefWriter::setPdfWriter(utils::IPdfWriter * writer)
 {
 using namespace utils;
@@ -146,7 +200,7 @@ using namespace utils;
 	return current;
 }
 
-bool XRefWriter::paranoidCheck(::Ref ref, ::Object * obj)
+bool XRefWriter::paranoidCheck(const ::Ref &ref, ::Object * obj)
 {
 	kernelPrintDbg(DBG_DBG, ref<<" type="<<obj->getType());
 
@@ -166,11 +220,10 @@ bool XRefWriter::paranoidCheck(::Ref ref, ::Object * obj)
 		{
 			// gets original value and uses typeSafe to 
 			// compare with given value type
-			::Object original;
-			fetch(ref.num, ref.gen, &original);
-			ObjType originalType=original.getType();
-			bool safe=typeSafe(&original, obj);
-			original.free();
+			boost::shared_ptr< ::Object> original(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
+			fetch(ref.num, ref.gen, original.get());
+			ObjType originalType=original->getType();
+			bool safe=typeSafe(original.get(), obj);
 			if(!safe)
 			{
 				kernelPrintDbg(DBG_WARN, ref<<" type="<<obj->getType()
@@ -181,7 +234,7 @@ bool XRefWriter::paranoidCheck(::Ref ref, ::Object * obj)
 			kernelPrintDbg(DBG_DBG, "Reference is not initialized yet. No checking done.");
 	}
 
-	kernelPrintDbg(DBG_INFO, "paranoidCheck successfull");
+	kernelPrintDbg(DBG_DBG, "paranoidCheck successfull");
 	return true;
 }
 
@@ -190,7 +243,9 @@ void XRefWriter::changeObject(int num, int gen, ::Object * obj)
 	::Ref ref={num, gen};
 	kernelPrintDbg(DBG_DBG, ref);
 
-	if(revision)
+	check_need_credentials(this);
+
+	if(!utils::isLatestRevision(*this))
 	{
 		// we are in later revision, so no changes can be
 		// done
@@ -203,7 +258,11 @@ void XRefWriter::changeObject(int num, int gen, ::Object * obj)
 		kernelPrintDbg(DBG_ERR, "pdf is in read-only mode.");
 		throw ReadOnlyDocumentException("Document is in Read-only mode.");
 	}
-
+	if(isEncrypted())
+	{
+		kernelPrintDbg(DBG_ERR, "Document is encrypted. Changing content is not supported");
+		throw NotImplementedException("changeObject is not implemented for encryted document");
+	}
 	
 	// paranoid checking
 	if(!paranoidCheck(ref, obj))
@@ -219,10 +278,97 @@ void XRefWriter::changeObject(int num, int gen, ::Object * obj)
 		xpdf::freeXpdfObject(oldValue);
 }
 
+namespace utils {
+bool canChangeTrailerEntry(const char * name)
+{
+	/* Trailer entries which cannot be changed by changeTrailer method.
+	 * This check is not done for easy mode where you are allowed to
+	 * to do anything you want. Please note that some of the fields changing
+	 * will not have any effect because they are are generated automatically
+	 * during save (e.g. Prev and Size).
+	 */
+	static const char *bannedTrailerEntries[] = {"Prev", "Size", "Encrypt", NULL};
+
+	for(int i=0; bannedTrailerEntries[i]; ++i)
+		if(!strcmp(name, bannedTrailerEntries[i]))
+		{
+			kernelPrintDbg(DBG_WARN, name<<" field is not editable in Trailer");
+			return false;
+		}
+	return true;
+}
+
+bool typeSafeTrailerEntry(const char *name, ::Object &value, XRef &xref)
+{
+	// all values have to be checked according to the specification
+	if(!strcmp(name, "Prev") || !strcmp(name, "Size"))	// Direct integer values
+	{
+		if(value.getType() != objInt)
+		{
+			kernelPrintDbg(DBG_ERR, name<<" cannot be assigned to "<<value.getType());
+			return false;
+		}
+	}else if(!strcmp(name, "Root") || !strcmp(name, "Info")) // Indirect reference to dictionary
+	{
+		if(value.getType() != objRef)
+		{
+			kernelPrintDbg(DBG_ERR, name<<" cannot be assigned to "<<value.getType());
+			return false;
+		}
+		boost::shared_ptr<Object> o(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
+		xref.fetch(value.getRefNum(), value.getRefGen(), o.get());
+		if(o->getType() != objDict)
+		{
+			kernelPrintDbg(DBG_ERR, name<<" cannot be assigned to "<<o->getType());
+			return false;
+		}
+	}else if(!strcmp(name, "ID"))	// direct array
+	{
+		if(value.getType() != objArray)
+		{
+			kernelPrintDbg(DBG_ERR, name<<" cannot be assigned to "<<value.getType());
+			return false;
+		}
+		// TODO maybe we should be more pedantic and check also
+		// the size and types of elements (2 strings)
+	}else if(!strcmp(name, "Encrypt"))	// direct array
+	{
+		boost::shared_ptr<Object> o(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
+		value.fetch(&xref, o.get());
+		if(o->getType() != objDict)
+		{
+			kernelPrintDbg(DBG_ERR, name<<" cannot be assigned to "<<o->getType());
+			return false;
+		}
+
+	}
+
+	// All other 
+
+	return true;
+}
+
+}
+
 ::Object * XRefWriter::changeTrailer(const char * name, ::Object * value)
 {
+	if (!name || !value)
+	{
+		kernelPrintDbg(DBG_ERR, "Invalid parameters. name="<<((name)?name:"NULL")
+				<<" value="<<(const void*)value);
+		throw ElementBadTypeException("");
+	}
 	kernelPrintDbg(DBG_DBG, "name="<<name);
-	if(revision)
+
+	check_need_credentials(this);
+
+	if(isEncrypted())
+	{
+		kernelPrintDbg(DBG_ERR, "Document is encrypted. Changing content is not supported");
+		throw NotImplementedException("changeObject is not implemented for encryted document");
+	}
+
+	if(!utils::isLatestRevision(*this))
 	{
 		// we are in later revision, so no changes can be
 		// done
@@ -240,32 +386,39 @@ void XRefWriter::changeObject(int num, int gen, ::Object * obj)
 	// direct - we are in trailer
 	if(mode==paranoid)
 	{
-		::Object original;
-		
 		kernelPrintDbg(DBG_DBG, "mode=paranoid type safety is checked");
-		// gets original value of value
-		Dict * dict=trailerDict.getDict();
-		dict->lookupNF(name, &original);
-		bool safe=typeSafe(&original, value);
-		original.free();
-		if(!safe)
-		{
-			kernelPrintDbg(DBG_ERR, "type safety error");
-			throw ElementBadTypeException(name);
-		}
+ 
+ 		if(!utils::canChangeTrailerEntry(name))
+ 		{
+ 			throw ElementBadTypeException("banned field");
+ 		}
+ 
+ 		if(!utils::typeSafeTrailerEntry(name, *value, *this))
+  		{
+  			throw ElementBadTypeException(name);
+  		}
 	}
 
 	// everything ok
 	return CXref::changeTrailer(name, value);
 }
 
+RefState XRefWriter::knowsRef(const IndiRef& ref)const
+{
+	::Ref xpdfRef={ref.num, ref.gen};
+	// otherwise use XRef directly
+	return knowsRef(xpdfRef);
+}
+
 ::Ref XRefWriter::reserveRef()
 {
 	kernelPrintDbg(DBG_DBG, "");
 
+	check_need_credentials(this);
+
 	// checks read-only mode
 	
-	if(revision)
+	if(!utils::isLatestRevision(*this))
 	{
 		// we are in later revision, so no changes can be
 		// done
@@ -289,9 +442,11 @@ void XRefWriter::changeObject(int num, int gen, ::Object * obj)
 {
 	kernelPrintDbg(DBG_DBG, "type="<<type);
 
+	check_need_credentials(this);
+
 	// checks read-only mode
 	
-	if(revision)
+	if(!utils::isLatestRevision(*this))
 	{
 		// we are in later revision, so no changes can be
 		// done
@@ -305,6 +460,12 @@ void XRefWriter::changeObject(int num, int gen, ::Object * obj)
 		throw ReadOnlyDocumentException("Document is in Read-only mode.");
 	}
 
+	if(isEncrypted())
+	{
+		kernelPrintDbg(DBG_ERR, "Document is encrypted. Changing content is not supported");
+		throw NotImplementedException("changeObject is not implemented for encryted document");
+	}
+
 	// changes are availabe
 	// delegates to CXref
 	return CXref::createObject(type, ref);
@@ -312,17 +473,19 @@ void XRefWriter::changeObject(int num, int gen, ::Object * obj)
 
 void XRefWriter::saveChanges(bool newRevision)
 {
-using namespace utils;
+	using namespace utils;
 
 	kernelPrintDbg(DBG_DBG, "");
 
+	check_need_credentials(this);
+
 	if(linearized)
 		kernelPrintDbg(DBG_WARN, "Pdf is linearized and changes may break rules for linearization.");
 
 	// if changedStorage is empty, there is nothing to do
 	if(changedStorage.size()==0)
 	{
-		kernelPrintDbg(DBG_INFO, "Nothing to be saved - changedStorage is empty");
+		kernelPrintDbg(DBG_DBG, "Nothing to be saved - changedStorage is empty");
 		return;
 	}
 	// checks if we have pdf content writer
@@ -339,21 +502,28 @@ using namespace utils;
 
 	// gets vector of all changed objects
 	IPdfWriter::ObjectList changed;
-	ObjectStorage< ::Ref, ObjectEntry *, xpdf::RefComparator>::Iterator i;
+	ChangedStorage::Iterator i;
 	for(i=changedStorage.begin(); i!=changedStorage.end(); ++i)
 	{
 		::Ref ref=i->first;
 		Object * obj=i->second->object;
-		changed.push_back(IPdfWriter::ObjectElement(ref, obj));
+		// for sake of paranoia we should send clones and not the
+		// object itself to writer which is allowed to alter object
+		changed.push_back(IPdfWriter::ObjectElement(ref, obj->clone()));
 	}
 
 	// delegates writing to pdfWriter using streamWriter stream from storePos
-	// position.
-	// Stores position of the cross reference section to xrefPos
+	// position and frees all clones from changed storage.
 	pdfWriter->writeContent(changed, *streamWriter, storePos);
+	for(IPdfWriter::ObjectList::iterator i=changed.begin(); i!=changed.end(); ++i){
+		Object *o = i->second;
+		xpdf::freeXpdfObject(o);
+	}
+
+	// Stores position of the cross reference section to xrefPos
 	size_t xrefPos=streamWriter->getPos();
-	IPdfWriter::PrevSecInfo secInfo={lastXRefPos, XRef::getNumObjects()};
-	size_t newEofPos=pdfWriter->writeTrailer(trailerDict, secInfo, *streamWriter);
+	IPdfWriter::PrevSecInfo secInfo={lastXRefPos, XRef::maxObj+1};
+	size_t newEofPos=pdfWriter->writeTrailer(*getTrailerDict(), secInfo, *streamWriter);
 
 	// if new revision should be created, moves storePos behind stored content
 	// (more preciselly before pdf end of file marker %%EOF) and forces CXref 
@@ -361,7 +531,8 @@ using namespace utils;
 	// now.
 	if(newRevision)
 	{
-		kernelPrintDbg(DBG_INFO, "Saving changes as new revision.");
+		kernelPrintDbg(DBG_INFO, "Saving changes as new revision number "
+				<<revisions.size()+1);
 		storePos=newEofPos;
 		kernelPrintDbg(DBG_DBG, "New storePos="<<storePos);
 
@@ -369,9 +540,10 @@ using namespace utils;
 		// last xref position
 		CXref::reopen(xrefPos);
 
-		// new revision number is added - we insert the newest revision so
-		// xrefPos value is stored
-		revisions.insert(revisions.begin(), xrefPos);
+		// new revision number is added and current revision is updated - 
+		// we insert the newest revision so xrefPos value is stored
+		revisions.push_back(xrefPos);
+		revision = revisions.size()-1;
 	}
 
 	kernelPrintDbg(DBG_DBG, "finished");
@@ -389,7 +561,7 @@ using namespace utils;
  */
 size_t getPrevFromTrailer(Object * trailer)
 {
-	Dict * trailerDict = NULL;
+	const Dict * trailerDict = NULL;
 	if(trailer->isDict())
 		trailerDict = trailer->getDict();
 	else if(trailer->isStream())
@@ -403,19 +575,18 @@ size_t getPrevFromTrailer(Object * trailer)
 
 	// gets prev field from current trailer and if it is null object (not
 	// present) or doesn't have integer value, jumps out of loop
-	Object prev;
-	trailerDict->lookupNF("Prev", &prev);
-	if(prev.getType()!=objInt)
+	boost::shared_ptr< ::Object> prev(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
+	trailerDict->lookupNF("Prev", prev.get());
+	if(prev->getType()!=objInt)
 	{
 		kernelPrintDbg(DBG_DBG, "Prev doesn't have int value. type="
-				<<prev.getType()<<
+				<<prev->getType()<<
 				". Assuming no more revisions.");
-		prev.free();
 		return ERR_OFFSET;
 	}
 
 	// releases prev because we don't need it anymore
-	int value=prev.getInt();
+	int value=prev->getInt();
 	if(value<0)
 		return ERR_OFFSET;
 	return value;
@@ -425,7 +596,7 @@ int XRefWriter::getOldStyleTrailer(Object * trailer, size_t off)
 {
 	// old style cross reference table, we have to skip whole table and
 	// then we will get to trailer
-	kernelPrintDbg(DBG_INFO, "New old style cross reference section found. off="<<off);
+	kernelPrintDbg(DBG_DBG, "New old style cross reference section found. off="<<off);
 	
 	// searches for TRAILER_KEYWORD to be able to parse older trailer (one
 	// for xref on off position) - this works only for oldstyle XRef tables
@@ -460,10 +631,16 @@ int XRefWriter::getOldStyleTrailer(Object * trailer, size_t off)
 
 			// deallocates previous one before it is filled by new one
 			trailer->free();
-			parser.getObj(trailer);
+			if(!parser.getObj(trailer))
+			{
+				kernelPrintDbg(DBG_ERR, "Unable to parse trailer");
+				return -1;
+			}
 			if(!trailer->isDict())
 			{
-				kernelPrintDbg(DBG_ERR, "Trailer is not dictionary.");
+				kernelPrintDbg(DBG_ERR, "Trailer is not dictionary. (type="
+						<<trailer->getType() << ")");
+				trailer->free();
 				return -1;
 			}
 
@@ -478,24 +655,25 @@ int XRefWriter::getOldStyleTrailer(Object * trailer, size_t off)
 	return -1;
 }
 
+// TODO is this ok for encrypted documents (streams should be encrypted there -
+// but how is this handled in trailer)?
 int XRefWriter::getStreamTrailer(Object * trailer, size_t off, ::Parser & parser)
 {
 	// gen number should follow
-	::Object obj;
-	parser.getObj(&obj);
-	if(!obj.isInt())
+	boost::shared_ptr< ::Object> obj(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
+	if(!parser.getObj(obj.get()))
+		goto malformedErr;
+	if(!obj->isInt())
 		goto bad_header;
-	// We don't need to free obj here, because int is not
-	// allocated internally
-	// end of indirect object header is obj key word
-	parser.getObj(&obj);
-	if(!obj.isCmd("obj"))
+	if(!parser.getObj(obj.get()))
+		goto malformedErr;
+	if(!obj->isCmd("obj"))
 		goto bad_header;
 
 	// header of indirect object is ok, so parse trailer object
-	obj.free();
 	trailer->free();
-	parser.getObj(trailer);
+	if(!parser.getObj(trailer))
+		goto malformedErr;
 	if(!trailer->isStream())
 	{
 		kernelPrintDbg(DBG_ERR, "Trailer is supposed to be stream, but "
@@ -505,12 +683,13 @@ int XRefWriter::getStreamTrailer(Object * trailer, size_t off, ::Parser & parser
 	
 	// xref stream object contains also trailer information, so parses
 	// stream object and uses just dictionary part
-	kernelPrintDbg(DBG_INFO, "New xref stream section. off="<<off);
+	kernelPrintDbg(DBG_DBG, "New xref stream section. off="<<off);
 	return 0;
-
+malformedErr:
+	kernelPrintDbg(DBG_ERR, "Unable to parse trailer");
+	return -1;
 bad_header:
 	kernelPrintDbg(DBG_ERR, "Trailer header corrupted.");
-	obj.free();
 	return -1;
 }
 
@@ -523,6 +702,9 @@ void XRefWriter::collectRevisions()
 
 	// linearized pdf doesn't support multiversion document clearly, so we don't
 	// implement collecting for such documents
+	// FIXME we might not have linearized flag set at the moment, because
+	// checkLinearized is not called for encrypted documents without credentials
+	// available. How to handle properly?
 	if(isLinearized())
 	{
 		// creates just one revision information with the newest one
@@ -539,30 +721,57 @@ void XRefWriter::collectRevisions()
 	}
 
 	// uses deep copy to prevent problems with original data
-	Object * trailer=XRef::trailerDict.clone();
+	Object * trailer = XRef::getTrailerDict()->clone();
 	if(!trailer)
 	{
 		kernelPrintDbg(DBG_ERR, "Unable to clone trailer. Ignoring revision collecting.");
 		return;
 	}
 
+	bool hybrid_xref = false;
 	do
 	{
-		// process current trailer (store offset and get previous
-		// if present) - we are starting with the newest one cloned
-		// above
-		kernelPrintDbg(DBG_DBG, "XRef offset for "<<
-				revisions.size()<<" revision is "<<off);
-		revisions.push_back(off);
+		// Take care about hybrid files which makes situation little bit more 
+		// complex, because these documents usually contain 2 sections to 
+		// describe one revision. The last (most recent one) has xref with no
+		// entries and trailer has /Prev pointing to the xref table and XRefStm
+		// pointing to the xref stream (PDFReference16.pdf: Chapter 3, 
+		// Compatibility with PDF 1.4). The pervious contains referred xrefs.
+		// This, however, doesn't mean that the document has 2 revisions so
+		// don't add them in such a case.
+		if (!hybrid_xref)
+		{
+			// process current trailer (store offset and get previous
+			// if present) - we are starting with the newest one cloned
+			// above
+			kernelPrintDbg(DBG_DBG, "XRef offset for "<<
+					revisions.size()<<" revision is "<<off);
+
+			revisions.insert(revisions.begin(), off);
+		}
 		off = getPrevFromTrailer(trailer);
 		if(isERR_OFFSET(off))
 			// no more previous trailers
 			break;
+		
+		hybrid_xref = false;
+		Object stm;
+		trailer->dictLookupNF("XRefStm", &stm);
+		if (stm.isInt())
+		{
+			kernelPrintDbg(DBG_INFO, "Document contains hybrid-file XREF.");
+			hybrid_xref = true;
+		}else if (!stm.isNull())
+		{
+			kernelPrintDbg(DBG_WARN, "Unexpected value for XRefStm trailer entry with type "
+					<< stm.getType());
+		}
+		stm.free();
 
 		// checks whether given offset is already in revisions, which 
 		// would mean corrupted referencies (because of cycle in 
 		// trailers)
-		if(std::find(revisions.begin(), revisions.end(), 
+		if(!hybrid_xref && std::find(revisions.begin(), revisions.end(), 
 					(size_t)off) != revisions.end())
 		{
 			kernelPrintDbg(DBG_ERR, "Trailer Prev points to already"
@@ -573,30 +782,34 @@ void XRefWriter::collectRevisions()
 
 		// off is the first byte of a cross reference section. 
 		// It can be either xref key word or beginning of the 
-		// xref stream object
+		// xref stream object - we have to process it even for
+		// hybrid_xref case becase this can contain reference to
+		// the previous revision
 		str->setPos(off);
-		Object parseObj, obj;
+		Object parseObj; 
+		boost::shared_ptr< ::Object> obj(XPdfObjectFactory::getInstance(), xpdf::object_deleter());
 		::Parser parser = Parser(this,
 			new Lexer(NULL, str->makeSubStream(str->getPos(), gFalse, 0, &parseObj)),
 			gTrue
 			);
-		parser.getObj(&obj);
-		if(obj.isCmd(XREF_KEYWORD))
+		if(!parser.getObj(obj.get()))
+		{
+			kernelPrintDbg(DBG_ERR, "Unable to parse stream");
+			throw MalformedFormatExeption("parse data stream");
+		}
+		if(obj->isCmd(XREF_KEYWORD))
 		{
-			obj.free();
 			if(getOldStyleTrailer(trailer, off)<0)
 				break;
-		}else if(obj.isInt())
+		}else if(obj->isInt())
 		{
 			// xref key work no found, it may be xref stream object
 			// gen number should follow
-			obj.free();
 			if(getStreamTrailer(trailer, off, parser))
 				break;
 		}else {
 			kernelPrintDbg(DBG_ERR, "Bad trailer definition. Dictionary or stream"
-					"expected, but "<<obj.getType()<<"found");
-			obj.free();
+					"expected, but "<<obj->getType()<<"found");
 			break;
 		}
 	// continues only if no problem with trailer occures
@@ -607,18 +820,22 @@ void XRefWriter::collectRevisions()
 	trailer->free();
 	gfree(trailer);
 
+	// initiailizes the current revision to the most recent one.
+	revision = revisions.size()-1;
 	kernelPrintDbg(DBG_INFO, "This document contains "<<revisions.size()<<" revisions.");
 }
 
 void XRefWriter::changeRevision(unsigned revNumber)
 {
 	kernelPrintDbg(DBG_DBG, "revNumber="<<revNumber);
+
+	check_need_credentials(this);
 	
 	// change to same revision
 	if(revNumber==revision)
 	{
 		// nothing to do, we are already here
-		kernelPrintDbg(DBG_INFO, "Revision changed to "<<revNumber);
+		kernelPrintDbg(DBG_INFO, "Revision kept at "<<revNumber);
 		return;
 	}
 
@@ -637,8 +854,9 @@ void XRefWriter::changeRevision(unsigned revNumber)
 	
 	// forces CXRef to reopen from revisions[revNumber] offset
 	// which points to start of xref section for that revision
+	// and forces keeping all changes
 	size_t off=revisions[revNumber];
-	reopen(off);
+	reopen(off, false);
 
 	// everything ok, so current revision can be set
 	revision=revNumber;
@@ -679,7 +897,15 @@ void XRefWriter::cloneRevision(FILE * file)const
 {
 using namespace debug;
 
-	kernelPrintDbg(DBG_ERR, "");
+	kernelPrintDbg(DBG_DBG, "");
+
+	check_need_credentials(this);
+
+	if(isEncrypted())
+	{
+		kernelPrintDbg(debug::DBG_WARN, "Operation is not supported for encrypted documents");
+		throw NotImplementedException("cloneRevision");
+	}
 
 	StreamWriter * streamWriter=dynamic_cast<StreamWriter *>(str);
 	size_t pos=streamWriter->getPos();
@@ -710,15 +936,22 @@ using namespace debug;
 
 	kernelPrintDbg(DBG_DBG, "rev="<<rev<<" includeXref="<<includeXref);
 
+	// constrains check
+	if(rev>revisions.size()-1)
+	{
+		kernelPrintDbg(DBG_ERR, "unkown revision with number="<<rev);
+		throw OutOfRange();
+	}
+	
 	// gets starting position of current rev
 	size_t revStart=revisions[rev];
 	size_t prevEnd=0;
 
-	// gets end of previous rev - if no exists keeps default value 0 (from
-	// the stream beginning)
-	if(rev+1<getRevisionCount())
+	// gets the end of the previous rev - keeps default value 0 (from
+	// the stream beginning) if there is no other revision
+	if(rev>0)
 	{
-		prevEnd=getRevisionEnd(revisions[rev+1]);
+		prevEnd=getRevisionEnd(revisions[rev-1]);
 		kernelPrintDbg(DBG_DBG, "Previous revision ends at "<<prevEnd);
 	}else
 		kernelPrintDbg(DBG_DBG, "No previous rev.");
