@@ -24,6 +24,8 @@
 // vim:tabstop=4:shiftwidth=4:noexpandtab:textwidth=80
 
 #include "kernel/static.h"
+#include "xpdf/PDFDoc.h"
+#include "kernel/cstreamsxpdfreader.h"
 #include "tests/kernel/testmain.h"
 #include "tests/kernel/testcobject.h"
 #include "tests/kernel/testcpage.h"
@@ -306,6 +308,11 @@ opcount (UNUSED_PARAM	ostream& oss, const char* fileName)
 	boost::shared_ptr<CPdf> pdf = getTestCPdf (fileName);
 	/// Intermezzo
 	boost::scoped_ptr<PDFDoc> doc  (new PDFDoc (new GString(fileName), NULL, NULL));
+	if(!doc->isOk())
+	{
+		std::cout << "Bad PDF document: " << fileName << flush;
+		return false;
+	}
 
 	for (size_t i = 0; i < pdf->getPageCount() && i < TEST_MAX_PAGE_COUNT; ++i)
 	{
