@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -135,9 +135,8 @@ c_getTp ()
 bool
 mdctrl (const char* filename)
 {
-	boost::shared_ptr<CPdf> _pdf (getTestCPdf (filename), pdf_deleter ());
-	CPdf& pdf = *_pdf;
-	pdf.getModeController ();
+	boost::shared_ptr<CPdf> _pdf = getTestCPdf (filename);
+	_pdf->getModeController ();
 
 	return true;
 }
@@ -499,7 +498,7 @@ c_xpdfctor (const char* filename)
 		// Array
 		//
 		Object obj;
-		obj.initArray (NULL);
+		obj.initArray ((XRef*)NULL);
 
 		Object item1; item1.initBool	(gFalse);
 		Object item2; item2.initBool	(gTrue);
@@ -511,8 +510,7 @@ c_xpdfctor (const char* filename)
 		obj.arrayAdd (&item3);
 		obj.arrayAdd (&item4);
 		
-		boost::shared_ptr<CPdf> _pdf (getTestCPdf (filename), pdf_deleter());
-		CPdf& pdf = *_pdf;
+		boost::shared_ptr<CPdf> pdf = getTestCPdf (filename);
 		IndiRef ref (12,11);
 		CArray ar (pdf,obj,ref);
 
@@ -541,8 +539,7 @@ c_xpdfctor (const char* filename)
 		obj.dictAdd (it3, &item3);
 		obj.dictAdd (it4, &item4);
 
-		boost::shared_ptr<CPdf> _pdf (getTestCPdf (filename), pdf_deleter());
-		CPdf& pdf = *_pdf;
+		boost::shared_ptr<CPdf> pdf = getTestCPdf (filename);
 
 		IndiRef ref (12,11);
 		// CArray ar (pdf,obj,ref); // GOOOOOD -- assertation failed
@@ -620,7 +617,7 @@ namespace{
 bool
 c_forEach (std::ostream& oss, const char* filename)
 {
-	boost::shared_ptr<CPdf> pdf (getTestCPdf (filename), pdf_deleter());
+	boost::shared_ptr<CPdf> pdf = getTestCPdf (filename);
 	if (0 < pdf->getPageCount())
 	{
 		boost::shared_ptr<CPage> page = pdf->getPage (1);
