@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -89,7 +89,7 @@ public:
 	{
 	}
 
-	void cloneTC(CPdf * pdf, string & originalFile)
+	void cloneTC(boost::shared_ptr<CPdf> pdf, string & originalFile)
 	{
 		printf("%s\n", __FUNCTION__);
 
@@ -113,7 +113,9 @@ public:
 		#endif
 		
 		printf("TC02:\tCloning of later revisions.\n");
-		for(CPdf::revision_t rev=1; rev<pdf->getRevisionsCount(); rev++)
+		int count;
+		for(CPdf::revision_t rev=pdf->getRevisionsCount()-1, count=pdf->getRevisionsCount(); 
+				count>0; rev--,count--)
 		{
 			try
 			{
@@ -134,13 +136,13 @@ public:
 			}
 		}
 		// gets back to the newest revision
-		pdf->changeRevision(0);
+		pdf->changeRevision(pdf->getRevisionsCount()-1);
 
 		printf("TC03:\t cloning doesn't change content test\n");
 		CPPUNIT_ASSERT(!pdf->isChanged());
 	}
 	
-	void pageIterationTC(CPdf * pdf)
+	void pageIterationTC(boost::shared_ptr<CPdf> pdf)
 	{
 	using namespace boost;
 	using namespace utils;
@@ -264,7 +266,7 @@ public:
 		XRef * fakeXref=pdf->getCXref();
 		fakeXpdfDict.initDict(fakeXref);
 		IndiRef fakeIndiRef(10, 0);
-		shared_ptr<CDict> fakeDict2(CDictFactory::getInstance(*pdf, fakeIndiRef, fakeXpdfDict));
+		shared_ptr<CDict> fakeDict2(CDictFactory::getInstance(pdf, fakeIndiRef, fakeXpdfDict));
 		shared_ptr<CPage> fake2(new CPage(fakeDict2));
 		fakeXpdfDict.free();
 
@@ -331,12 +333,17 @@ public:
 		CPPUNIT_ASSERT(!pdf->isChanged());
 	}
 
-	void pageManipulationTC(CPdf * pdf)
+	void pageManipulationTC(boost::shared_ptr<CPdf> pdf)
 	{
 	using namespace boost;
 	using namespace utils;
 
 		printf("%s\n", __FUNCTION__);
+		if(pdf->isLinearized())
+		{
+			printf("Usecase is not suitable becuase document is linearized\n");
+			return;
+		}
 
 		size_t pageCount=pdf->getPageCount();
 		if (0 == pageCount)
@@ -344,10 +351,9 @@ public:
 			printf("TC01:\tinsertPage to an empty document results in 1 total pages\n");
 			if (0 < TestParams::instance().files.size())
 			{
-				CPdf * test_doc = getTestCPdf(TestParams::instance().files.front().c_str());
+				boost::shared_ptr<CPdf> test_doc = getTestCPdf(TestParams::instance().files.front().c_str());
 				pdf->insertPage(test_doc->getFirstPage(), 1);
 				CPPUNIT_ASSERT(pdf->getPageCount()==1);
-				test_doc->close();
 			}
 			return;
 		}
@@ -359,17 +365,12 @@ public:
 		CPPUNIT_ASSERT(pageCount-1==pdf->getPageCount());
 
 		// insert page implies pageCount incrementation
-		// and newPage must be different instance than original one
 		shared_ptr<CPage> newPage=pdf->insertPage(page, 1);
 		CPPUNIT_ASSERT(pageCount==pdf->getPageCount());
 
-		printf("TC02:\tinsertPage returns different instance than parameter\n");
-		CPPUNIT_ASSERT(page!=newPage);
-		CPPUNIT_ASSERT(page->getDictionary()!=newPage->getDictionary());
-
 		// page count is same as in original file now
 
-		printf("TC03:\tremovePage out of range test\n");
+		printf("TC02:\tremovePage out of range test\n");
 		// remove from 0 page should fail
 		try
 		{
@@ -389,23 +390,24 @@ public:
 			// everything ok
 		}
 
-		printf("TC04:\tinsert page never causes ambiguous page tree\n");
-		// inserts first page again and tries to to call getNodePosition
-		shared_ptr<CPage> addedPage=pdf->insertPage(pdf->getFirstPage(), 1);
-		size_t pos=getNodePosition(*pdf, addedPage->getDictionary(), NULL);
-		CPPUNIT_ASSERT(pos==1);
-		// removes added page
-		pdf->removePage(pos);
+		printf("TC03:\tinsert of already present page should fail\n");
+		try
+		{
+			shared_ptr<CPage> addedPage=pdf->insertPage(pdf->getFirstPage(), 1);
+			CPPUNIT_FAIL("Insert of already present page should have failed");
+		}catch(AmbiguousPageTreeException &)
+		{
+			// everything ok
+		}
 
-		printf("TC05:\tremoved page is no longer available test\n");
+		printf("TC04:\tremoved page is no longer available test\n");
 		// try to remove last page
 		shared_ptr<CPage> removedPage=pdf->getLastPage();
 		IndiRef removedPageRef=removedPage->getDictionary()->getIndiRef();
-		pos=pdf->getPagePosition(removedPage);
+		size_t pos=pdf->getPagePosition(removedPage);
 		CPPUNIT_ASSERT(pos==pdf->getPageCount());
 		pdf->removePage(pdf->getPageCount());
-		// FIXME uncoment when ready
-		//CPPUNIT_ASSERT(! removePage->isValid());
+		CPPUNIT_ASSERT(! removedPage->isValid());
 		try
 		{
 			pos=pdf->getPagePosition(removedPage);
@@ -417,7 +419,7 @@ public:
 		// restore to previous state
 		pdf->insertPage(removedPage, pos);
 		
-		printf("TC06:\tremoving page's dictionary invalidates page\n");
+		printf("TC05:\tremoving page's dictionary invalidates page\n");
 		pos=pdf->getPageCount()/2;
 		// if we have just one page, use it
 		if(!pos)
@@ -438,8 +440,7 @@ public:
 		CPPUNIT_ASSERT(positions.size()>0);
 		// we know that position is not ambiguous so use 1st in positions array
 		kidsArray->delProperty(positions[0]);
-		// FIXME uncoment when ready
-		//CPPUNIT_ASSERT(! page->isValid());
+		CPPUNIT_ASSERT(! page->isValid());
 		try
 		{
 			pdf->getPagePosition(page);
@@ -454,7 +455,7 @@ public:
 		// uses 1st internode kid from page tree root dictionary
 		shared_ptr<CDict> interNode;
 		shared_ptr<CRef> interNodeCRef;
-		shared_ptr<CDict> rootDict=getPageTreeRoot(*pdf);
+		shared_ptr<CDict> rootDict=getPageTreeRoot(pdf);
 		shared_ptr<IProperty> rootKidsProp=rootDict->getProperty("Kids");
 		shared_ptr<CArray> rootKids;
 		if(isRef(rootKidsProp))
@@ -510,13 +511,13 @@ public:
 			for(size_t i=1; i<=pageCount; i++)
 			{
 				shared_ptr<CPage> page=pdf->getPage(i);	
-				if(isDescendant(*pdf, interNode->getIndiRef(), page->getDictionary()))
+				if(isNodeDescendant(pdf, interNode->getIndiRef(), page->getDictionary()))
 					descendants.push_back(page);
 			}
 
 			// all descendants are collected, we can remove interNode reference
 			// from rootKids
-			printf("TC07:\tremovig inter node removes all pages under\n");
+			printf("TC06:\tremovig inter node removes all pages under\n");
 			rootKids->delProperty(interPos);
 
 			// page count has to be decreased by descendants.size()
@@ -538,7 +539,7 @@ public:
 			// inserts back interNode to 1st position in root kids array
 			// currently first page should be at 1+getKidsCount (if there is any
 			// page);
-			printf("TC08:\tinserting intermediate node test.\n");
+			printf("TC07:\tinserting intermediate node test.\n");
 			shared_ptr<CPage> firstPage, lastPage;
 			size_t currPageCount=pdf->getPageCount();
 			if(currPageCount)
@@ -556,7 +557,7 @@ public:
 				CPPUNIT_ASSERT(pdf->getPagePosition(lastPage) == interNodeLeafCount + currPageCount);
 
 			
-			printf("TC09:\treplacing intermediate node by another intermediate node\n");
+			printf("TC08:\treplacing intermediate node by another intermediate node\n");
 			// gets CRef of firts root's kid (one we have inserted)
 			shared_ptr<CRef> replaceElement=IProperty::getSmartCObjectPtr<CRef>(rootKids->getProperty(0));
 			// change value in replaceElement to contain reference to newly
@@ -573,7 +574,7 @@ public:
 
 			// TODO Kids array as reference to array/mess, 
 
-			printf("TC13:\tambiguous page tree test - ambiguous intermediate node\n");
+			printf("TC09:\tambiguous page tree test - ambiguous intermediate node\n");
 			// inserts reference to interNode to rootKids - this produces
 			// ambiguous page tree for this intermediate node - despite that all
 			// pages should be accessible
@@ -583,7 +584,7 @@ public:
 			CPPUNIT_ASSERT(pdf->getPageCount()==currPageCount+getKidsCount(interNode,NULL));
 			try
 			{
-				getNodePosition(*pdf, interNode, NULL);
+				getNodePosition(pdf, interNode, NULL);
 				CPPUNIT_FAIL("getNodePosition should have failed");
 			}catch(AmbiguousPageTreeException & e)
 			{
@@ -595,7 +596,7 @@ public:
 				shared_ptr<CPage> page=pdf->getFirstPage();
 				while(pdf->hasNextPage(page))
 					page=pdf->getNextPage(page);
-			}catch(exception & e)
+			}catch(std::exception & e)
 			{
 				CPPUNIT_FAIL("page iteration methods shouldn't failed");
 			}
@@ -603,7 +604,7 @@ public:
 			rootKids->delProperty(rootKids->getPropertyCount()-1);
 			CPPUNIT_ASSERT(pdf->getPageCount()==currPageCount);
 			
-			printf("TC14:\tambiguous page tree test - ambiguous leaf node\n");
+			printf("TC10:\tambiguous page tree test - ambiguous leaf node\n");
 			// gets parent of first page
 			firstPage=pdf->getFirstPage();
 			shared_ptr<CDict> parentDict=getCObjectFromRef<CDict>(
@@ -627,7 +628,7 @@ public:
 			}
 			try
 			{
-				getNodePosition(*pdf, firstPage->getDictionary(), NULL);
+				getNodePosition(pdf, firstPage->getDictionary(), NULL);
 				CPPUNIT_FAIL("getNodePosition should have failed for ambiguous page dictionary.");
 			}catch(AmbiguousPageTreeException & e)
 			{
@@ -637,7 +638,7 @@ public:
 			{
 				for(size_t pos=1; pos<pdf->getPageCount(); pos++)
 					page=pdf->getPage(pos);
-			}catch(exception & e)
+			}catch(std::exception & e)
 			{
 				CPPUNIT_FAIL("page iteration methods shouldn't failed");
 			}
@@ -647,18 +648,18 @@ public:
 			// gets back to unambiguous state
 			parentKids->delProperty(parentKids->getPropertyCount()-1);
 			CPPUNIT_ASSERT(pdf->getPageCount()==currPageCount);
-			getNodePosition(*pdf, firstPage->getDictionary(), NULL);
+			getNodePosition(pdf, firstPage->getDictionary(), NULL);
 		}
 
 		// checks PageTreeRootObserver for all possible situations: Pages
 		// property (add, delete or change and Pages reference change)
-		printf("TC10:\tremoving page tree root test\n");
-		shared_ptr<CDict> pageTreeRoot=getPageTreeRoot(*pdf);
+		printf("TC11:\tremoving page tree root test\n");
+		shared_ptr<CDict> pageTreeRoot=getPageTreeRoot(pdf);
 		size_t currPageCount=pdf->getPageCount();
 		pdf->getDictionary()->delProperty("Pages");
 		CPPUNIT_ASSERT(pdf->getPageCount()==0);
 
-		printf("TC11:\tadding wrong page tree root element\n");
+		printf("TC12:\tadding wrong page tree root element\n");
 		shared_ptr<IProperty> fakeInterCRef(CRefFactory::getInstance(fakeInterRef));
 		pdf->getDictionary()->addProperty("Pages", *fakeInterCRef);
 		CPPUNIT_ASSERT(pdf->getPageCount()==0);
@@ -679,7 +680,7 @@ public:
 			/* ok */
 		}
 
-		printf("TC12:\treplacing page tree root test\n");
+		printf("TC13:\treplacing page tree root test\n");
 		// creates new reference which points to some nonsense and changes Pages
 		// reference value
 		shared_ptr<CRef> pagesProp=IProperty::getSmartCObjectPtr<CRef>(pdf->getDictionary()->getProperty("Pages"));
@@ -696,6 +697,64 @@ public:
 		CPPUNIT_ASSERT(pdf->isChanged());
 	}
 
+	void linearizedTC(boost::shared_ptr<CPdf> pdf)
+	{
+		printf("%s\n", __FUNCTION__);
+		if(!pdf->isLinearized())
+		{
+			printf("Usecase is not suitable becuase document is not linearized\n");
+			return;
+		}
+		printf("TC01:\tPdf mustn't be modified\n");
+		CPPUNIT_ASSERT(!pdf->isChanged());
+		printf("TC02:\tAll modification methods have to fail with exception\n");
+		shared_ptr<CInt> prop(pdfobjects::CIntFactory::getInstance(1));
+		try
+		{
+			pdf->addIndirectProperty(prop);
+			CPPUNIT_FAIL("CPdf::addIndirectProperty should have failed");
+		}catch(ReadOnlyDocumentException e)
+		{
+			// ok should have failed
+		}
+		try
+		{
+			pdf->changeIndirectProperty(prop);
+			CPPUNIT_FAIL("CPdf::changeIndirectProperty should have failed");
+		}catch(ReadOnlyDocumentException e)
+		{
+			// ok should have failed
+		}
+		shared_ptr<CPage> page = pdf->getFirstPage();
+		try
+		{
+			pdf->insertPage(page, 1);
+			CPPUNIT_FAIL("CPdf::insertPage should have failed");
+		}catch(ReadOnlyDocumentException e)
+		{
+			// ok should have failed
+		}
+		try
+		{
+			pdf->removePage(1);
+			CPPUNIT_FAIL("CPdf::removePage should have failed");
+		}catch(ReadOnlyDocumentException e)
+		{
+			// ok should have failed
+		}
+		try
+		{
+			pdf->canChange();
+			CPPUNIT_FAIL("CPdf::canChange should have failed");
+		}catch(ReadOnlyDocumentException e)
+		{
+			// ok should have failed
+		}
+		
+		printf("TC03:\tLinearized document has only one revision\n");
+		CPPUNIT_ASSERT(pdf->getRevisionsCount() == 1);	
+	}
+
 /** Multiversion file name. */
 #define MV_F "multiversion.pdf"
 
@@ -721,7 +780,7 @@ public:
 
 		// opens special test file
 		printf("Using file \"%s\"\n", TestParams::add_path(MV_F).c_str());
-		CPdf *pdf=getTestCPdf(TestParams::add_path(MV_F).c_str());
+		boost::shared_ptr<CPdf> pdf=getTestCPdf(TestParams::add_path(MV_F).c_str());
 		CPdf::OpenMode mode=pdf->getMode();
 
 		// number of revision must match
@@ -736,15 +795,13 @@ public:
 		}
 
 		printf("TC03:\tgetPageCount for revision test\n");
-		// starts from the oldest one - each revision has number of pages one
-		// more than revision number
-		for(CPdf::revision_t i=pdf->getRevisionsCount()-1; ; i--)
+		// starts from the oldest one - each newer revision has one less
+		// page count
+		size_t page_count = pdf->getRevisionsCount();
+		for(CPdf::revision_t i=0; i<pdf->getRevisionsCount(); i++, page_count--)
 		{
 			pdf->changeRevision(i);
-			CPPUNIT_ASSERT(pdf->getPageCount()==i+1);
-			if(i==0)
-				break;
-			
+			CPPUNIT_ASSERT(pdf->getPageCount()==page_count);
 		}
 
 		printf("TC04:\tgetCXref::getNumObjects is same for all revisions\n");
@@ -764,21 +821,24 @@ public:
 		}
 
 		printf("TC05:\tolder revisions has to be readOnly\n");
-		for(CPdf::revision_t i=1; i<pdf->getRevisionsCount(); i++)
+		for(CPdf::revision_t i=0; i<pdf->getRevisionsCount()-1; i++)
 		{
 			pdf->changeRevision(i);
 			CPPUNIT_ASSERT(pdf->getMode()==CPdf::ReadOnly);
 		}
 
 		printf("TC06:\tThe newest revision has mode same as set in getInstace\n");
-		pdf->changeRevision(0);
+		pdf->changeRevision(pdf->getRevisionsCount()-1);
 		CPPUNIT_ASSERT(pdf->getMode()==mode);
 		
 		printf("TC07:\tno changes can be done in older revisions\n");
-		for(CPdf::revision_t i=1; i<pdf->getRevisionsCount(); i++)
+		for(CPdf::revision_t i=0; i<pdf->getRevisionsCount()-1; i++)
 		{
 			printf("\trevision=%d\n", i);
 			pdf->changeRevision(i);
+			XRefWriter* xref = dynamic_cast<XRefWriter *>(pdf->getCXref());
+			CPPUNIT_ASSERT(xref);
+			CPPUNIT_ASSERT(!utils::isLatestRevision(*xref));
 			
 			// addIndirectProperty
 			printf("\t\taddIndirectProperty\n");
@@ -804,8 +864,21 @@ public:
 		// isModified returns always false
 		printf("TC08:\tisChanged is allways false on unchanged document\n");
 		CPPUNIT_ASSERT(!pdf->isChanged());
-		
-		pdf->close();
+
+		printf("TC09:\tLatest revision allows changes\n");
+		pdf->changeRevision(pdf->getRevisionsCount()-1);
+		shared_ptr<IProperty> newProp(CIntFactory::getInstance(1));
+		IndiRef ref = pdf->addIndirectProperty(newProp);
+		shared_ptr<IProperty> prop = pdf->getIndirectProperty(ref);
+		CPPUNIT_ASSERT(prop->getType()==pInt);
+		CPPUNIT_ASSERT(utils::getValueFromSimple<CInt>(prop)==1);
+
+		printf("TC10:\tchange done to the latest revision is preserved\n");
+		pdf->changeRevision(0);
+		pdf->changeRevision(pdf->getRevisionsCount()-1);
+		prop = pdf->getIndirectProperty(ref);
+		CPPUNIT_ASSERT(prop->getType()==pInt);
+		CPPUNIT_ASSERT(utils::getValueFromSimple<CInt>(prop)==1);
 	}
 #undef TRY_READONLY_OP
 	
@@ -819,12 +892,17 @@ public:
 	}
 
 
-	void indirectPropertyTC(CPdf * pdf)
+	void indirectPropertyTC(boost::shared_ptr<CPdf> pdf)
 	{
 	using namespace boost;
 	using namespace utils;
 	
 		printf("%s\n", __FUNCTION__);
+		if(pdf->isLinearized())
+		{
+			printf("Usecase is not suitable becuase document is linearized\n");
+			return;
+		}
 
 		printf("TC01:\taddIndirectProperty with simple property with no pdf\n");
 		// creates new property and adds it
@@ -838,7 +916,7 @@ public:
 		// value must be same (we know that prop is CInt)
 		PropertyEquals pe;
 		CPPUNIT_ASSERT(pe(added, prop));
-		CPPUNIT_ASSERT(added->getPdf()==pdf);
+		CPPUNIT_ASSERT(added->getPdf().lock().get()==pdf.get());
 		CPPUNIT_ASSERT(added->getIndiRef()==addedRef);
 		printf("\t\tReference state is INITIALIZED_REF (according CXref::knowsRef)\n");
 		CPPUNIT_ASSERT(pdf->getCXref()->knowsRef(addedRef)==INITIALIZED_REF);
@@ -875,14 +953,14 @@ public:
 		added=pdf->getIndirectProperty(addedRef);
 		CPPUNIT_ASSERT(isDict(*added));
 		shared_ptr<CDict> addedDict=IProperty::getSmartCObjectPtr<CDict>(added);
-		CPPUNIT_ASSERT(added->getPdf()==pdf);
+		CPPUNIT_ASSERT(added->getPdf().lock().get()==pdf.get());
 		CPPUNIT_ASSERT(added->getIndiRef()==addedRef);
 		CPPUNIT_ASSERT(addedDict->getPropertyCount()==3);
 		CPPUNIT_ASSERT(isReal(*(addedDict->getProperty("Elem1"))));
 		CPPUNIT_ASSERT(isRef(*(addedDict->getProperty("Elem2"))));
 		// target of Elem2 has to be CNull
 		ref = getValueFromSimple<CRef>(addedDict->getProperty("Elem2"));
-		CPPUNIT_ASSERT(isNull(* pdf->getIndirectProperty(ref)));
+		CPPUNIT_ASSERT(isNull(*pdf->getIndirectProperty(ref)));
 		CPPUNIT_ASSERT(isArray(*(addedDict->getProperty("Elem3"))));
 
 		// adds the same dictionary, with followRef now!
@@ -899,7 +977,7 @@ public:
 		// target of Elem2 has to be CNull - it makes no sense to 
 		// dereference without document
 		ref = getValueFromSimple<CRef>(followAddedDict->getProperty("Elem2"));
-		CPPUNIT_ASSERT(isNull(* pdf->getIndirectProperty(ref)));
+		CPPUNIT_ASSERT(isNull(*pdf->getIndirectProperty(ref)));
 		CPPUNIT_ASSERT(isArray(*(followAddedDict->getProperty("Elem3"))));
 
 		printf("TC04:\taddIndirectProperty with CRef from same pdf\n");
@@ -922,14 +1000,14 @@ public:
 		// opens TEST_FILE
 		if (0 == TestParams::instance().files.size())
 			return;
-		CPdf * differentPdf=getTestCPdf(TestParams::instance().files.front().c_str());
+		boost::shared_ptr<CPdf> differentPdf=getTestCPdf(TestParams::instance().files.front().c_str());
 		// gets page dictionary which contains at least one reference (to its
 		// parent). addIndirectProperty with followRefs==false
 		shared_ptr<CDict> differentPageDict=differentPdf->getFirstPage()->getDictionary();
 		addedRef=pdf->addIndirectProperty(differentPageDict, false);
 		added=pdf->getIndirectProperty(addedRef);
 		CPPUNIT_ASSERT(added->getIndiRef()==addedRef);
-		CPPUNIT_ASSERT(added->getPdf()==pdf);
+		CPPUNIT_ASSERT(added->getPdf().lock().get()==pdf.get());
 		CPPUNIT_ASSERT(isDict(*added));
 		printf("\t\tReference state is INITIALIZED_REF (according CXref::knowsRef)\n");
 		CPPUNIT_ASSERT(pdf->getCXref()->knowsRef(addedRef)==INITIALIZED_REF);
@@ -963,13 +1041,13 @@ public:
 		CPPUNIT_ASSERT(addedRef==ref);
 		added=pdf->getIndirectProperty(addedRef);
 		CPPUNIT_ASSERT(added->getIndiRef()==addedRef);
-		CPPUNIT_ASSERT(added->getPdf()==pdf);
+		CPPUNIT_ASSERT(added->getPdf().lock().get()==pdf.get());
 		CPPUNIT_ASSERT(isDict(*added));
 		printf("\t\tReference state is INITIALIZED_REF (according CXref::knowsRef)\n");
 		CPPUNIT_ASSERT(pdf->getCXref()->knowsRef(addedRef)==INITIALIZED_REF);
 		addedDict=IProperty::getSmartCObjectPtr<CDict>(added);
 		CPPUNIT_ASSERT(addedDict->getPropertyCount()==differentPageDict->getPropertyCount());
-		differentPdf->close();
+		differentPdf.reset();
 
 		printf("TC07:\tgetIndirectProperty with uknown reference returns CNull\n");
 		// creates unknown reference from existing by adding 1 to generation
@@ -984,7 +1062,7 @@ public:
 		// creates fake and try to use changeIndirectProperty with unknownRef
 		Object obj;
 		obj.initInt(1);
-		shared_ptr<CInt> fakeInt(CIntFactory::getInstance(*pdf, unknownRef, obj));
+		shared_ptr<CInt> fakeInt(CIntFactory::getInstance(pdf, unknownRef, obj));
 		try
 		{
 			pdf->changeIndirectProperty(fakeInt);
@@ -997,7 +1075,7 @@ public:
 		printf("TC09:\tchangeIndirectProperty with bad typed parameter should fail\n");
 		// creates integer and tries to change value of Pages field which is
 		// reference
-		fakeInt=shared_ptr<CInt>(CIntFactory::getInstance(*pdf, pdf->getDictionary()->getProperty("Pages")->getIndiRef(), obj));
+		fakeInt=shared_ptr<CInt>(CIntFactory::getInstance(pdf, pdf->getDictionary()->getProperty("Pages")->getIndiRef(), obj));
 		try
 		{
 			pdf->changeIndirectProperty(fakeInt);
@@ -1027,7 +1105,7 @@ public:
 		changedIntProp.reset();
 		Object intXpdfObj;
 		intXpdfObj.initInt(0);
-		changedIntProp=shared_ptr<CInt>(CIntFactory::getInstance(*pdf, intPropRef, intXpdfObj));
+		changedIntProp=shared_ptr<CInt>(CIntFactory::getInstance(pdf, intPropRef, intXpdfObj));
 		pdf->changeIndirectProperty(changedIntProp);
 		// resets value and gets it again
 		changedIntProp.reset();
@@ -1050,7 +1128,7 @@ public:
 		IPdfWriter * writer=new OldStylePdfWriter();
 		ProgressBar * progressBar=new ProgressBar(cout);
 		writer->registerObserver(shared_ptr<PdfWriterObserver>(new ProgressObserver(progressBar)));
-		Delinearizator *delinearizator=Delinearizator::getInstance(fileName.c_str(), writer);
+		boost::shared_ptr<Delinearizator> delinearizator=Delinearizator::getInstance(fileName.c_str(), writer);
 		if(!delinearizator)
 		{
 			printf("\t%s is not suitable because it is not linearized.\n", fileName.c_str());
@@ -1059,7 +1137,184 @@ public:
 		string outputFile=fileName+"-delinearizator.pdf";
 		printf("\tDelinearized output is in %s file\n", outputFile.c_str());
 		delinearizator->delinearize(outputFile.c_str());
-		delete delinearizator;
+	}
+
+#define staticArraySize(array) sizeof(array)/sizeof(*array)
+	void changeTrailerTC(string& fname)
+	{
+		printf("%s\n", __FUNCTION__);
+		struct TestField {
+			const char *name;
+			// NULL means that all values are valid
+			::Object *validVal;
+		};
+		boost::shared_ptr<CPdf> pdf1 = getTestCPdf(fname.c_str());
+		if (pdf1->getMode() == CPdf::ReadOnly)
+		{
+			printf("%s: Document is read only and it is not usable for this test\n", __FUNCTION__);
+			return;
+		}
+		boost::shared_ptr<CPdf> pdf2 = getTestCPdf(fname.c_str(), CPdf::Advanced);
+		XRefWriter *xref1 = dynamic_cast<XRefWriter *>(pdf1->getCXref());
+		XRefWriter *xref2 = dynamic_cast<XRefWriter *>(pdf2->getCXref());
+
+		Object oNull;
+		oNull.initNull();
+		Object oInt;
+		oInt.initInt(1);
+		Object oRef;
+		oRef.initRef(1,0);
+		Object oDict;
+		oDict.initDict(xref1);
+		Object oArray;
+		oArray.initArray(xref1);
+		Object oStream;
+		Stream *str= new MemStream((char*)malloc(sizeof(char)*10), 0, 10, &oDict, true);
+		oStream.initStream(str);
+
+		printf("\tNULL value is not allowed\n");
+		try
+		{
+			xref1->changeTrailer("Foo", NULL);
+			CPPUNIT_FAIL("changeTrailer(\"Foo\", NULL) should fail");
+		}catch(ElementBadTypeException )
+		{
+		}
+		try
+		{
+			xref1->changeTrailer(NULL, NULL);
+			CPPUNIT_FAIL("changeTrailer(NULL, NULL) should fail");
+		}catch(ElementBadTypeException )
+		{
+		}
+		try
+		{
+			xref1->changeTrailer(NULL, &oInt);
+			CPPUNIT_FAIL("changeTrailer(null, obj) should fail");
+		}catch(ElementBadTypeException )
+		{
+		}
+		try
+		{
+			xref2->changeTrailer("Foo", NULL);
+			CPPUNIT_FAIL("changeTrailer(\"Foo\", NULL) should fail also for easy mode");
+		}catch(ElementBadTypeException )
+		{
+		}
+		try
+		{
+			xref2->changeTrailer(NULL, NULL);
+			CPPUNIT_FAIL("changeTrailer(NULL, NULL) should fail also for easy mode");
+		}catch(ElementBadTypeException )
+		{
+		}
+		try
+		{
+			xref2->changeTrailer(NULL, &oInt);
+			CPPUNIT_FAIL("changeTrailer(NULL, obj) should fail also for easy mode");
+		}catch(ElementBadTypeException )
+		{
+		}
+
+		static const struct TestField fieldsToTest[] = {
+			{"Prev", &oInt}, 
+			{"Size", &oInt}, 
+			{"Root", &oRef},
+			{"Encrypt", &oRef},
+			{"Info", &oRef},
+			{"ID", &oArray},
+			{"Foo", NULL}};
+		Object *allValues[] = {&oNull, &oInt, &oRef, &oDict, &oArray, &oStream};
+
+		for(size_t i=0; i<staticArraySize(fieldsToTest); ++i) 
+		{
+			const char *name = fieldsToTest[i].name;
+			bool canChange = utils::canChangeTrailerEntry(name);
+			printf("\t%s: canChange=%s\n", name, (canChange)?"yes":"no");
+			
+			// check for canChangeTrailerEntry and changeTrailer consistency
+			try
+			{
+				// if the validVal==NULL then all values are valid
+				if(fieldsToTest[i].validVal)
+					xref1->changeTrailer(name, fieldsToTest[i].validVal);
+				else
+					for(size_t j=0; j<staticArraySize(allValues); ++j)
+						xref1->changeTrailer(name, allValues[j]);
+
+				CPPUNIT_ASSERT(canChange);
+			}catch(ElementBadTypeException)
+			{
+				CPPUNIT_ASSERT(!canChange);
+			}
+
+			// invalid value must fail - only for fields which have some
+			// well known invalid value (validVal!=NULL) - invalid values
+			// are considered all but the valid one
+			if (canChange && fieldsToTest[i].validVal)
+				for(size_t j=0; j<staticArraySize(allValues); j++)
+				{
+					if (fieldsToTest[i].validVal != allValues[j])
+					{
+						Object *o = allValues[j];
+						printf("\t%s: must fail with invalid value with type=%d\n", name, o->getType());
+						try
+						{
+							xref1->changeTrailer(name, o);
+							CPPUNIT_FAIL("Invalid value setting succedded for changeTrailer");
+						}catch(ElementBadTypeException)
+						{
+						}
+					}
+				}
+
+			// ADVANCED mode eats everything
+			printf("\t%s: Advanced mode eats everything\n", name);
+			for(size_t j=0; j<staticArraySize(allValues); j++)
+			{
+				try
+				{
+					Object *o = allValues[j];
+					xref2->changeTrailer(name, o);
+				}catch(ElementBadTypeException)
+				{
+					CPPUNIT_FAIL("changeTrailer failed in Advanced mode");
+				}
+			}
+		}
+
+		// play with CPdf now
+		pdf2.reset();
+		pdf2 = getTestCPdf(fname.c_str(), CPdf::Advanced);
+		printf("\tCheck CPdf::changeTrailer\n");
+		std::string name = "FooXXXXXXXXX";
+		int initV = 100;
+		shared_ptr<IProperty> vP(CIntFactory::getInstance(initV));
+		pdf2->changeTrailer(name, vP);
+		shared_ptr<const CDict> trailer = pdf2->getTrailer();
+		shared_ptr<CInt> newVP = IProperty::getSmartCObjectPtr<CInt>(trailer->getProperty(name));
+		int v = newVP->getValue();
+		CPPUNIT_ASSERT(v == initV);
+
+		if (pdf2->getRevisionsCount()>1)
+		{
+			pdf2->changeRevision(0);
+			trailer = pdf2->getTrailer();
+			printf("\tCPdf::changeTrailer mustn't influence other revisions\n");
+			try
+			{
+				IProperty::getSmartCObjectPtr<CInt>(trailer->getProperty(name));
+				CPPUNIT_FAIL("trailer shouldn't contain property added in a different revision");
+			}catch(ElementNotFoundException )
+			{
+			}
+			printf("\tCPdf::changeTrailer must survive revision change\n");
+			pdf2->changeRevision(pdf2->getRevisionsCount()-1);
+			trailer = pdf2->getTrailer();
+			newVP = IProperty::getSmartCObjectPtr<CInt>(trailer->getProperty(name));
+			v = newVP->getValue();
+			CPPUNIT_ASSERT(v == initV);
+		}
 	}
 
 	void setUp()
@@ -1080,12 +1335,11 @@ public:
 		{
 			string fileName=*i;
 			printf("\nTests for file:%s\n", fileName.c_str());
-			CPdf * pdf=getTestCPdf(fileName.c_str());
+			boost::shared_ptr<CPdf> pdf=getTestCPdf(fileName.c_str());
 			string filterName;
-			if(pdfobjects::utils::isEncrypted(*pdf, &filterName))
+			if(pdfobjects::utils::isEncrypted(pdf))
 			{
 				printf("Test file is encrypted and so not supported.\n");
-				printf("File is encrypted by %s method\n", filterName.c_str());
 				continue;
 			}
 			// pageIterationTC is before indirectPropertyTC because it needs to
@@ -1095,9 +1349,10 @@ public:
 			cloneTC(pdf, fileName);
 			indirectPropertyTC(pdf);
 			pageManipulationTC(pdf);
-			pdf->close();
+			linearizedTC(pdf);
 
 			delinearizatorTC(fileName);
+			changeTrailerTC(fileName);
 		}
 		revisionsTC();
 		printf("TEST_CPDF testig finished\n");
@@ -1107,7 +1362,7 @@ public:
 CPPUNIT_TEST_SUITE_REGISTRATION(TestCPdf);
 CPPUNIT_TEST_SUITE_NAMED_REGISTRATION(TestCPdf, "TEST_CPDF");
 
-pdfobjects::CPdf * getTestCPdf(const char* filename)
+boost::shared_ptr<pdfobjects::CPdf> getTestCPdf(const char* filename, pdfobjects::CPdf::OpenMode mode)
 {
-	return CPdf::getInstance(filename, CPdf::ReadWrite);
+	return CPdf::getInstance(filename, mode);
 }
