@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,6 +29,6 @@
 #include "tests/kernel/testmain.h"
 
 
-pdfobjects::CPdf * getTestCPdf(const char* filename);
+boost::shared_ptr<pdfobjects::CPdf> getTestCPdf(const char* filename, pdfobjects::CPdf::OpenMode mode=pdfobjects::CPdf::ReadWrite);
 
 #endif // _TESTCPDF_H_
