@@ -1,9 +1,9 @@
 /*
  * PDFedit - free program for PDF document manipulation.
- * Copyright (C) 2006, 2007, 2008  PDFedit team: Michal Hocko,
- *                                              Miroslav Jahoda,
- *                                              Jozef Misutka,
- *                                              Martin Petricek
+ * Copyright (C) 2006-2009  PDFedit team: Michal Hocko,
+ *                                        Jozef Misutka,
+ *                                        Martin Petricek
+ *                   Former team members: Miroslav Jahoda
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,7 +48,7 @@ public:
         /** Iterator type. */
         typedef typename Mapping::iterator Iterator;
 
-        /* Constant iterator type. */
+        /** Constant iterator type. */
         typedef typename Mapping::const_iterator ConstIterator;
 
         /** Empty constructor.
@@ -172,6 +172,15 @@ public:
                 return mapping.begin();
         }
 
+        /** Returns const iterator to first element.
+         *
+         * @return ConstIterator instance.
+         */
+	ConstIterator begin()const
+	{
+		return mapping.begin();
+	}
+
         /** Returns iterator to end iterator.
          *
          * @return Iterator instance.
@@ -180,5 +189,14 @@ public:
         {
                 return mapping.end();
         }
+
+        /** Returns const iterator to end iterator.
+         *
+         * @return ConstIterator instance.
+         */
+	ConstIterator end()const
+	{
+		return mapping.end();
+	}
 };
 #endif
