@@ -19,7 +19,7 @@
 
 //------------------------------------------------------------------------
 
-typedef void (*FoFiOutputFunc)(void *stream, char *data, int len);
+typedef void (*FoFiOutputFunc)(void *stream, const char *data, int len);
 
 //------------------------------------------------------------------------
 // FoFiBase
@@ -33,20 +33,20 @@ public:
 protected:
 
   FoFiBase(char *fileA, int lenA, GBool freeFileDataA);
-  static char *readFile(char *fileName, int *fileLen);
+  static char *readFile(const char *fileName, int *fileLen);
 
   // S = signed / U = unsigned
   // 8/16/32/Var = word length, in bytes
   // BE = big endian
-  int getS8(int pos, GBool *ok);
-  int getU8(int pos, GBool *ok);
-  int getS16BE(int pos, GBool *ok);
-  int getU16BE(int pos, GBool *ok);
-  int getS32BE(int pos, GBool *ok);
-  Guint getU32BE(int pos, GBool *ok);
-  Guint getUVarBE(int pos, int size, GBool *ok);
+  int getS8(int pos, GBool *ok)const;
+  int getU8(int pos, GBool *ok)const;
+  int getS16BE(int pos, GBool *ok)const;
+  int getU16BE(int pos, GBool *ok)const;
+  int getS32BE(int pos, GBool *ok)const;
+  Guint getU32BE(int pos, GBool *ok)const;
+  Guint getUVarBE(int pos, int size, GBool *ok)const;
 
-  GBool checkRegion(int pos, int size);
+  GBool checkRegion(int pos, int size)const;
 
   Guchar *fileData;
   Guchar *file;
