@@ -7,7 +7,7 @@
 #ifndef SPLASHFTFONT_H
 #define SPLASHFTFONT_H
 
-#include <aconf.h>
+#include <xpdf-aconf.h>
 
 #if HAVE_FREETYPE_FREETYPE_H || HAVE_FREETYPE_H
 
