@@ -7,7 +7,7 @@
 #ifndef SPLASHFONTFILEID_H
 #define SPLASHFONTFILEID_H
 
-#include <aconf.h>
+#include <xpdf-aconf.h>
 
 #ifdef USE_GCC_PRAGMAS
 #pragma interface
@@ -24,7 +24,7 @@ public:
 
   SplashFontFileID();
   virtual ~SplashFontFileID();
-  virtual GBool matches(SplashFontFileID *id) = 0;
+  virtual GBool matches(const SplashFontFileID *id)const = 0;
 };
 
 #endif
