@@ -33,8 +33,8 @@ public:
 
   // Create the CMap specified by <collection> and <cMapName>.  Sets
   // the initial reference count to 1.  Returns NULL on failure.
-  static CMap *parse(CMapCache *cache, GString *collectionA,
-		     GString *cMapNameA);
+  static CMap *parse(CMapCache *cache, const GString *collectionA,
+		     const GString *cMapNameA);
 
   ~CMap();
 
@@ -42,26 +42,26 @@ public:
   void decRefCnt();
 
   // Return collection name (<registry>-<ordering>).
-  GString *getCollection() { return collection; }
+  const GString *getCollection()const { return collection; }
 
   // Return true if this CMap matches the specified <collectionA>, and
   // <cMapNameA>.
-  GBool match(GString *collectionA, GString *cMapNameA);
+  GBool match(const GString *collectionA, const GString *cMapNameA)const;
 
   // Return the CID corresponding to the character code starting at
   // <s>, which contains <len> bytes.  Sets *<nUsed> to the number of
   // bytes used by the char code.
-  CID getCID(char *s, int len, int *nUsed);
+  CID getCID(const char *s, int len, int *nUsed)const;
 
   // Return the writing mode (0=horizontal, 1=vertical).
-  int getWMode() { return wMode; }
+  int getWMode()const { return wMode; }
 
 private:
 
   CMap(GString *collectionA, GString *cMapNameA);
   CMap(GString *collectionA, GString *cMapNameA, int wModeA);
-  void useCMap(CMapCache *cache, char *useName);
-  void copyVector(CMapVectorEntry *dest, CMapVectorEntry *src);
+  void useCMap(CMapCache *cache, const char *useName);
+  void copyVector(CMapVectorEntry *dest, const CMapVectorEntry *src);
   void addCodeSpace(CMapVectorEntry *vec, Guint start, Guint end,
 		    Guint nBytes);
   void addCIDs(Guint start, Guint end, Guint nBytes, CID firstCID);
@@ -92,7 +92,7 @@ public:
   // Increments its reference count; there will be one reference for
   // the cache plus one for the caller of this function.  Returns NULL
   // on failure.
-  CMap *getCMap(GString *collection, GString *cMapName);
+  CMap *getCMap(const GString *collection, const GString *cMapName);
 
 private:
 
