@@ -33,13 +33,13 @@ public:
   // Read the CID-to-Unicode mapping for <collection> from the file
   // specified by <fileName>.  Sets the initial reference count to 1.
   // Returns NULL on failure.
-  static CharCodeToUnicode *parseCIDToUnicode(GString *fileName,
-					      GString *collection);
+  static CharCodeToUnicode *parseCIDToUnicode(const GString *fileName,
+					      const GString *collection);
 
   // Create a Unicode-to-Unicode mapping from the file specified by
   // <fileName>.  Sets the initial reference count to 1.  Returns NULL
   // on failure.
-  static CharCodeToUnicode *parseUnicodeToUnicode(GString *fileName);
+  static CharCodeToUnicode *parseUnicodeToUnicode(const GString *fileName);
 
   // Create the CharCode-to-Unicode mapping for an 8-bit font.
   // <toUnicode> is an array of 256 Unicode indexes.  Sets the initial
@@ -47,11 +47,11 @@ public:
   static CharCodeToUnicode *make8BitToUnicode(Unicode *toUnicode);
 
   // Parse a ToUnicode CMap for an 8- or 16-bit font.
-  static CharCodeToUnicode *parseCMap(GString *buf, int nBits);
+  static CharCodeToUnicode *parseCMap(const GString *buf, int nBits);
 
   // Parse a ToUnicode CMap for an 8- or 16-bit font, merging it into
   // <this>.
-  void mergeCMap(GString *buf, int nBits);
+  void mergeCMap(const GString *buf, int nBits);
 
   ~CharCodeToUnicode();
 
@@ -59,17 +59,17 @@ public:
   void decRefCnt();
 
   // Return true if this mapping matches the specified <tagA>.
-  GBool match(GString *tagA);
+  GBool match(const GString *tagA)const;
 
   // Set the mapping for <c>.
-  void setMapping(CharCode c, Unicode *u, int len);
+  void setMapping(CharCode c, const Unicode *u, int len);
 
   // Map a CharCode to Unicode.
-  int mapToUnicode(CharCode c, Unicode *u, int size);
+  int mapToUnicode(CharCode c, Unicode *u, int size)const;
 
   // Return the mapping's length, i.e., one more than the max char
   // code supported by the mapping.
-  CharCode getLength() { return mapLen; }
+  CharCode getLength()const { return mapLen; }
 
 private:
 
@@ -103,7 +103,7 @@ public:
   // Get the CharCodeToUnicode object for <tag>.  Increments its
   // reference count; there will be one reference for the cache plus
   // one for the caller of this function.  Returns NULL on failure.
-  CharCodeToUnicode *getCharCodeToUnicode(GString *tag);
+  CharCodeToUnicode *getCharCodeToUnicode(const GString *tag)const;
 
   // Insert <ctu> into the cache, in the most-recently-used position.
   void add(CharCodeToUnicode *ctu);
