@@ -6,7 +6,7 @@
 //
 //========================================================================
 
-#include <aconf.h>
+#include <xpdf-aconf.h>
 
 #ifdef USE_GCC_PRAGMAS
 #pragma implementation
@@ -35,7 +35,7 @@ static Guchar passwordPad[32] = {
 //------------------------------------------------------------------------
 
 GBool Decrypt::makeFileKey(int encVersion, int encRevision, int keyLength,
-			   GString *ownerKey, GString *userKey,
+			   const GString *ownerKey, const GString *userKey,
 			   int permissions, GString *fileID,
 			   GString *ownerPassword, GString *userPassword,
 			   Guchar *fileKey, GBool encryptMetadata,
@@ -100,7 +100,7 @@ GBool Decrypt::makeFileKey(int encVersion, int encRevision, int keyLength,
 }
 
 GBool Decrypt::makeFileKey2(int encVersion, int encRevision, int keyLength,
-			    GString *ownerKey, GString *userKey,
+			    const GString *ownerKey, const GString *userKey,
 			    int permissions, GString *fileID,
 			    GString *userPassword, Guchar *fileKey,
 			    GBool encryptMetadata) {
@@ -181,7 +181,7 @@ GBool Decrypt::makeFileKey2(int encVersion, int encRevision, int keyLength,
 // DecryptStream
 //------------------------------------------------------------------------
 
-DecryptStream::DecryptStream(Stream *strA, Guchar *fileKey,
+DecryptStream::DecryptStream(Stream *strA, const Guchar *fileKey,
 			     CryptAlgorithm algoA, int keyLength,
 			     int objNum, int objGen):
   FilterStream(strA)
@@ -335,7 +335,7 @@ int DecryptStream::lookChar() {
   return c;
 }
 
-GBool DecryptStream::isBinary(GBool last) {
+GBool DecryptStream::isBinary(GBool last)const {
   return str->isBinary(last);
 }
 
