@@ -445,11 +445,11 @@ void JPXStream::fillReadBuf() {
   } while (readBufLen < 8);
 }
 
-GString *JPXStream::getPSFilter(int psLevel, char *indent) {
+GString *JPXStream::getPSFilter(int psLevel, const char *indent)const {
   return NULL;
 }
 
-GBool JPXStream::isBinary(GBool last) {
+GBool JPXStream::isBinary(GBool last)const {
   return str->isBinary(gTrue);
 }
 
