@@ -6,7 +6,7 @@
 //
 //========================================================================
 
-#include <aconf.h>
+#include <xpdf-aconf.h>
 
 #ifdef USE_GCC_PRAGMAS
 #pragma implementation
@@ -50,7 +50,9 @@ public:
 
   // Create an object stream, using object number <objStrNum>,
   // generation 0.
-  ObjectStream(XRef *xref, int objStrNumA);
+  ObjectStream(const XRef *xref, int objStrNumA);
+
+  GBool isOk()const { return ok; }
 
   ~ObjectStream();
 
@@ -67,9 +69,10 @@ private:
   int nObjects;			// number of objects in the stream
   Object *objs;			// the objects (length = nObjects)
   int *objNums;			// the object numbers (length = nObjects)
+  GBool ok;
 };
 
-ObjectStream::ObjectStream(XRef *xref, int objStrNumA) {
+ObjectStream::ObjectStream(const XRef *xref, int objStrNumA) {
   Stream *str;
   Parser *parser;
   int *offsets;
@@ -80,7 +83,10 @@ ObjectStream::ObjectStream(XRef *xref, int objStrNumA) {
   nObjects = 0;
   objs = NULL;
   objNums = NULL;
+  ok = gFalse;
 
+  // we don't have to check for isOk here because fetch failure
+  // is reported via returned objNull
   if (!xref->fetch(objStrNum, 0, &objStr)->isStream()) {
     goto err1;
   }
@@ -105,6 +111,13 @@ ObjectStream::ObjectStream(XRef *xref, int objStrNumA) {
     goto err1;
   }
 
+  // this is an arbitrary limit to avoid integer overflow problems
+  // in the 'new Object[nObjects]' call (Acrobat apparently limits
+  // object streams to 100-200 objects)
+  if (nObjects > 1000000) {
+    error(-1, "Too many objects in an object stream");
+    goto err1;
+  }
   objs = new Object[nObjects];
   objNums = (int *)gmallocn(nObjects, sizeof(int));
   offsets = (int *)gmallocn(nObjects, sizeof(int));
@@ -115,8 +128,12 @@ ObjectStream::ObjectStream(XRef *xref, int objStrNumA) {
   str = new EmbedStream(objStr.getStream(), &obj1, gTrue, first);
   parser = new Parser(xref, new Lexer(xref, str), gFalse);
   for (i = 0; i < nObjects; ++i) {
-    parser->getObj(&obj1);
-    parser->getObj(&obj2);
+    if(!parser->getObj(&obj1))
+      goto malformedErr;
+    if(!parser->getObj(&obj2)) {
+      obj1.free();
+      goto malformedErr;
+    }
     if (!obj1.isInt() || !obj2.isInt()) {
       obj1.free();
       obj2.free();
@@ -155,16 +172,24 @@ ObjectStream::ObjectStream(XRef *xref, int objStrNumA) {
 			    offsets[i+1] - offsets[i]);
     }
     parser = new Parser(xref, new Lexer(xref, str), gFalse);
-    parser->getObj(&objs[i]);
+    if(!parser->getObj(&objs[i])) 
+      goto malformedErr;
+    
     while (str->getChar() != EOF) ;
     delete parser;
   }
 
   gfree(offsets);
+  ok = gTrue;
 
  err1:
   objStr.free();
   return;
+ malformedErr:
+  gfree(offsets);
+  if(parser)
+    delete parser;
+  // TODO getObj how to hande ObjectStream constructor
 }
 
 ObjectStream::~ObjectStream() {
@@ -190,12 +215,37 @@ Object *ObjectStream::getObject(int objIdx, int objNum, Object *obj) {
 // XRef
 //------------------------------------------------------------------------
 
-XRef::XRef(BaseStream *strA) {
+static const char * PDFHEADER="%PDF-";
+XRef::XRef(BaseStream *strA):entries(NULL), streamEnds(NULL), objStr(NULL) {
   // inits stream and initializes internals
   str = strA;
+
+  setErrCode(errNone);
+  // get PDF specification version from file
+  char buffer[1024];
+  char * header;
+  str->reset();
+  do {
+    if(!str->getLine(buffer, sizeof(buffer)))
+    {
+      setErrCode(errBadHeader);
+      error(-1, "PDF file doesn't contain proper header");
+      return;
+    }
+  }while (!(header = strstr(buffer, PDFHEADER)));
+  header+=strlen(PDFHEADER);
+  pdfVersion.append(header);
+
   // gets position of last xref section
   Guint pos = getStartXref();
-  initInternals(pos);
+  if(isOk())
+    initInternals(pos);
+}
+
+void XRef::setErrCode(int err)const
+{
+  errCode = err;
+  ok = (errCode == errNone)?gTrue:gFalse;
 }
 
 /** Initializes all XRef internal structures.
@@ -208,14 +258,15 @@ void XRef::initInternals(Guint pos)
   Object obj;
 
   ok = gTrue;
-  errCode = errNone;
+  setErrCode(errNone);
   size = 0;
   entries = NULL;
   streamEnds = NULL;
   streamEndsLen = 0;
   objStr = NULL;
+  maxObj = 0;
 
-  encrypted = gFalse;
+  useEncrypt = gFalse;
   permFlags = defPermFlags;
   ownerPasswordOk = gFalse;
 
@@ -226,7 +277,7 @@ void XRef::initInternals(Guint pos)
   // reconstruct the xref table
   if (pos == 0) {
     if (!(ok = constructXRef())) {
-      errCode = errDamaged;
+      setErrCode(errDamaged);
       return;
     }
 
@@ -238,35 +289,38 @@ void XRef::initInternals(Guint pos)
     // try to reconstruct it
     if (!ok) {
       if (!(ok = constructXRef())) {
-	errCode = errDamaged;
+	setErrCode(errDamaged);
 	return;
       }
     }
   }
 
   // get the root dictionary (catalog) object
-  trailerDict.dictLookupNF("Root", &obj);
-  if (obj.isRef()) {
-    rootNum = obj.getRefNum();
-    rootGen = obj.getRefGen();
-    obj.free();
-  } else {
+  getTrailerDict()->dictLookupNF("Root", &obj);
+  if (!obj.isRef()) {
     obj.free();
     if (!(ok = constructXRef())) {
-      errCode = errDamaged;
+      setErrCode(errDamaged);
       return;
     }
   }
 
   // now set the trailer dictionary's xref pointer so we can fetch
   // indirect objects from it
-  trailerDict.getDict()->setXRef(this);
+  Dict *d = (Dict *)getTrailerDict()->getDict();
+  d->setXRef(this);
 }
 
 void XRef::destroyInternals()
 {
-  gfree(entries);
-  entries=NULL;
+  if(entries)
+  {
+    gfree(entries);
+    entries=NULL;
+  }
+  // Don't use getTrailerDict here because we have to be sure that we
+  // are deallocating the correct trailer (not the one from descendant
+  // class which replaces the original one because of changes)
   trailerDict.free();
   if (streamEnds) {
     gfree(streamEnds);
@@ -285,9 +339,10 @@ XRef::~XRef() {
 // Read the 'startxref' position.
 Guint XRef::getStartXref() {
   char buf[xrefSearchSize+1];
-  char *p;
   int c, n, i;
 
+  setErrCode(errNone);
+
   // read last xrefSearchSize bytes
   str->setPos(xrefSearchSize, -1);
   for (n = 0; n < xrefSearchSize; ++n) {
@@ -305,12 +360,15 @@ Guint XRef::getStartXref() {
     }
   }
   if (i < 0) {
+    setErrCode(errDamaged);
     return 0;
   }
-  for (p = &buf[i+9]; isspace(*p); ++p) ;
-  lastXRefPos = strToUnsigned(p);
 
-  // p points to file offset value for startxref now, we will try to 
+  // get value for startxref
+  for (i += strlen("startxref"); isspace(buf[i]); ++i) ;
+  lastXRefPos = strToUnsigned(&buf[i]);
+
+  // We are immediatelly after startxref value now. We will try to 
   // find %%EOF from here. If not found, we will use end of buffer as
   // end of file position
   for(; i<n; i++)
@@ -320,7 +378,7 @@ Guint XRef::getStartXref() {
   // calculates eofPos from position in buffer
   // sets position to %%EOF start from buffer begining
   // which starts at xrefSearchSize from the end of stream
-  str->setPos(xrefSearchSize-i, -1);
+  str->setPos(n-i, -1);
   eofPos=str->getPos();
 
   return lastXRefPos;
@@ -329,7 +387,7 @@ Guint XRef::getStartXref() {
 // Read one xref table section.  Also reads the associated trailer
 // dictionary, and returns the prev pointer (if any).
 GBool XRef::readXRef(Guint *pos) {
-  Parser *parser;
+  Parser *parser = NULL;
   Object obj;
   GBool more;
 
@@ -339,7 +397,8 @@ GBool XRef::readXRef(Guint *pos) {
 	     new Lexer(NULL,
 	       str->makeSubStream(start + *pos, gFalse, 0, &obj)),
 	     gTrue);
-  parser->getObj(&obj);
+  if (!parser->getObj(&obj))
+    goto malformedErr;
 
   // parse an old-style xref table
   if (obj.isCmd("xref")) {
@@ -349,17 +408,21 @@ GBool XRef::readXRef(Guint *pos) {
   // parse an xref stream
   } else if (obj.isInt()) {
     obj.free();
-    if (!parser->getObj(&obj)->isInt()) {
+    Object * fetch;
+    if (!(fetch = parser->getObj(&obj)))
+      goto malformedErr;
+    if (!fetch->isInt()) 
       goto err1;
-    }
     obj.free();
-    if (!parser->getObj(&obj)->isCmd("obj")) {
+    if (!(fetch = parser->getObj(&obj)))
+      goto malformedErr;
+    if (!fetch->isCmd("obj")) 
       goto err1;
-    }
     obj.free();
-    if (!parser->getObj(&obj)->isStream()) {
+    if (!(fetch = parser->getObj(&obj)))
+      goto malformedErr;
+    if (!fetch->isStream()) 
       goto err1;
-    }
     more = readXRefStream(obj.getStream(), pos);
     obj.free();
 
@@ -370,9 +433,11 @@ GBool XRef::readXRef(Guint *pos) {
   delete parser;
   return more;
 
- err1:
+err1:
   obj.free();
-  delete parser;
+malformedErr:
+  if(parser)
+    delete parser;
   ok = gFalse;
   return gFalse;
 }
@@ -382,10 +447,13 @@ GBool XRef::readXRefTable(Parser *parser, Guint *pos) {
   GBool more;
   Object obj, obj2;
   Guint pos2;
-  int first, n, newSize, i;
+  Object * fetch;
+  int first, n, newSize;
+  Guint i;
 
   while (1) {
-    parser->getObj(&obj);
+    if (!parser->getObj(&obj))
+      goto malformedErr;
     if (obj.isCmd("trailer")) {
       obj.free();
       break;
@@ -395,7 +463,9 @@ GBool XRef::readXRefTable(Parser *parser, Guint *pos) {
     }
     first = obj.getInt();
     obj.free();
-    if (!parser->getObj(&obj)->isInt()) {
+    if (!(fetch = parser->getObj(&obj)))
+      goto malformedErr;
+    if (!fetch->isInt()) {
       goto err1;
     }
     n = obj.getInt();
@@ -413,22 +483,28 @@ GBool XRef::readXRefTable(Parser *parser, Guint *pos) {
       entries = (XRefEntry *)greallocn(entries, newSize, sizeof(XRefEntry));
       for (i = size; i < newSize; ++i) {
 	entries[i].offset = 0xffffffff;
+	entries[i].gen = 0;
 	entries[i].type = xrefEntryFree;
       }
       size = newSize;
     }
     for (i = first; i < first + n; ++i) {
-      if (!parser->getObj(&obj)->isInt()) {
+      if (!(fetch = parser->getObj(&obj)))
+        goto malformedErr;
+      if (!fetch->isInt()) {
 	goto err1;
       }
       entry.offset = (Guint)obj.getInt();
       obj.free();
-      if (!parser->getObj(&obj)->isInt()) {
+      if (!(fetch = parser->getObj(&obj)))
+        goto malformedErr;
+      if (!fetch->isInt()) {
 	goto err1;
       }
       entry.gen = obj.getInt();
       obj.free();
-      parser->getObj(&obj);
+      if (!parser->getObj(&obj))
+        goto malformedErr;
       if (obj.isCmd("n")) {
 	entry.type = xrefEntryUncompressed;
       } else if (obj.isCmd("f")) {
@@ -449,12 +525,18 @@ GBool XRef::readXRefTable(Parser *parser, Guint *pos) {
 	  entries[0] = entries[1];
 	  entries[1].offset = 0xffffffff;
 	}
+
+	// store maximum present indirect object number
+	if (entries[i].type != xrefEntryFree && i > maxObj)
+	  maxObj = i;
       }
     }
   }
 
   // read the trailer dictionary
-  if (!parser->getObj(&obj)->isDict()) {
+  if (!(fetch = parser->getObj(&obj)))
+    goto malformedErr;
+  if (!fetch->isDict()) {
     goto err1;
   }
 
@@ -474,6 +556,8 @@ GBool XRef::readXRefTable(Parser *parser, Guint *pos) {
   obj2.free();
 
   // save the first trailer dictionary
+  // XPDF don't care about older trailers and it always uses the
+  // most recent one
   if (trailerDict.isNone()) {
     obj.copy(&trailerDict);
   }
@@ -492,14 +576,15 @@ GBool XRef::readXRefTable(Parser *parser, Guint *pos) {
   obj.free();
   return more;
 
- err1:
+err1:
   obj.free();
+malformedErr:
   ok = gFalse;
   return gFalse;
 }
 
 GBool XRef::readXRefStream(Stream *xrefStr, Guint *pos) {
-  Dict *dict;
+  const Dict *dict;
   int w[3];
   GBool more;
   Object obj, obj2, idx;
@@ -519,6 +604,7 @@ GBool XRef::readXRefStream(Stream *xrefStr, Guint *pos) {
     entries = (XRefEntry *)greallocn(entries, newSize, sizeof(XRefEntry));
     for (i = size; i < newSize; ++i) {
       entries[i].offset = 0xffffffff;
+      entries[i].gen = 0;
       entries[i].type = xrefEntryFree;
     }
     size = newSize;
@@ -579,8 +665,11 @@ GBool XRef::readXRefStream(Stream *xrefStr, Guint *pos) {
     more = gFalse;
   }
   obj.free();
+  // save the first trailer dictionary
+  // XPDF don't care about older trailers and it always uses the
+  // most recent one
   if (trailerDict.isNone()) {
-    trailerDict.initDict(dict);
+    trailerDict.initDict((Dict *)dict);
   }
 
   return more;
@@ -609,6 +698,7 @@ GBool XRef::readXRefStreamSection(Stream *xrefStr, int *w, int first, int n) {
     entries = (XRefEntry *)greallocn(entries, newSize, sizeof(XRefEntry));
     for (i = size; i < newSize; ++i) {
       entries[i].offset = 0xffffffff;
+      entries[i].gen = 0;
       entries[i].type = xrefEntryFree;
     }
     size = newSize;
@@ -657,14 +747,41 @@ GBool XRef::readXRefStreamSection(Stream *xrefStr, int *w, int first, int n) {
 	return gFalse;
       }
     }
+
+    // store maximum present indirect object number
+    if (entries[i].type != xrefEntryFree && i > maxObj)
+      maxObj = i;
   }
 
   return gTrue;
 }
 
+/** Returns the size of EOL marker preceding the given possition.
+ * @param pos Position at the begginning of the line.
+ * @param str Stream
+ *
+ * Stream will keep its current possition.
+ *
+ * @return length of the EOL (if any) preceeing pos.
+ */
+static int eolLength(Guint pos, BaseStream *str)
+{
+	Guint currPos = str->getPos();
+	str->setPos(pos-2);
+	int ch1 = str->getChar();
+	int ch2 = str->getChar();
+	int eoln = 0;
+	if (ch1 == '\r' && ch2 == '\n')
+		eoln = 2;
+	else if (ch2 == '\n')
+			eoln = 1;
+	str->setPos(currPos);
+	return eoln;
+}
+
 // Attempt to construct an xref table for a damaged file.
 GBool XRef::constructXRef() {
-  Parser *parser;
+  Parser *parser = NULL;
   Object newTrailerDict, obj;
   char buf[256];
   Guint pos;
@@ -701,12 +818,11 @@ GBool XRef::constructXRef() {
 		 new Lexer(NULL,
 		   str->makeSubStream(pos + 7, gFalse, 0, &obj)),
 		 gFalse);
-      parser->getObj(&newTrailerDict);
+      if (!parser->getObj(&newTrailerDict))
+        goto malformedErr;
       if (newTrailerDict.isDict()) {
 	newTrailerDict.dictLookupNF("Root", &obj);
 	if (obj.isRef()) {
-	  rootNum = obj.getRefNum();
-	  rootGen = obj.getRefGen();
 	  if (!trailerDict.isNone()) {
 	    trailerDict.free();
 	  }
@@ -720,20 +836,20 @@ GBool XRef::constructXRef() {
 
     // look for object
     } else if (isdigit((unsigned char)(*p))) {
-      num = atoi(p);
+      num = (int)strtoul(p, NULL, 10);
       if (num > 0) {
 	do {
 	  ++p;
-	} while (*p && isdigit(*p));
-	if (isspace(*p)) {
+	} while (*p && isdigit((unsigned char)*p));
+	if (isspace((unsigned char)*p)) {
 	  do {
 	    ++p;
 	  } while (*p && isspace(*p));
-	  if (isdigit(*p)) {
-	    gen = atoi(p);
+	  if (isdigit((unsigned char)*p)) {
+	    gen = (int)strtoul(p, NULL, 10);
 	    do {
 	      ++p;
-	    } while (*p && isdigit(*p));
+	    } while (*p && isdigit((unsigned char)*p));
 	    if (isspace(*p)) {
 	      do {
 		++p;
@@ -749,6 +865,7 @@ GBool XRef::constructXRef() {
 		      greallocn(entries, newSize, sizeof(XRefEntry));
 		  for (i = size; i < newSize; ++i) {
 		    entries[i].offset = 0xffffffff;
+		    entries[i].gen = 0;
 		    entries[i].type = xrefEntryFree;
 		  }
 		  size = newSize;
@@ -771,7 +888,18 @@ GBool XRef::constructXRef() {
 	streamEnds = (Guint *)greallocn(streamEnds,
 					streamEndsSize, sizeof(int));
       }
-      streamEnds[streamEndsLen++] = pos;
+      // We are reading lines and the pdf specification says that:
+      // "The sequence of bytes that make up a stream lie between the stream
+      // and endstream keywords; the stream dictionary specifies the exact 
+      // number of bytes. It is recommended that there be an end-of-line 
+      // marker after the data and before endstream; this marker is not 
+      // included in the stream length."
+      // So we have to either add stream data that preceeds the keyword
+      // or decrease the lenght by the lenght of EOL marker if we are at 
+      // the beggining of line
+      streamEnds[streamEndsLen++] = pos + 
+	      (p-buf)?p-buf
+	      :-eolLength(pos, str);
     }
   }
 
@@ -780,14 +908,19 @@ GBool XRef::constructXRef() {
 
   error(-1, "Couldn't find trailer dictionary");
   return gFalse;
+malformedErr:
+  error(-1, "malformed content. Not able to parse.");
+  if (parser)
+    delete parser;
+  return gFalse;
 }
 
 void XRef::setEncryption(int permFlagsA, GBool ownerPasswordOkA,
-			 Guchar *fileKeyA, int keyLengthA, int encVersionA,
+			 const Guchar *fileKeyA, int keyLengthA, int encVersionA,
 			 CryptAlgorithm encAlgorithmA) {
   int i;
 
-  encrypted = gTrue;
+  useEncrypt = gTrue;
   permFlags = permFlagsA;
   ownerPasswordOk = ownerPasswordOkA;
   if (keyLengthA <= 16) {
@@ -802,47 +935,56 @@ void XRef::setEncryption(int permFlagsA, GBool ownerPasswordOkA,
   encAlgorithm = encAlgorithmA;
 }
 
-GBool XRef::okToPrint(GBool ignoreOwnerPW) {
+GBool XRef::okToPrint(GBool ignoreOwnerPW)const {
   return (!ignoreOwnerPW && ownerPasswordOk) || (permFlags & permPrint);
 }
 
-GBool XRef::okToChange(GBool ignoreOwnerPW) {
+GBool XRef::okToChange(GBool ignoreOwnerPW)const {
   return (!ignoreOwnerPW && ownerPasswordOk) || (permFlags & permChange);
 }
 
-GBool XRef::okToCopy(GBool ignoreOwnerPW) {
+GBool XRef::okToCopy(GBool ignoreOwnerPW)const {
   return (!ignoreOwnerPW && ownerPasswordOk) || (permFlags & permCopy);
 }
 
-GBool XRef::okToAddNotes(GBool ignoreOwnerPW) {
+GBool XRef::okToAddNotes(GBool ignoreOwnerPW)const {
   return (!ignoreOwnerPW && ownerPasswordOk) || (permFlags & permNotes);
 }
 
-Object *XRef::fetch(int num, int gen, Object *obj) {
+Object *XRef::fetch(int num, int gen, Object *obj)const {
   XRefEntry *e;
   Parser *parser;
   Object obj1, obj2, obj3;
+  GBool failed = gFalse;
 
   // check for bogus ref - this can happen in corrupted PDF files
   if (num < 0 || num >= size) {
-    goto err;
+    goto err_no_obj;
   }
 
+  setErrCode(errNone);
   e = &entries[num];
   switch (e->type) {
 
   case xrefEntryUncompressed:
     if (e->gen != gen) {
-      goto err;
+      goto err_no_obj;
     }
     obj1.initNull();
     parser = new Parser(this,
 	       new Lexer(this,
 		 str->makeSubStream(start + e->offset, gFalse, 0, &obj1)),
 	       gTrue);
-    parser->getObj(&obj1);
-    parser->getObj(&obj2);
-    parser->getObj(&obj3);
+    if (!parser->getObj(&obj1))
+      goto err_damaged;
+    if (!parser->getObj(&obj2)) {
+      obj1.free();
+      goto err_damaged;
+    }
+    if (!parser->getObj(&obj3)) {
+      obj2.free();
+      goto err_damaged;
+    } 
     if (!obj1.isInt() || obj1.getInt() != num ||
 	!obj2.isInt() || obj2.getInt() != gen ||
 	!obj3.isCmd("obj")) {
@@ -850,49 +992,62 @@ Object *XRef::fetch(int num, int gen, Object *obj) {
       obj2.free();
       obj3.free();
       delete parser;
-      goto err;
+      goto err_damaged;
     }
-    parser->getObj(obj, encrypted ? fileKey : (Guchar *)NULL,
-		   encAlgorithm, keyLength, num, gen);
+    if (!parser->getObj(obj, useEncrypt ? fileKey : (const Guchar *)NULL,
+		   encAlgorithm, keyLength, num, gen)) 
+      failed = gTrue;
+
     obj1.free();
     obj2.free();
     obj3.free();
     delete parser;
+    if (failed)
+      goto err_damaged;
     break;
 
   case xrefEntryCompressed:
     if (gen != 0) {
-      goto err;
+      goto err_no_obj;
     }
     if (!objStr || objStr->getObjStrNum() != (int)e->offset) {
       if (objStr) {
 	delete objStr;
       }
       objStr = new ObjectStream(this, e->offset);
+      if (!objStr->isOk()) {
+	delete objStr;
+	objStr = NULL;
+	goto err_damaged;
+      }
     }
     objStr->getObject(e->gen, num, obj);
     break;
 
   default:
-    goto err;
+    // TODO is this correct?
+    goto err_no_obj;
   }
 
   return obj;
 
- err:
+ err_damaged:
+  setErrCode(errDamaged);
+  ok = false;
+ err_no_obj:
   return obj->initNull();
 }
 
 Object *XRef::getDocInfo(Object *obj) {
-  return trailerDict.dictLookup("Info", obj);
+  return getTrailerDict()->dictLookup("Info", obj);
 }
 
 // Added for the pdftex project.
 Object *XRef::getDocInfoNF(Object *obj) {
-  return trailerDict.dictLookupNF("Info", obj);
+  return getTrailerDict()->dictLookupNF("Info", obj);
 }
 
-GBool XRef::getStreamEnd(Guint streamStart, Guint *streamEnd) {
+GBool XRef::getStreamEnd(Guint streamStart, Guint *streamEnd)const {
   int a, b, m;
 
   if (streamEndsLen == 0 ||
@@ -915,14 +1070,70 @@ GBool XRef::getStreamEnd(Guint streamStart, Guint *streamEnd) {
   return gTrue;
 }
 
-Guint XRef::strToUnsigned(char *s) {
+Guint XRef::strToUnsigned(const char *s)const {
   Guint x;
-  char *p;
+  const char *p;
   int i;
 
   x = 0;
-  for (p = s, i = 0; *p && isdigit(*p) && i < 10; ++p, ++i) {
+  for (p = s, i = 0; *p && isdigit((unsigned char)*p) && i < 10; ++p, ++i) {
     x = 10 * x + (*p - '0');
   }
   return x;
 }
+
+int getRootFromTrailer(const Object *trailer, Ref &ref)
+{
+	Object o;
+	trailer->dictLookupNF("Root", &o);
+	if (o.getType() == objRef)
+	{
+		ref = o.getRef();
+		return 0;
+	}
+	return -1;
+}
+
+int XRef::getRootNum()const
+{
+	Ref r;
+	if(!getRootFromTrailer(getTrailerDict(), r))
+		return r.num;
+	return -1;
+}
+
+int XRef::getRootGen()const
+{
+	Ref r;
+	if(!getRootFromTrailer(getTrailerDict(), r))
+		return r.gen;
+	return -1;
+}
+
+RefState XRef::knowsRef(const Ref &ref)const
+{
+   // boundary checking
+   if(ref.num<0 || ref.num>size)
+      return UNUSED_REF;
+
+   switch(entries[ref.num].type)
+   {
+      // must not be free entry
+      case xrefEntryFree:
+         return UNUSED_REF;
+
+      // if uncompressed entry, also gen number must fit
+      case xrefEntryUncompressed:
+         return (ref.gen==entries[ref.num].gen)?INITIALIZED_REF:UNUSED_REF;
+
+      // if compressed entry, gen number must be 0
+      // NOTE: XRef internaly uses this number for indexing of object in 
+      // object stream
+      case xrefEntryCompressed:
+         return (ref.gen==0)?INITIALIZED_REF:UNUSED_REF;
+         
+   }
+
+   // unknown entry type
+   return UNUSED_REF;
+}
